/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package javax.xml;

/** <p>This class contains a set of constants, as specified
 * by various W3C and other standards.</p>
 *
 * @author JSR-31
 * @since JAXB 1.0
 */
public class XMLConstants {
  /** <p>This constant is used to represent the default
   * namespace. Elements or attributes in the default
   * namespace are sometimes also referred as "having no
   * namespace". The constant value is "" (the empty
   * string).</p>
   * <p><em>Note</em>: The default namespace is used like this
   * in SAX handlers. Note, that DOM uses <code>null</code>
   * to represent the default namespace, hence a different
   * value.</p> 
   */
  public static final String DEFAULT_NS_PREFIX = "";

  /** <p>Constant holding the reserved "xml" prefix. This
   * prefix is reserved by the XML namespace standard. Unlike
   * other prefixes, this one is fixed and will always be
   * associated with the same namespace, {@link #XML_NS_URI}.
   * Namespace and prefix are reserved by the XML namespace
   * standard for use by the XML specifications.</p>
   * <p><em>Note</em>: Not only the prefix "xml" itself is
   * reserved, but also any other prefix beginning with
   * "xml". For example, a "new_prefix" may be declared in an
   * XML instance by using the attribute "xmlns:new_prefix".</p>
   */
   public static final String XML_NS_PREFIX = "xml";

  /** <p>Constant holding the reserved namespace URI associated
   * with the "xml" prefix. Namespace and prefix are reserved
   * by the XML namespace standard for use by the XML specifications.</p>
   */
  public static final java.lang.String XML_NS_URI =
      "http://www.w3.org/XML/1998/namespace";

  /** <p>Constant holding the attribute name for declaration
   * of new prefixes. The constant value is "xmlns".</p>
   * <p><em>Note</em>: This is both an attribute name
   * and a namespace prefix: For example, to assign the empty
   * prefix to a namespace, one would use
   * <pre>
   *   xmlns="http://my.namespace/..."
   * </pre>
   * But for assigning the prefix "pre" to the same namespace,
   * one would use
   * <pre>
   *   xmlns:pre="http://my.namespace/..."
   * </pre></p>
   */
  public static final java.lang.String XMLNS_ATTRIBUTE = "xmlns";

  /** <p>Constant holding the namespace of the "xmlns" attribute:
   * "http://www.w3.org/2000/xmlns/".</p>
   * <p><em>Note</em>: This namespace will always be used for the
   * attribute, regardless whether you used it as an attribute name
   * (as in <code>xmlns="..."</code> or as an attribute prefix
   * (as in <code>xmlns:pre="..."</code>).</p>
   */
  public static final java.lang.String XMLNS_ATTRIBUTE_NS_URI =
      "http://www.w3.org/2000/xmlns/";
}
