/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package javax.xml.bind;

/** <p>An instance of <code>ValidationEvent</code> indicates some
 * error condition, which occurred when validating a JAXB object.
 * The purpose of the {@link ValidationEventHandler} is to
 * customize the reply on instances of <code>ValidationEvent</code>.
 * The default event handler will throw an exception in case of
 * events, but application specific validation event handlers need
 * not do the same.</p>
 * 
 * @see Validator
 * @see ValidationEventHandler
 * @since JAXB1.0
 * @author JSR-31
 */
public interface ValidationEvent {
  /** <p>In contrast to errors or fatal errors, this indicates an
   * event which can possibly be ignored. This constant has the
   * value 0. See section 1.2 of the W3C XML 1.0 Recommendation for
   * details.</p>
   * @see #ERROR
   * @see #FATAL_ERROR
   * @see #getSeverity()
   */
  public static final int WARNING = 0;

  /** <p>This value indicates an "error", as specified by section
   * 1.2 of the W3C XML 1.0 Recommendation. The constant value is
   * 1.</p>
   * @see #WARNING
   * @see #FATAL_ERROR
   * @see #getSeverity()
   */
  public static final int ERROR = 1;

  /** <p>This value indicates a "fatal error", as specified by section
   * 1.2 of the W3C XML 1.0 Recommendation. The constant value is
   * 2.</p>
   * @see #WARNING
   * @see #ERROR
   * @see #getSeverity()
   */
  public static final int FATAL_ERROR = 2;

  /** <p>Returns the events severity: Either of
   * {@link #WARNING}, {@link #ERROR}, or {@link #FATAL_ERROR}.</p>
   * @return Returns the events severity.
   */
  public int getSeverity();

  /** <p>Returns a textual description of the event.</p>
   */
  public java.lang.String getMessage();

  /** <p>Returns a {@link Throwable} related to the event. In most cases
   * an exception causing the event.</p>
   */
  public java.lang.Throwable getLinkedException();

  /** <p>Returns a description of the location, where the event
   * occurred.</p>
   */
  public ValidationEventLocator getLocator();
}
