/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package javax.xml.bind;


/** <p>A <code>Validator</code> may be used to decide, whether
 * a JAXB object is valid or not. If it is not, the JAXB user
 * may decide to trigger an exception or not (via the
 * {@link javax.xml.bind.ValidationEventHandler} and he may
 * receive information on the problems location (via the
 * event handlers {@link javax.xml.bind.ValidationEventLocator}.</p>
 * <p>A Validator may be present implicitly, invoked by the
 * Unmarshaller. See {@link javax.xml.bind.Unmarshaller#setValidating(boolean)} for
 * more information on that.</p>
 * @since JAXB1.0
 * @author JSR-31
 * @see ValidationEventHandler
 * @see ValidationEvent
 */
public interface Validator {
  /** <p>Registers an event handler that shall be invoked for
   * notifications on problems detected by the <code>Validator</code>.
   * If this method is not invoked, there is a default event handler.
   * The default event handler will trigger an exception for
   * errors and fatal errors.</p>
   *
   * @param pHandler The event handler being notified or null
   *   to restore the default event handler.
   * @throws JAXBExeption Setting the event handler failed.
   */
  public void setEventHandler(ValidationEventHandler pHandler) throws JAXBException;

  /** <p>Returns an event handler that shall be invoked for
   * notifications on problems detected by the <code>Validator</code>.
   * If no specific event handler was set, returns the default
   * event handler. The default event handler will trigger an
   * exception for errors and fatal errors.</p>
   *
   * @throws JAXBExeption Getting the event handler failed.
   * @return The event handler previously set or the default
   *   handler.
   */
  public ValidationEventHandler getEventHandler() throws JAXBException;

  /** <p>Validates the given JAXB object, invoking its error handler
   * for any problems it detects. Detected problems may cause exceptions,
   * for example, if the event handlers
   * {@link ValidationEventHandler#handleEvent(ValidationEvent)}
   * method returns false.</p>
   *
   * @param pObject The JAXB object being validated.
   * @throws JAXBException An unexpected problem occurred during
   *   validation
   * @throws ValidationException It was detected, that the
   *   object is invalid.
   * @throws IllegalArgumentException The parameter was null.
   * @see #validateRoot(Object)
   */
  public boolean validate(Object pObject) throws JAXBException;

  /** <p>Validates the given JAXB object, but not its child
   * elements.</p>
   *
   * @param pObject The JAXB object being validated.
   * @throws JAXBException An unexpected problem occurred during
   *   validation
   * @throws ValidationException It was detected, that the
   *   object is invalid.
   * @throws IllegalArgumentException The parameter was null.
   * @see #validate(Object)
   */ 
  public boolean validateRoot(Object pObject) throws JAXBException;

  /** <p>Sets the <code>Validator</code> property <code>pName</code>
   * to <code>pValue</code>.</p>
   * <p><em>Note</em>: The values type depends on the property name.</p>
   *
   * @param pName The property name.
   * @param pValue The property value.
   * @throws PropertyException Setting the property failed.
   * @throws IllegalArgumentException The <code>pName</code> parameter was null.
   */
  public void setProperty(String pName, Object pValue) throws PropertyException;

  /** <p>Returns the marshallers property <code>pName</code>.</p>
   * <p><em>Note</em>: The values type depends on the property name.</p>
   *
   * @param pName The property name.
   * @return The property value.
   * @throws PropertyException Fetching the property failed.
   * @throws IllegalArgumentException The parameter was null.
   */
  public java.lang.Object getProperty(String pName) throws PropertyException;
}
