/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package javax.xml.bind.helpers;

import javax.xml.bind.ValidationEvent;
import javax.xml.bind.ValidationEventLocator;

/** <p>Default implementation of a {@link javax.xml.bind.ValidationEvent}.</p>
 *
 * @author JSR-31
 * @since JAXB1.0
 */
public class ValidationEventImpl implements ValidationEvent {
  private int severity;
  private String message;
  private Throwable linkedException;
  private ValidationEventLocator locator;

  /** <p>Creates a new instance of <code>ValidationEventImpl</code>.</p>
   */
  public ValidationEventImpl(int pSeverity, String pMessage,
                             ValidationEventLocator pLocator) {
    severity = pSeverity;
    message = pMessage;
    locator = pLocator;
  }

  /** <p>Creates a new instance of <code>ValidationEventImpl</code>.</p>
   */
  public ValidationEventImpl(int pSeverity, String pMessage,
                             ValidationEventLocator pLocator,
                             Throwable pLinkedException) {
    severity = pSeverity;
    message = pMessage;
    linkedException = pLinkedException;
    locator = pLocator;
  }

  /* @see javax.xml.bind.ValidationEvent#getSeverity()
   */
  public int getSeverity() {
    return severity;
  }

  /** <p>Sets the events severity.</p>
   * @param pSeverity The events severity, either of
   * {@link javax.xml.bind.ValidationEvent#WARNING},
   * {@link javax.xml.bind.ValidationEvent#ERROR}, or
   * {@link javax.xml.bind.ValidationEvent#FATAL_ERROR}.</p> 
   */
  public void setSeverity(int pSeverity) {
    severity = pSeverity;
  }

  /* @see javax.xml.bind.ValidationEvent#getMessage()
   */
  public String getMessage() {
    return message;
  }

  /** <p>Sets the events message.</p>
   */
  public void setMessage(String pMessage) {
    message = pMessage;
  }

  /* @see javax.xml.bind.ValidationEvent#getLinkedException()
   */
  public Throwable getLinkedException() {
    return linkedException;
  }

  /** <p>Sets the exception, which is linked to the event.</p>
   */
  public void setLinkedException(Throwable pLinkedException) {
    linkedException = pLinkedException;
  }

  /* @see javax.xml.bind.ValidationEvent#getLocator()
   */
  public ValidationEventLocator getLocator() {
    return locator;
  }

  /** <p>Sets the events locator.</p>
   */
  public void setLocator(ValidationEventLocator pLocator) {
    locator = pLocator;
  }
}
