/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package javax.xml.bind.util;

import javax.xml.bind.JAXBException;
import javax.xml.bind.UnmarshallerHandler;
import javax.xml.transform.sax.SAXResult;


/** <p>Utility class that allows to catch the result of a
 * stylesheet transformation in a JAXB object.</p>
 *
 * @author JSR-31
 * @since JAXB1.0
 */
public class JAXBResult extends SAXResult {
  /** <p>Creates a new instance of <code>JAXBResult</code>.
   * The instance will use the specified {@link javax.xml.bind.JAXBContext}
   * to create an {@link javax.xml.bind.Unmarshaller}.</p>
   */
  public JAXBResult(javax.xml.bind.JAXBContext pContext) throws JAXBException {
    this(pContext.createUnmarshaller());
  }

  /** <p>Creates a new instance of <code>JAXBResult</code>.
   * The instance will use the given {@link javax.xml.bind.Unmarshaller}
   * to create a {@link org.xml.sax.ContentHandler}.</p>
   * <p>In most cases you will use the constructor taking a
   * {@link javax.xml.bind.JAXBContext} as input. This additional
   * constructor is required, if you want to configure the
   * {@link javax.xml.bind.Unmarshaller}.</p>
   * @param pUnmarshaller The Unmarshaller that may be queried for an
   *   {@link UnmarshallerHandler}.
   */
  public JAXBResult(javax.xml.bind.Unmarshaller pUnmarshaller) throws JAXBException {
    super(pUnmarshaller.getUnmarshallerHandler());
  }

  /** <p>Returns the result of a previous transformation.</p>
   */
  public Object getResult() throws JAXBException {
    return ((UnmarshallerHandler) super.getHandler()).getResult();
  }
}
