/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme;

import javax.xml.bind.JAXBException;

import javax.xml.bind.DatatypeConverterInterface;

import org.apache.ws.jaxme.impl.JAXBContextImpl;
import org.apache.ws.jaxme.util.NamespaceSupport;
import org.xml.sax.ContentHandler;


/** <p>A Handler is capable and used to unmarshal a certain
 * subclass of JMElement. It is unable to marshal generic JMElements.
 * The JMHandler is typically created by the Manager.</p>
 * <p>A JMHandler is reusable: If the sequence
 * <code>startDocument()</code>, ..., <code>endDocument()</code>
 * was executed, you can immediately perform the same sequence
 * again, effectively reading another document. If the sequence
 * was interrupted, you may also reset the handlers state by
 * calling its <code>init()</code> method.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JMHandler.java 231559 2003-09-23 12:37:47Z jochen $
 */
public interface JMHandler extends ContentHandler, Observable {
  public interface Data {
    /** <p>Returns the Unmarshaller controlling the unmarshalling
     * process.</p>
     */
    public JMUnmarshaller getUnmarshaller();

    /** <p>Returns the object factory used to create new objects.</p>
     */
    public JAXBContextImpl getFactory();

    /** <p>Returns a ContentHandler used to parse an elements contents.</p>
     */
    public JMHandler getAtomicHandler();

    /** <p>Returns the {@link javax.xml.bind.DatatypeConverterInterface}.</p>
     */
    public DatatypeConverterInterface getDatatypeConverter();

    /** <p>Returns the {@link javax.xml.namespace.NamespaceContext}.</p>
     */
    public NamespaceSupport getNamespaceContext();
  }

  /** <p>Initializes the handler by setting its Data.</p>
   * 
   * @param pData An instance of {@link Data} providing access to the
   *   handlers configuration..
   */
  public void init(Data pData) throws JAXBException;

  /** <p>Initializes the handler by creating a new Data instance
   * and calling <code>init(Data)</code>.</p>
   */
  public void init(JMUnmarshaller pUnmarshaller) throws JAXBException;

  /** <p>Returns the handlers Data.</p>
   */
  public Data getData();

  /** <p>Returns the handlers result object.</p>
   * 
   * @return Result object
   * @throws IllegalStateException If called before a full
   *   <code>startDocument()</code>, ..., </code>endDocument()</code>
   *   sequence.
   */
  public Object getResult();
}
