/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme;

import javax.xml.namespace.QName;

import org.apache.ws.jaxme.impl.JAXBContextImpl;


/** <p>A JMManager controls the object factory (aka JAXBContext)
 * for a given document type. The document type is both identified
 * by its QName and its interface, which is extending JMElement.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JMManager.java 231598 2003-10-20 20:32:43Z jochen $
 */
public interface JMManager {
  /** <p>Returns a property value, which is used to configure
   * the manager. The property value is set in the configuration
   * file.</p>
   *
   * @param pName The property name
   * @return pValue The property value; null, if the property is not
   *   set.
   */
  public String getProperty(String pName);

  /** <p>Returns the {@link org.apache.ws.jaxme.impl.JAXBContextImpl},
   * that created this manager.</p>
   */
  public JAXBContextImpl getFactory();

  /** <p>Returns the QName of the document type that this
   * Manager controls.</p>
   */
  public QName getQName();

  /** <p>Returns the interface matching the document type.
   * This must be a subinterface of JMElement.</p>
   */
  public Class getElementInterface();

  /** <p>Returns the implementation class of the interface
   * returned by <code>getElementInterface()</code>.</p>
   */
  public Class getElementClass();

  /** <p>Returns the document types handler class. This class
   * must be implementing JMHandler and it must be able to
   * convert the document type controlled by the manager into
   * objects implementing the element interface.</p>
   */
  public Class getHandlerClass();

  /** <p>Returns the document types marshaller class. This class
   * must be implementing JMXmlSerializer and it must be able
   * to convert objects implementing the element interface into
   * a stream of SAX events.</p>
   */
  public Class getMarshallerClass();

  /** <p>Returns the persistency class. The persistency class
   * must be able to store documents in a database, update,
   * delete or retrieve them.</p>
   */
  public Class getPmClass();
}
