/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003,2004 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme;

/** <p>List of error codes, being used in validation events.</p>
 * 
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: ValidationEvents.java 231705 2004-01-07 02:07:20Z jochen $
 */
public interface ValidationEvents {
  /** <p>A processing instruction was found. JaxMe doesn't know
   * how to handle processing instruction, thus they are treated
   * as a validation event, possibly throwing an exception.</p>
   * <p>This behaviour is questionable. It may very well be changed
   * at a later time, if another way of handling processing
   * instructions is defined. However, if we throw an event now,
   * the possible change is upwards compatible.</p>
   */
  public static final String EVENT_PROCESSING_INSTRUCTION = "JM_EVENT_PROCESSING_INSTRUCTION";

  /** <p>A skipped entity was found. JaxMe doesn't know
   * how to handle skipped entities, thus they are treated
   * as a validation event, possibly throwing an exception.</p>
   * <p>This behaviour is questionable. It may very well be changed
   * at a later time, if another way of handling skipped
   * entities is defined. However, if we throw an event now,
   * the possible change is upwards compatible.</p>
   */
  public static final String EVENT_SKIPPED_ENTITY = "JM_EVENT_SKIPPED_ENTITY";

  /** <p>Unexpected textual contents have been found. For example,
   * a sequence must not have embedded text, because it would have
   * mixed content otherwise. Textual content is ignored, if it
   * consists of whitespace characters only.</p>
   */
  public static final String EVENT_UNEXPECTED_TEXTUAL_CONTENTS = "JM_EVENT_UNEXPECTED_TEXTUAL_CONTENTS";

  /** <p>An unexpected child was found in an atomic element or in a
   * complex element with simple content.</p>
   */
  public static final String EVENT_UNEXPECTED_CHILD_ELEMENT = "JM_EVENT_UNEXPECTED_CHILD_ELEMENT";

  /** <p>A child element was not expected at this place. For example,
   * in the case of a choice, this may indicate that more than one
   * of the possible elements have been found. In the case of a
   * sequence, this can indicate a mismatch in the order of the
   * child elements.</p>
   */
  public static final String EVENT_UNEXPECTED_CHILD_STATE = "JM_EVENT_UNEXPECTED_CHILD_STATE";

  /** <p>A complex elements child is unknown. A possible reason
   * is an error in the child elements name.</p>
   */
  public static final String EVENT_ADDITIONAL_CHILD_ELEMENT = "JM_EVENT_ADDITIONAL_CHILD_ELEMENT";

  /** <p>An element occurred more than expected. In other words,
   * the elements <code>maxOccurs</code> facet was violated.</p>
   */
  public static final String EVENT_MULTIPLE_OCCURRENCIES = "JM_EVENT_MULTIPLE_OCCURRENCIES";

  /** <p>The root elements type was wrong.</p>
   */
  public static final String EVENT_WRONG_ROOT_ELEMENT = "JM_EVENT_WRONG_ROOT_ELEMENT";

  /** <p>An element or attribute value was invalid. For example, in the
   * case of a dateTime instance, this may indicate an unparseable date.</p>
   */
  public static final String EVENT_ILLEGAL_VALUE = "JM_EVENT_ILLEGAL_VALUE";

  /** <p>An attribute was unknown.</p>
   */
  public static final String EVENT_UNKNOWN_ATTRIBUTE = "JM_EVENT_UNKNOWN_ATTRIBUTE";

  /** <p>An attribute with an invalid namespace was detected in an
   * element with an "anyAttribute" declaration.</p>
   */
  public static final String EVENT_UNKNOWN_ANY_ATTRIBUTE = "JM_EVENT_UNKNOWN_ANY_ATTRIBUTE";
}
