/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator;

import java.io.File;
import java.net.URL;

import org.apache.ws.jaxme.generator.sg.SchemaSG;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;

/** <p>The Generator is a frontend for working with the
 * SchemaReaders, SourceWriters and whatever else.</p>
 * <p><em>Implementation note</em>: If you update this interface, you
 * should consider updating the following files and classes as
 * well:
 * <ul>
 *   <li>{@link Main}</li>
 *   <li>{@link XJCTask}</li>
 *   <li>docs/Reference.html</li>
 * </ul></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: Generator.java 231697 2003-12-27 22:10:40Z jochen $
 */
public interface Generator extends PropertySource {
  /** <p>Sets the SchemaReader to use.</p>
   */
  public void setSchemaReader(SchemaReader pSchemaReader);

  /** <p>Returns the SchemaReader being used.</p>
   */
  public SchemaReader getSchemaReader();

  /** <p>Sets the directory where to create files.</p>
   */
  public void setTargetDirectory(File pDirectory);

  /** <p>Returns the directory where to create files.</p>
   */
  public File getTargetDirectory();

  /** <p>Sets whether the generator is using a validating XML
   * schema parser. Defaults to false.</p>
   */
  public void setValidating(boolean pValidating);

  /** <p>Returns whether the generator is using a validating XML
   * schema parser. Defaults to false.</p>
   */
  public boolean isValidating();

  /** <p>Returns whether the generator is forcing an overwrite of files.</p>
   */
  public boolean isForcingOverwrite();

  /** <p>Sets whether the generator is forcing an overwrite of files.</p>
   */
  public void setForcingOverwrite(boolean pIsForcingOverwrite);

  /** <p>Returns whether the generator will create files in read-only mode.</p>
   */
  public boolean isSettingReadOnly();

  /** <p>Sets whether the generator will create files in read-only mode.</p>
   */
  public void setSettingReadOnly(boolean pIsSettingReadOnly);

  /** <p>Starts the Generator on the given File.</p>
   */
  public SchemaSG generate(File pFile) throws Exception;

  /** <p>Starts the Generator on the given URL.</p>
   */
  public SchemaSG generate(URL pURL) throws Exception;

  /** <p>Starts the Generator on the given Reader.</p>
   *
   * @param pSource A SAX Input Source, with the system ID set,
   *   if possible
   */
  public SchemaSG generate(InputSource pSource) throws Exception;

  /** <p>Returns a key for getting and setting custom data.</p>
   */
  public String getKey();

  /** <p>Sets the {@link EntityResolver} being used to import external
   * schemata.</p>
   */
  public void setEntityResolver(EntityResolver pEntityResolver);

  /** <p>Returns the {@link EntityResolver} being used to import external
   * schemata.</p>
   */
  public EntityResolver getEntityResolver();
}
