/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg;

import org.apache.ws.jaxme.js.DirectAccessible;
import org.apache.ws.jaxme.js.JavaSource;
import org.apache.ws.jaxme.xs.XSParticle;
import org.xml.sax.SAXException;


/** <p>Interface of a source generator for model groups.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface GroupSG extends SGItem {
  /** <p>Returns whether the group is global.</p>
   */
  public boolean isGlobal();

  /** <p>Returns whether the groups compositor is "all".</p>
   */
  public boolean isAll();

  /** <p>Returns whether the groups compositor is "choice".</p>
   */
  public boolean isChoice();

  /** <p>Returns whether the groups compositor is "sequence".</p>
   */
  public boolean isSequence();

  /** <p>Returns the groups {@link Context}.</p>
   */
  public Context getClassContext() throws SAXException;

  /** <p>Generates the groups interface.</p>
   */
  public JavaSource getXMLInterface() throws SAXException;

  /** <p>Generates the groups implementation.</p>
   */
  public JavaSource getXMLImplementation() throws SAXException;

  /** <p>Generates the groups set and get methods.</p>
   */
  public void generateProperties(JavaSource pSource) throws SAXException;

  /** <p>Generates the XML interfaces subclasses.</p>
   */
  public void generateXMLInterfaceSubclasses(JavaSource pSource) throws SAXException;

  /** <p>Generates the XML implementations subclasses.</p>
   */
  public void generateXMLImplementationSubclasses(JavaSource pSource) throws SAXException;

  /** <p>Generates the XML handlers methods for reading child elements.</p>
   */
  public void generateXMLHandlersElements(JavaSource pSource, DirectAccessible pLevelVar) throws SAXException;

  /** <p>Generates the XML serializers methods that create child elements.</p>
   */
  public void generateXMLSerializersElements(JavaSource pSource) throws SAXException;

  /** <p>Generates the groups sources.</p>
   */
  public void generate() throws SAXException;

  /** <p>Returns the groups particles.</p>
   */
  public ParticleSG[] getParticles();

  /** <p>Creates a new instance of
   * {@link org.apache.ws.jaxme.generator.sg.ParticleSGChain} generating the
   * given particle.</p>
   * <p><em>Implementation note</em>: The type
   * {@link org.apache.ws.jaxme.generator.sg.ParticleSGChain}
   * must not be exposed in the interface, because the interface
   * class is used to generate this type. In other words, this
   * interface must be compilable without the
   * {@link org.apache.ws.jaxme.generator.sg.ParticleSGChain}
   * interface.</p>
   */
  public Object newParticleSG(XSParticle pParticle) throws SAXException;
}
