/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg;

import org.apache.ws.jaxme.js.DirectAccessible;
import org.apache.ws.jaxme.js.JavaMethod;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface ParticleSG {
  /** <p>Initializes the ParticleSG.</p>
   */
  public void init() throws SAXException;

  /** <p>Returns the particles locator.</p>
   */
  public Locator getLocator();

  /** <p>Returns whether the pariticle is a group. If so, you may use the
   * {@link #getGroupSG()} method.</p>
   * @see #getGroupSG()
   */
  public boolean isGroup();

  /** <p>Returns whether the particle is an element. If so, you may use the
   * {@link #getObjectSG()} method.</p>
   * @see #getObjectSG()
   */
  public boolean isElement();

  /** <p>Returns whether the particle is a wildcard. If so, you may use the
   * {@link #getObjectSG()} method.</p>
   * @see #getObjectSG()
   */
  public boolean isWildcard();

  /** <p>If the particle is a group, returns the particles {@link GroupSG}.</p>
   * @throws IllegalStateException The particle is no group.
   * @see #isGroup()
   */
  public GroupSG getGroupSG();

  /** <p>If the particle is an element or wildcard, returns the particles {@link ObjectSG}.</p>
   * @throws IllegalStateException The particle is neither an element nor a wildcard
   * @see #isElement()
   * @see #isWildcard()
   */
  public ObjectSG getObjectSG();

  /** <p>Returns the particles minOccurs value.</p>
   * @see #getMaxOccurs()
   */
  public int getMinOccurs();

  /** <p>Returns the particles maxOccurs value; -1 indicated "unbounded".</p>
   * @see #isMultiple()
   * @see #getMinOccurs()
   */
  public int getMaxOccurs();

  /** <p>Returns whether the particles multiplicity is 2 or greater.</p>
   * @see #getMaxOccurs()
   */
  public boolean isMultiple();

  /** <p>Creates a new instance of {@link org.apache.ws.jaxme.generator.sg.PropertySGChain}.</p>
   */
  public Object newPropertySGChain();

  /** <p>Returns an instance of {@link org.apache.ws.jaxme.generator.sg.PropertySG}.</p>
   */
  public PropertySG getPropertySG();

  /** <p>Invokes the given {@link SGlet} for all non null values.</p>
   */
  public void forAllNonNullValues(JavaMethod pMethod, DirectAccessible pElement, SGlet pSGlet) throws SAXException;
}
