/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg;

import org.apache.ws.jaxme.js.DirectAccessible;
import org.apache.ws.jaxme.js.JavaField;
import org.apache.ws.jaxme.js.JavaMethod;
import org.apache.ws.jaxme.js.JavaQName;
import org.apache.ws.jaxme.js.JavaSource;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface PropertySG {
  /** <p>Initializes the <code>PropertySG</code>.</p>
   */
  public void init() throws SAXException;

  /** <p>Returns whether the property has an "is set" method.</p>
   */
  public boolean hasIsSetMethod();

  /** <p>Returns the properties collection type.</p>
   */
  public String getCollectionType();

  /** <p>Returns the objects property name.</p>
   */
  public String getXMLFieldName() throws SAXException;

  /** <p>Returns the objects getter name.</p>
   */
  public String getXMLGetMethodName() throws SAXException;

  /** <p>Returns the objects setter name.</p>
   */
  public String getXMLSetMethodName() throws SAXException;

  /** <p>Returns the name of the objects "isSet" method.</p>
   */
  public String getXMLIsSetMethodName() throws SAXException;

  /** <p>Creates the Java field holding the objects property value.</p>
   */
  public JavaField getXMLField(JavaSource pSource) throws SAXException;

  /** <p>Creates the getter returning the property value.</p>
   */
  public JavaMethod getXMLGetMethod(JavaSource pSource) throws SAXException;

  /** <p>Creates the setter returning the property value.</p>
   */
  public JavaMethod getXMLSetMethod(JavaSource pSource) throws SAXException;

  /** <p>Creates the isSet returning whether the property value is set or not.</p>
   */
  public JavaMethod getXMLIsSetMethod(JavaSource pSource) throws SAXException;

  /** <p>Returns a piece of Java code with the property value.</p>
   * @param pElement The element on which the value is being set or null for "this".
   */
  public Object getValue(DirectAccessible pElement) throws SAXException;

  /** <p>Creates a piece of Java code setting the elements property value.
   * In the case of an element with multiplicity > 1, the object must be
   * a list or an array.</p>
   *
   * @param pMethod The method being generated.
   * @param pElement The element on which the value is being set or null for "this".
   * @param pType The values type, if a cast is required, or null, if the value
   *   is already casted.
   */
  public void setValue(JavaMethod pMethod, DirectAccessible pElement, Object pValue, JavaQName pType)
    throws SAXException;

  /** <p>Creates a piece of Java code adding an element value. In the case
   * of an element with multiplicity > 1, the object must be the atomic
   * value.</p>
   * @param pElement The element on which the value is being set or null for "this".
   * @param pType The values type, if a cast is required, or null, if the value
   *   is already casted.
   */
  public void addValue(JavaMethod pMethod, DirectAccessible pElement, Object pValue, JavaQName pType)
    throws SAXException;

  /** <p>Invokes the given {@link org.apache.ws.jaxme.generator.sg.SGlet}
   * for any value.</p>
   * @param pElement The element on which the value is being set or null for "this".
   */
  public void forAllValues(JavaMethod pMethod, DirectAccessible pElement, SGlet pSGlet) throws SAXException;

  /** <p>Invokes the given {@link org.apache.ws.jaxme.generator.sg.SGlet}
   * for any non null value.</p>
   * @param pElement The element on which the value is being set or null for "this".
   */
  public void forAllNonNullValues(JavaMethod pMethod, DirectAccessible pElement, SGlet pSGlet) throws SAXException;

  /** <p>Generates the property setters and getters.</p>
   */
  public void generate(JavaSource pSource) throws SAXException;
}
