/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg;

import java.util.List;

import org.apache.ws.jaxme.js.JavaSourceFactory;
import org.apache.ws.jaxme.xs.jaxb.JAXBJavaType;
import org.apache.ws.jaxme.xs.xml.XsQName;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;


/** <p>Interface of a source generator for the whole schema.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface SchemaSG extends SGItem {
  /** <p>Returns the schemas global types.</p>
   */
  public TypeSG[] getTypes() throws SAXException;

  /** <p>Returns the schemas global type with the given name or
   * null, if no such type exists.</p>
   */
  public TypeSG getType(XsQName pName) throws SAXException;

  /** <p>Returns the schemas model groups.</p>
   */
  public GroupSG[] getGroups() throws SAXException;

  /** <p>Returns the schemas global group with the given name or
   * null, if no such type exists.</p>
   */
  public GroupSG getGroup(XsQName pName) throws SAXException;

  /** <p>Returns the schemas global attributes and elements.</p>
   */
  public ObjectSG[] getObjects() throws SAXException;

  /** <p>Returns the schemas global element with the given name or
   * null, if no such element exists.</p>
   */
  public ObjectSG getElement(XsQName pName) throws SAXException;

  /** <p>Returns the schemas global elements.</p>
   */
  public ObjectSG[] getElements() throws SAXException;

  /** <p>Returns the schemas collection type, as specified by the
   * JAXB globalBindings tag.</p>
   */
  public String getCollectionType();

  /** <p>Returns the schemas {@link org.apache.ws.jaxme.js.JavaSourceFactory}.</p>
   */
  public JavaSourceFactory getJavaSourceFactory();

  /** <p>Performs the source generation.</p>
   */
  public void generate() throws SAXException;

  /** <p>Returns whether the schema prefers model group binding style or not.
   * Defaults to false.</p>
   */
  public boolean isBindingStyleModelGroup();

  /** <p>Returns whether the value "choiceContentProperty" is enabled.
   * Defaults to false.</p>
   */
  public boolean isChoiceContentProperty();

  /** <p>Returns whether the property "enableFailFastCheck" is enabled.
   * Defaults to false.</p>
   */
  public boolean isFailFastCheckEnabled();

  /** <p>Returns whether the property "enableJavaConventions" is enabled.
   * Defaults to true.</p>
   */
  public boolean isJavaNamingConventionsEnabled();

  /** <p>Returns whether the property "isFixedAttributeConstantProperty" is
   * enabled. Defaults to false.</p>
   */
  public boolean isFixedAttributeConstantProperty();

  /** <p>Returns whether the property "generateIsSetMethod" is enabled.
   * Defaults to false.</p>
   */
  public boolean isGeneratingIsSetMethod();

  /** <p>Returns whether the property "underscoreBinding" has the value
   * "asWordSeparator". Defaults to true.</p>
   */
  public boolean isUnderscoreWordSeparator();

  /** <p>Returns the globally configured instances of {@link JAXBJavaType}.</p>
   */
  public JAXBJavaType[] getJAXBJavaTypes();

  /** <p>Returns the globally configured value for <code>typesafeenumbase</code>.</p>
   */
  public XsQName[] getTypesafeEnumBase();

  /** <p>Generates the "Configuration.xml" file as a DOM node. Event
   * handlers may modify the DOM node.</p>
   * @param pPackageName The package, for which a configuration is being generated.
   * @param pContextList A list of objects generated in the package.
   */
  public Document getConfigFile(String pPackageName, List pContextList) throws SAXException;

  /** <p>Creates the "jaxb.properties" file.</p>
   */
  public void generateJaxbProperties() throws SAXException;
}
