/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg.impl;

import org.apache.ws.jaxme.generator.sg.SchemaSG;
import org.apache.ws.jaxme.js.JavaQName;
import org.apache.ws.jaxme.js.JavaQNameImpl;
import org.apache.ws.jaxme.xs.XSObject;
import org.apache.ws.jaxme.xs.XSType;
import org.apache.ws.jaxme.xs.jaxb.JAXBClass;
import org.apache.ws.jaxme.xs.jaxb.JAXBClassOwner;
import org.apache.ws.jaxme.xs.jaxb.JAXBSchemaBindings;
import org.apache.ws.jaxme.xs.xml.XsQName;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class GlobalContext extends AbstractContext {
	/** <p>Creates a new, global class context.</p>
	 */
	public GlobalContext(XsQName pQName, XSObject pJAXBClassOwner,
						 String pPrefix, String pSuffix, SchemaSG pSchemaSG)
			throws SAXException {
		Locator locator;
		if (pJAXBClassOwner instanceof XSType) {
			XSType type = (XSType) pJAXBClassOwner;
			if (type.isBuiltin()) {
				locator = null;
			} else {
				locator = type.getLocator();
			}
		} else {
			locator = pJAXBClassOwner.getLocator();
		}

		if (pQName == null) {
			throw new NullPointerException("The XsQName argument must not be null.");
		}
		setName(pQName);
		if (pJAXBClassOwner == null) {
			throw new NullPointerException("The XSObject argument must not be null.");
		}
		
		JAXBClassOwner jaxbClassOwner = null;
		JAXBSchemaBindings schemaBindings = null;
		
		if (pJAXBClassOwner instanceof JAXBClassOwner) {
			jaxbClassOwner = (JAXBClassOwner) pJAXBClassOwner;
			schemaBindings = jaxbClassOwner.getJAXBSchemaBindings();
		}
		
		String packageName = pSchemaSG.getFactory().getGenerator().getProperty("jaxme.package.name");
		if (packageName == null) {
			if (schemaBindings != null) {
				JAXBSchemaBindings.Package jaxbPackage = schemaBindings.getPackage();
				if (jaxbPackage != null) {
					packageName = jaxbPackage.getName();
				}
			}
		}

		if (packageName == null) {
			packageName = getPackageNameFromURI(locator, pQName.getNamespaceURI());
		} 
		
		String className = null, implementationName = null;
		JAXBClass jaxbClass = (jaxbClassOwner == null) ? null : jaxbClassOwner.getJAXBClass();
		if (jaxbClass != null) {
			className = jaxbClass.getName();
			implementationName = jaxbClass.getImplClass();
		}
		
		if (className == null) {
			String prefix = null, suffix = null;
			className = getClassNameFromLocalName(locator, pQName.getLocalName(), pSchemaSG);
			if (prefix == null) { prefix = pPrefix; }
			if (prefix != null) className = prefix + className;
			if (suffix == null) { suffix = pSuffix; }
			if (suffix != null) className += suffix;
		}
		if (className.equals("EmailDetailsType")) {
			throw new IllegalStateException();
		}
		
		JavaQName xmlInterfaceName = JavaQNameImpl.getInstance(packageName, className);
		setXMLInterfaceName(xmlInterfaceName);
		
		if (implementationName == null) {
			setXMLImplementationName(JavaQNameImpl.getInstance(xmlInterfaceName.getPackageName() + ".impl",
					xmlInterfaceName.getClassName() + "Impl"));
		} else {
			setXMLImplementationName(JavaQNameImpl.getInstance(implementationName, true));
		}
		setXMLHandlerName(JavaQNameImpl.getInstance(xmlInterfaceName.getPackageName() + ".impl",
				xmlInterfaceName.getClassName() + "Handler"));
		setXMLSerializerName(JavaQNameImpl.getInstance(xmlInterfaceName.getPackageName() + ".impl",
				xmlInterfaceName.getClassName() + "Serializer"));
		setXMLValidatorName(JavaQNameImpl.getInstance(xmlInterfaceName.getPackageName() + ".impl",
				xmlInterfaceName.getClassName() + "Validator"));
		setPMName(JavaQNameImpl.getInstance(xmlInterfaceName.getPackageName() + ".impl",
				xmlInterfaceName.getClassName() + "PM"));
	}
	
	public boolean isGlobal() { return true; }
}
