/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003,2004 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg.impl;

import org.apache.ws.jaxme.generator.sg.AttributeSG;
import org.apache.ws.jaxme.generator.sg.AttributeSGChain;
import org.apache.ws.jaxme.generator.sg.Context;
import org.apache.ws.jaxme.generator.sg.PropertySG;
import org.apache.ws.jaxme.generator.sg.PropertySGChain;
import org.apache.ws.jaxme.generator.sg.SGFactory;
import org.apache.ws.jaxme.generator.sg.SGlet;
import org.apache.ws.jaxme.generator.sg.SchemaSG;
import org.apache.ws.jaxme.generator.sg.TypeSG;
import org.apache.ws.jaxme.js.DirectAccessible;
import org.apache.ws.jaxme.js.JavaMethod;
import org.apache.ws.jaxme.xs.XSAttribute;
import org.apache.ws.jaxme.xs.XSWildcard;
import org.apache.ws.jaxme.xs.xml.XsNamespaceList;
import org.apache.ws.jaxme.xs.xml.XsQName;
import org.apache.ws.jaxme.xs.xml.XsTWildcard;
import org.apache.ws.jaxme.xs.xml.XsTWildcard.ProcessContents;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
class JAXBAttributeSG extends JAXBSGItem implements AttributeSGChain {
	private final boolean isRequired, isWildcard;
	private final XsQName name;
	private final XsNamespaceList namespaceList;
	private final XsTWildcard.ProcessContents processContents;
	private XSAttribute xsAttribute;
	private XSWildcard xsWildcard;
	private final TypeSG typeSG;
	private PropertySG propertySG;
	
	
	protected JAXBAttributeSG(SchemaSG pSchema, XSAttribute pAttribute, Context pClassContext) throws SAXException {
		super(pSchema.getFactory(), pSchema, pAttribute);
		xsAttribute = pAttribute;
		xsWildcard = null;
		isRequired = !pAttribute.isOptional();
		name = pAttribute.getName();
		typeSG = getFactory().getTypeSG(pAttribute.getType(), pClassContext, name);
		isWildcard = false;
		namespaceList = null;
		processContents = null;
	}
	
	protected JAXBAttributeSG(SchemaSG pSchema, XSWildcard pWildcard, Context pClassContext) throws SAXException {
		super(pSchema.getFactory(), pSchema, pWildcard);
		xsWildcard = pWildcard;
		xsAttribute = null;
		isRequired = false;
		name = null;
		typeSG = null;
		isWildcard = true;
		namespaceList = pWildcard.getNamespaceList();
		processContents = pWildcard.getProcessContents();
	}
	
	public Object newPropertySGChain(AttributeSG pController) {
		PropertySGChain result;
		if (xsWildcard != null) {
			result = new AnyAttributePropertySG(pController, xsWildcard);
			xsWildcard = null;
		} else if (xsAttribute != null) {
			result = new JAXBPropertySG(pController, xsAttribute);
			xsAttribute = null;  // Make this available for garbage collection
		} else {
			throw new IllegalStateException("PropertySG is already created.");
		}
		return result;
	}
	
	public void init(AttributeSG pController) throws SAXException {
		PropertySGChain chain = (PropertySGChain) pController.newPropertySGChain();
		propertySG = new PropertySGImpl(chain);
		propertySG.init();
	}
	
	public PropertySG getPropertySG(AttributeSG pController) { return propertySG; }
	public TypeSG getTypeSG(AttributeSG pController) { return typeSG; }
	public SGFactory getFactory(AttributeSG pController) { return getFactory(); }
	public SchemaSG getSchema(AttributeSG pController) { return getSchema(); }
	public Locator getLocator(AttributeSG pController) { return getLocator(); }
	public XsQName getName(AttributeSG pController) { return name; }
	
	public boolean isRequired(AttributeSG pAttrController) { return isRequired; }
	public boolean hasIsSetMethod(AttributeSG pController) {
		return false;
	}
	
	public void forAllValues(AttributeSG pController, JavaMethod pMethod,
							 DirectAccessible pElement, SGlet pSGlet) throws SAXException {
		pController.getPropertySG().forAllValues(pMethod, pElement, pSGlet);
	}
	
	public void forAllNonNullValues(AttributeSG pController, JavaMethod pMethod,
									DirectAccessible pElement, SGlet pSGlet) throws SAXException {
		pController.getPropertySG().forAllNonNullValues(pMethod, pElement, pSGlet);
	}

	public boolean isWildcard(AttributeSG pController) {
		return isWildcard;
	}

	public XsNamespaceList getNamespaceList(AttributeSG pController) {
		return namespaceList;
	}

	public ProcessContents getProcessContents(AttributeSG pController) {
		return processContents;
	}
}
