/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.sg.impl;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.List;

import org.apache.ws.jaxme.generator.Generator;
import org.apache.ws.jaxme.xs.jaxb.impl.JAXBAppinfoImpl;
import org.apache.ws.jaxme.xs.jaxb.impl.JAXBXsObjectFactoryImpl;
import org.apache.ws.jaxme.xs.xml.XsEAppinfo;
import org.apache.ws.jaxme.xs.xml.XsObject;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class JaxMeSGFactory extends JAXBSGFactory {
  public class JaxMeAppinfoImpl extends JAXBAppinfoImpl {
    JaxMeAppinfoImpl(XsObject pParent) {
      super(pParent);
    }

    public ContentHandler getChildHandler(String pQName, String pNamespaceURI, String pLocalName) throws SAXException {
      List myAnnotationClasses = getAnnotationClasses();
      for (int i = 0;  i < myAnnotationClasses.size();  i +=3) {
        if (((String) myAnnotationClasses.get(i)).equals(pNamespaceURI)  &&
            ((String) myAnnotationClasses.get(i+1)).equals(pLocalName)) {
          Class c = (Class) myAnnotationClasses.get(i+2);
          Object o;
          try {
            Constructor con = c.getConstructor(new Class[]{JaxMeXsObjectFactory.class, Locator.class});
            o = con.newInstance(new Object[]{this, getLocator()});
          } catch (NoSuchMethodException e) {
            throw new SAXException("Invalid appinfo class " + c.getClass().getName() +
                                    ": Doesn't have a constructor taking the arguments " +
                                    JaxMeXsObjectFactory.class.getName() + " and " +
                                    Locator.class.getName());
          } catch (InvocationTargetException e) {
            Throwable t = e.getTargetException();
            String msg = "Failed to create appinfo element of class " + c.getClass().getName() +
                         ": " + t.getClass().getName() + ", " + t.getMessage();
            if (t instanceof Exception) {
              throw new SAXException(msg, (Exception) t);
            } else {
              throw new SAXException(msg, e);
            }
          } catch (Exception e) {
            throw new SAXException("Failed to create appinfo element of class " + c.getClass().getName() +
                                    ": " + e.getClass().getName());
          }
          return getObjectFactory().newXsSAXParser(o);
        }
      }
      return super.getChildHandler(pQName, pNamespaceURI, pLocalName);
    }
  }

  public class JaxMeXsObjectFactory extends JAXBXsObjectFactoryImpl {
    public XsEAppinfo newXsEAppinfo(XsObject pParent) {
      return new JaxMeAppinfoImpl(pParent);
    }
  }

  public JaxMeSGFactory(Generator pGenerator) {
    super(pGenerator);
  }

  private List annotationClasses = new ArrayList();
  protected List getAnnotationClasses() {
    return annotationClasses;
  }

  public void addAnnotationClass(String pNamespaceURI, String pLocalName, Class pClass) {
    if (pNamespaceURI == null  ||  pNamespaceURI.length() == 0) {
      throw new NullPointerException("A nonempty namespace URI must be given.");
    }
    if (pLocalName == null  ||  pLocalName.length() == 0) {
      throw new NullPointerException("A nonempty local name must be given.");
    }
    if (pClass == null) {
      throw new NullPointerException("An annotation class must be given.");
    }
    annotationClasses.add(pNamespaceURI);
    annotationClasses.add(pLocalName);
    annotationClasses.add(pClass);
  }
}
