/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.types;

import org.apache.ws.jaxme.generator.sg.AtomicTypeSG;
import org.apache.ws.jaxme.generator.sg.Facet;
import org.apache.ws.jaxme.generator.sg.ListTypeSG;
import org.apache.ws.jaxme.generator.sg.SGFactory;
import org.apache.ws.jaxme.generator.sg.SchemaSG;
import org.apache.ws.jaxme.generator.sg.SimpleTypeSG;
import org.apache.ws.jaxme.generator.sg.SimpleTypeSGChain;
import org.apache.ws.jaxme.generator.sg.UnionTypeSG;
import org.apache.ws.jaxme.generator.sg.impl.JAXBSGItem;
import org.apache.ws.jaxme.js.DirectAccessible;
import org.apache.ws.jaxme.js.JavaMethod;
import org.apache.ws.jaxme.js.JavaQNameImpl;
import org.apache.ws.jaxme.js.JavaSource;
import org.apache.ws.jaxme.xs.XSType;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public abstract class SimpleTypeSGImpl extends JAXBSGItem implements SimpleTypeSGChain {
  private boolean isNullable;

  /** <p>Creates a new instance of SimpleTypeSGImpl.</p>
   */
  protected SimpleTypeSGImpl(SGFactory pFactory, SchemaSG pSchema, XSType pType) throws SAXException {
    super(pFactory, pSchema, pType);
    if (!pType.isSimple()) {
      throw new IllegalStateException("The given type is complex.");
    }
  }

  protected XSType getXSType() { return (XSType) super.getXSObject(); }
  public SGFactory getFactory(SimpleTypeSG pController) { return getFactory(); }
  public SchemaSG getSchema(SimpleTypeSG pController) { return getSchema(); }
  public Locator getLocator(SimpleTypeSG pController) { return getLocator(); }
  public boolean isAtomic(SimpleTypeSG pController) { return false; }
  public boolean isList(SimpleTypeSG pController) { return false; }
  public boolean isUnion(SimpleTypeSG pController) { return false; }
  public boolean hasSetMethod(SimpleTypeSG pController) { return true; }
  public void setNullable(SimpleTypeSG pController, boolean pNullable) { isNullable = pNullable; }
  public boolean isNullable(SimpleTypeSG pController) { return isNullable; }

  public void init(SimpleTypeSG pController) throws SAXException {
  }

  public String getCollectionType(SimpleTypeSG pController) {
    return getSchema().getCollectionType();
  }

  public UnionTypeSG getUnionType(SimpleTypeSG pController) {
    throw new IllegalStateException("This type is no union.");
  }

  public ListTypeSG getListType(SimpleTypeSG pController) {
    throw new IllegalStateException("This type is no list.");
  }

  public AtomicTypeSG getAtomicType(SimpleTypeSG pController) {
    throw new IllegalStateException("This type is not atomic.");
  }

  public Facet[] getFacets(SimpleTypeSG pController) {
    return new Facet[0];
  }

  public Facet getFacet(SimpleTypeSG pController, Facet.Type pType) {
    Facet[] facets = pController.getFacets();
    for (int i = 0;  i < facets.length;  i++) {
      Facet f = facets[i];
      if (f.getType().equals(pType)) {
        return f;
      }
    }
    return null;
  }

  public void generate(SimpleTypeSG pController) {
  }

  public void generate(SimpleTypeSG pController, JavaSource pSource) {
  }

  public Object getInitialValue(SimpleTypeSG pController, JavaSource pSource) throws SAXException {
    return null;
  }

  public JavaMethod getXMLSetMethod(SimpleTypeSG pController, JavaSource pSource,
                                     String pFieldName, String pMethodName) throws SAXException {
    if (pController.hasSetMethod()) {
      String pName = "p" + Character.toUpperCase(pFieldName.charAt(0)) + pFieldName.substring(1);
      JavaMethod jm = pSource.newJavaMethod(pMethodName, JavaQNameImpl.VOID, JavaSource.PUBLIC);
      DirectAccessible param = jm.addParam(pController.getRuntimeType(), pName);
      if (!pSource.isInterface()) {
        pController.addValidation(jm, param);
        jm.addLine(pFieldName, " = ", param, ";");
      }
      return jm;
    } else {
      return null;
    }                                 
  }

  public void addValidation(SimpleTypeSG pController, JavaMethod pMethod, DirectAccessible pValue) throws SAXException {
  }
}
