/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.util;

import org.apache.ws.jaxme.generator.sg.SchemaSG;


/**
 * @author <a href="mailto:iasandcb@tmax.co.kr">Ias</a>
 */
public class JavaNamer {
  
  /** punctuation characters defined in JAXB spec */
  public static final char[] PUNCTUATION_CHARS = {'-', '.', ':', '_', '\u00B7', '\u0387', '\u06DD', '\u06DE'};

  /**
   * Check whether the given character is a punctuation one or not.
   * 
   * @param c character to check out
   * @param pSchema hint for handling underscore
   * @return true if c belongs to the punctuation characters, otherwise false.
   */
  public static boolean isPunctuationCharacter(char c, SchemaSG pSchema) {
    for (int i = 0; i < PUNCTUATION_CHARS.length; i++) {
      char pc = PUNCTUATION_CHARS[i];
      if (pc == '_') {
        if (!pSchema.isUnderscoreWordSeparator()) {
          continue;
        }
      }
      if (c == pc) {
        return true;
      }
    }
    return false;
  }

  /**
   * Convert a local part name in XML to a class or field name in Java.
   * 
   * @param pLocalName a given local name
   * @param pSchema hint for following Java naming conventions and handling underscore
   * @return the converted name based on the given hints.
   */
  
  public static String convert(String pLocalName, SchemaSG pSchema) {
    if (!pSchema.isJavaNamingConventionsEnabled()) {
      return pLocalName;
    }
    StringBuffer result = new StringBuffer();
    char c = pLocalName.charAt(0);
    if (Character.isJavaIdentifierStart(c)) {
      result.append(Character.toUpperCase(c));
    } else {
      result.append('_');
    }
    for (int i = 1;  i < pLocalName.length();  i++) {
      c = pLocalName.charAt(i);
      if (Character.isJavaIdentifierPart(c) && (c != '_')) {
        result.append(c);
      } else {
        if (isPunctuationCharacter(c, pSchema)) {
          i++;
          c = pLocalName.charAt(i);
          result.append(Character.toUpperCase(c));
        } else {
          result.append('_');
        }
      }
    }
    return result.toString();
  }
}
