/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.generator.util;

import java.util.Comparator;

import javax.xml.namespace.QName;

import org.apache.ws.jaxme.generator.QNameOwner;



/** <p>Used for sorting arrays or lists of QNameOwner's.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: QNameComparator.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class QNameComparator implements Comparator {
  private static final QNameComparator theInstance = new QNameComparator();

  protected QNameComparator() {}

  public static QNameComparator getInstance() { return theInstance; }

  /** <p>Compares two instances of <code>QNameOwner</code> by
   * calling their <code>getQName()</code> method.</p>
   * 
   * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
   * @see org.apache.ws.jaxme.generator.QNameOwner#getQName()
   */
  public int compare(Object o1, Object o2) {
    if (o1 == null) {
      return o2 == null ? 0 : -1;
    }
    if (o2 == null) {
      return 1;
    }
    QNameOwner qo1 = (QNameOwner) o1;
    QNameOwner qo2 = (QNameOwner) o2;
    QName n1 = qo1.getQName();
    QName n2 = qo2.getQName();
    if (n1 == null) {
      return n2 == null ? 0 : -1;
    }
    if (n2 == null) {
      return 1;
    }
    String s1 = n1.getNamespaceURI();
    String s2 = n2.getNamespaceURI();
    if (s1 == null) { s1 = ""; }
    if (s2 == null) { s2 = ""; }
    int result = s1.compareTo(s2);
    if (result == 0) {
      result = n1.getLocalPart().compareTo(n2.getLocalPart());
    }
    return result;
  }

}
