/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003,2004 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.impl;

import javax.xml.bind.ValidationEvent;

import org.apache.ws.jaxme.ValidationEvents;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JMHandlerImpl.java 231705 2004-01-07 02:07:20Z jochen $
 */
public abstract class JMHandlerImpl extends JMHandlerBase {
  private Object result;

  /** <p>Sets the result object.</p>
   */
  public void setResult(Object pResult) {
    result = pResult;
  }

  public Object getResult() {
    return result;
  }

  public void ignorableWhitespace(char[] ch, int start, int length)
    throws SAXException {
  }

  public void addAttribute(String pNamespaceURI, String pLocalName,
                            String pValue) throws SAXException {
      validationEvent(ValidationEvent.ERROR,
                      "Unknown attribute: '" + pLocalName + "' in namespace '" +
                      pNamespaceURI + "'",
                      ValidationEvents.EVENT_UNKNOWN_ATTRIBUTE);
  }

  public void startElement(String pNamespaceURI, String pLocalName,
                            String pQName, Attributes pAttr) throws SAXException {
    validationEvent(ValidationEvent.WARNING,
                    "Unexpected element: '" + pQName + "'",
                    ValidationEvents.EVENT_UNEXPECTED_CHILD_ELEMENT);
  }

  public void characters(char[] pChars, int pOffset, int pLen) throws SAXException {
    for (int i = 0;  i < pLen;  i++) {
      if (!Character.isWhitespace(pChars[pOffset+i])) {
        validationEvent(ValidationEvent.WARNING, "Unexpected non-whitespace characters: '" +
                        new String(pChars, pOffset, pLen) + "'",
                        ValidationEvents.EVENT_UNEXPECTED_TEXTUAL_CONTENTS);
      }
    }
  }

  public void endElement(String pNamespaceURI, String pLocalName,
                          String pQName) throws SAXException {
    validationEvent(ValidationEvent.WARNING,
                    "Unexpected element: '" + pQName + "'",
                    ValidationEvents.EVENT_UNEXPECTED_CHILD_ELEMENT);
  }
}
