/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.impl;

import javax.xml.bind.DatatypeConverterInterface;
import javax.xml.bind.JAXBException;
import javax.xml.namespace.QName;

import org.apache.ws.jaxme.JMMarshaller;
import org.apache.ws.jaxme.JMXmlSerializer;
import org.apache.ws.jaxme.util.NamespaceSupport;
import org.xml.sax.Attributes;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.AttributesImpl;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JMXmlSerializerImpl.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class JMXmlSerializerImpl implements JMXmlSerializer {
  private static final Attributes zeroAttributes = new AttributesImpl();

  protected class Data implements JMXmlSerializer.Data {
    private int cnt;
    private JMMarshaller marshaller;
    private ContentHandler handler;
    private NamespaceSupport nss = new NamespaceSupport();

    protected Data(JMMarshaller pMarshaller, ContentHandler pHandler) {
      marshaller = pMarshaller;
      handler = pHandler;
    }

    public JMMarshaller getJMMarshaller() { return marshaller; }
    public ContentHandler getContentHandler() { return handler; }
    public NamespaceSupport getNamespaceSupport() { return nss; }
    public DatatypeConverterInterface getDatatypeConverter() { return getJMMarshaller().getDatatypeConverter(); }
    public JMXmlSerializer getJMXmlSerializer() {
      return JMXmlSerializerImpl.this;
    }
    public String getNewPrefix(String pURI, String pSuggestedPrefix) {
      if (pSuggestedPrefix == null  ||  pSuggestedPrefix.length() == 0) {
        if (!nss.isPrefixDeclared("")) {
          nss.declarePrefix("", pURI);
          return "";
        }
        pSuggestedPrefix = "p";
      }
      String pc = pSuggestedPrefix;
      for (;;) {
        if (!nss.isPrefixDeclared(pc)) {
          nss.declarePrefix(pc, pURI);
          return pc;
        }
        pc = pSuggestedPrefix + ++cnt;
      }
    }
  }

  public void init(JAXBContextImpl pFactory) throws JAXBException {}

  public String getPreferredPrefix(String pURI) {
    return null;
  }

  public JMXmlSerializer.Data getData(JMMarshaller pMarshaller, ContentHandler pHandler) {
    return new Data(pMarshaller, pHandler);
  }

  protected AttributesImpl getAttributes(JMXmlSerializer.Data pData,
                                          Object pElement) throws SAXException {
    return new AttributesImpl();
  }

  protected String getAttributeQName(JMXmlSerializer.Data pData, String pURI, String pLocalName)
      throws SAXException {
    NamespaceSupport nss = pData.getNamespaceSupport();
    String prefix = nss.getAttributePrefix(pURI);
    if (prefix == null) {
      String preferredPrefix = getPreferredPrefix(pURI);
      if (preferredPrefix == null  ||  preferredPrefix.length() == 0) {
        preferredPrefix = "p";
      }
      prefix = pData.getNewPrefix(pURI, preferredPrefix);
      pData.getContentHandler().startPrefixMapping(prefix, pURI);
    }
    if (prefix.length() == 0) {
      return pLocalName;
    } else {
      return prefix + ":" + pLocalName;
    }
  }

  protected String getElementQName(JMXmlSerializer.Data pData, String pURI,
                             String pLocalName) throws SAXException {
    NamespaceSupport nss = pData.getNamespaceSupport();
    String prefix = nss.getPrefix(pURI);
    if (prefix == null) {
      prefix = pData.getNewPrefix(pURI, getPreferredPrefix(pURI));
      pData.getContentHandler().startPrefixMapping(prefix, pURI);
    }
    if (prefix.length() == 0) {
      return pLocalName;
    } else {
      return prefix + ":" + pLocalName;
    }
  }

  protected void marshalChilds(JMXmlSerializer.Data pData, Object pElement)
      throws SAXException {
  }

  protected void marshalAtomicChild(JMXmlSerializer.Data pData,
                                      QName pQName,
                                      String pValue)
      throws SAXException {
    ContentHandler handler = pData.getContentHandler();
    String uri = pQName.getNamespaceURI();
    String localName = pQName.getLocalPart();
    String qName = getElementQName(pData, uri, localName);
    handler.startElement(uri, localName, qName, zeroAttributes);
    handler.characters(pValue.toCharArray(), 0, pValue.length());
    handler.endElement(uri, localName, qName);
  }

  protected void marshalAtomicChild(JMXmlSerializer.Data pData,
                                      String pNamespaceURI,
                                      String pLocalName,
                                      String pValue)
      throws SAXException {
    ContentHandler handler = pData.getContentHandler();
    String qName = getElementQName(pData, pNamespaceURI, pLocalName);
    handler.startElement(pNamespaceURI, pLocalName, qName, zeroAttributes);
    handler.characters(pValue.toCharArray(), 0, pValue.length());
    handler.endElement(pNamespaceURI, pLocalName, qName);
  }

  public void marshal(JMXmlSerializer.Data pData, QName pName, Object pElement)
      throws SAXException {
    NamespaceSupport nss = pData.getNamespaceSupport();
    int context = nss.getContext();
    ContentHandler handler = pData.getContentHandler();
    String uri = pName.getNamespaceURI();
    if (uri == null) uri = "";
    String name = pName.getLocalPart();
    String qName = getElementQName(pData, uri, name);
    handler.startElement(uri, name, qName,
                         getAttributes(pData, pElement));
    marshalChilds(pData, pElement);
    handler.endElement(uri, name, qName);
    for (;;) {
      String prefix = nss.setContext(context);
      if (prefix == null) {
        break;
      }
      handler.endPrefixMapping(prefix);
    }
  }
}
