/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.junit;

import junit.framework.TestCase;


/** <p>A base class for JUnit tests.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: BaseTestCase.java 231599 2003-10-21 16:44:37Z jochen $
 */
public abstract class BaseTestCase extends TestCase {
  public BaseTestCase(String pName) {
    super(pName);
  }

  public BaseTestCase(Class c) {
    this(c.getName());
  }

  // Asserts equality of the two given strings.
  protected void assertStringEquals(String pExpect, String pGot) {
    if (pExpect == null  ||  pGot == null) {
      if (pExpect == null  &&  pGot == null) {
        return;
      }
      if (pExpect == null) {
        fail("Expected null, got <" + pGot + ">");
      } else {
        fail("Expected <" + pExpect + ">, got null");
      }
    }
    if (pExpect.equals(pGot)) {
      return;
    }
    int l1 = pExpect.length();
    int l2 = pGot.length();
    int l = (l1 > l2) ? l2 : l1;
    int offset = 0;
    for (int i = 0;  i < l;  i++) {
      if (pExpect.charAt(i) != pGot.charAt(i)) {
        break;
      }
      offset = i;
    }
    fail("Expected <" + pExpect + "> (length " + l1 + "), got <" + pGot +
         "> (length " + l2 + "), difference at offset " + offset);
  }

  // Asserts equality of the two given byte arrays.
  protected void assertEquals(byte[] pExpect, byte[] pGot) {
    if (pExpect.length != pGot.length) {
      fail("Expected " + pExpect.length + " bytes, got " + pGot.length);
    } else {
      for (int i = 0;  i < pExpect.length;  i++) {
        if (pExpect[i] != pGot[i]) {
          fail("Expected byte " + ((int) pExpect[i]) + " at offset " + i +
               ", got byte " + ((int) pGot[i]));
        }
      }
    }
  }
}
