/*
 * The Apache Software License, Version 1.1
 * 
 * 
 * Copyright (c) 2003 The Apache Software Foundation. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met: 1.
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer. 2. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution. 3. The end-user documentation
 * included with the redistribution, if any, must include the following
 * acknowledgment: "This product includes software developed by the Apache
 * Software Foundation (http://www.apache.org/)." Alternately, this
 * acknowledgment may appear in the software itself, if and wherever such
 * third-party acknowledgments normally appear. 4. The name "Apache Software
 * Foundation" must not be used to endorse or promote products derived from
 * this software without prior written permission. For written permission,
 * please contact apache@apache.org. 5. Products derived from this software may
 * not be called "Apache", nor may "Apache" appear in their name, without prior
 * written permission of the Apache Software Foundation.
 * 
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * APACHE SOFTWARE FOUNDATION OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.apache.ws.jaxme.junit;

import java.io.StringReader;
import java.util.Iterator;
import java.util.List;

import javax.xml.bind.JAXBContext;

import org.apache.ws.jaxme.test.misc.defaults.Persons;
import org.apache.ws.jaxme.test.misc.defaults.PersonsType.PersonType;
import org.apache.ws.jaxme.test.misc.defaults.PersonsType.PersonType.NameType;
import org.xml.sax.InputSource;

/**
 * @author <a href="mailto:iasandcb@tmax.co.kr">Ias</a>
 */
public class DefaultValueTest extends BaseTestCase {
  public DefaultValueTest(String pName) {
    super(pName);
  }

  private String getPersons() throws Exception {
    return "<Persons xmlns=\"http://ws.apache.org/jaxme/test/misc/defaults\">\n"
      + "  <Person>\n"
      + "    <Name>\n"
      + "      <Last>Lee</Last>\n"
      + "    </Name>\n"
      + "  </Person>\n"
      + "  <Person Alias=\"Cb\">\n"
      + "    <Age>30</Age>\n"
      + "  </Person>\n"
      + "</Persons>";
  }

  public void testDefaults() throws Exception {
    String persons = getPersons();
    InputSource isource = new InputSource(new StringReader(persons));
    JAXBContext context =
      JAXBContext.newInstance("org.apache.ws.jaxme.test.misc.defaults");
    Persons unmarshalledPersons =
      (Persons) context.createUnmarshaller().unmarshal(isource);
    List personList = unmarshalledPersons.getPerson();
    Iterator i = personList.iterator();
    i.hasNext();
    PersonType person = (PersonType) i.next();
    NameType name = person.getName();
    assertEquals("Anonymous", name.getFirst());
    assertEquals("Lee", name.getLast());
    assertEquals("Ias", person.getAlias());
    assertEquals(25, person.getAge());

    i.hasNext();
    person = (PersonType) i.next();
    name = person.getName();
    assertEquals("Anonymous", name.getFirst());
    assertEquals(null, name.getLast());
    assertEquals("Cb", person.getAlias());
    assertEquals(30, person.getAge());
  }
}
