/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.junit;

import java.io.StringReader;
import java.io.StringWriter;

import javax.xml.bind.JAXBContext;

import org.apache.ws.jaxme.examples.misc.address.AddressCreator;
import org.apache.ws.jaxme.examples.misc.address.AddressPrinter;
import org.apache.ws.jaxme.test.misc.address.Address;
import org.xml.sax.InputSource;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class PrinterCreatorTest extends BaseTestCase {
  public PrinterCreatorTest(String pName) {
    super(pName);
  }

  private String getAddress() throws Exception {
    StringWriter sw = new StringWriter();
    AddressCreator.writeAddress(sw);
    sw.close();
    return "<Address xmlns=\"http://ws.apache.org/jaxme/test/misc/address\">\n" +
            "  <Name>\n" +
            "    <First>Jane</First>\n" +
            "    <Last>Doe</Last>\n" +
            "  </Name>\n" +
            "  <Postal>\n" +
            "    <Street>34 Main Street</Street>\n" +
            "    <ZIP>02215</ZIP>\n" +
            "    <City>Boston</City>\n" +
            "    <State>MA</State>\n" +
            "  </Postal>\n" +
            "  <PhoneDetails>\n" +
            "    <Phone type=\"Work\">\n" +
            "      <PhoneNumber>555.6789</PhoneNumber>\n" +
            "    </Phone>\n" +
            "    <Phone type=\"Fax\">\n" +
            "      <PhoneNumber>555.1212</PhoneNumber>\n" +
            "    </Phone>\n" +
            "  </PhoneDetails>\n" +
            "  <EmailDetails>\n" +
            "    <Email type=\"Private\">\n" +
            "      <EmailAddress>jdoe@yourcompany.com</EmailAddress>\n" +
            "    </Email>\n" +
            "    <Email type=\"Office\">\n" +
            "      <EmailAddress>josephdoe@mycompany.com</EmailAddress>\n" +
            "    </Email>\n" +
            "    <Email type=\"Office\">\n" +
            "      <EmailAddress>joseph.doe@mycompany.com</EmailAddress>\n" +
            "    </Email>\n" +
            "  </EmailDetails>\n" +
            "</Address>";
  }

  public void testCreate() throws Exception {
    StringWriter sw = new StringWriter();
    AddressCreator.writeAddress(sw);
    sw.close();
    String expect = "<Address xmlns=\"http://ws.apache.org/jaxme/test/misc/address\">\n" +
                    "  <Name>\n" +
                    "    <First>Jane</First>\n" +
                    "    <Last>Doe</Last>\n" +
                    "  </Name>\n" +
                    "  <Postal>\n" +
                    "    <Street>34 Main Street</Street>\n" +
                    "    <ZIP>02215</ZIP>\n" +
                    "    <City>Boston</City>\n" +
                    "    <State>MA</State>\n" +
                    "  </Postal>\n" +
                    "  <PhoneDetails>\n" +
                    "    <Phone type=\"Work\">\n" +
                    "      <PhoneNumber>555.6789</PhoneNumber>\n" +
                    "    </Phone>\n" +
                    "    <Phone type=\"Fax\">\n" +
                    "      <PhoneNumber>555.1212</PhoneNumber>\n" +
                    "    </Phone>\n" +
                    "  </PhoneDetails>\n" +
                    "  <EmailDetails>\n" +
                    "    <Email type=\"Private\">\n" +
                    "      <EmailAddress>jdoe@yourcompany.com</EmailAddress>\n" +
                    "    </Email>\n" +
                    "    <Email type=\"Office\">\n" +
                    "      <EmailAddress>josephdoe@mycompany.com</EmailAddress>\n" +
                    "    </Email>\n" +
                    "    <Email type=\"Office\">\n" +
                    "      <EmailAddress>joseph.doe@mycompany.com</EmailAddress>\n" +
                    "    </Email>\n" +
                    "  </EmailDetails>\n" +
                    "</Address>";
    String got = sw.toString();
    assertStringEquals(expect, got);
  }

  public void testPrint() throws Exception {
    String address = getAddress();
    InputSource isource = new InputSource(new StringReader(address));
    isource.setSystemId("testPrint.xml");
    Address addr = AddressPrinter.getAddress(isource);
    JAXBContext context = JAXBContext.newInstance("org.apache.ws.jaxme.test.misc.address");
    StringWriter sw = new StringWriter();
    context.createMarshaller().marshal(addr, sw);
    sw.close();
    String got = sw.toString();
    assertStringEquals(address, got);
  }
}
