/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.util;

/** <p>Utility class for xs:hexbinary.</p>
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class HexBinary {
  public static byte[] getClone(byte[] pHexBinary) {
    byte[] result = new byte[pHexBinary.length];
    System.arraycopy(pHexBinary, 0, result, 0, pHexBinary.length);
    return result;
  }

  public static byte[] decode(String pValue) {
    if ((pValue.length() % 2) != 0) {
      throw new IllegalArgumentException("A HexBinary string must have even length.");
    }
    byte[] result = new byte[pValue.length() / 2];
    int j = 0;
    for (int i = 0;  i < pValue.length();  ) {
      byte b;
      char c = pValue.charAt(i++);
      char d = pValue.charAt(i++);
      if (c >= '0'  &&  c <= '9') {
        b = (byte) ((c - '0') << 4);
      } else if (c >= 'A'  &&  c <= 'F') {
        b = (byte) ((c - 'A' + 10) << 4);
      } else if (c >= 'a'  &&  c <= 'f') {
        b = (byte) ((c - 'a' + 10) << 4);
      } else {
        throw new IllegalArgumentException("Invalid hex digit: " + c);
      }
      if (d >= '0'  &&  d <= '9') {
        b += (byte) (d - '0');
      } else if (d >= 'A'  &&  d <= 'F') {
        b += (byte) (d - 'A' + 10);
      } else if (d >= 'a'  &&  d <= 'f') {
        b += (byte) (d - 'a' + 10);
      } else {
        throw new IllegalArgumentException("Invalid hex digit: " + d);
      }
      result[j++] = b;
    }
    return result;
  }

  public static String encode(byte[] pHexBinary) {
    StringBuffer result = new StringBuffer();
    for (int i = 0;  i < pHexBinary.length;  i++) {
      byte b = pHexBinary[i];
      byte c = (byte) ((b & 0xf0) >> 4);
      if (c <= 9) {
        result.append((char) ('0' + c));
      } else {
        result.append((char) ('A' + c - 10));
      }
      c = (byte) (b & 0x0f);
      if (c <= 9) {
        result.append((char) ('0' + c));
      } else {
        result.append((char) ('A' + c - 10));
      }
    }
    return result.toString();
  }
}
