/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.js;

import java.io.IOException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: IndentationEngine.java 231559 2003-09-23 12:37:47Z jochen $
 */
public interface IndentationEngine {
  public static final Object NOTHING = "";

  /** <p>Increases the current level of indentation.</p>
   */
  public void indent();
  /** <p>Decreases the current level of indentation.</p>
   */
  public void unindent();

  /** <p>Adds the IndentationEngine's contents to the given
   * {@link IndentationTarget}.</p>
   */
  public void write(IndentationTarget pTarget) throws IOException;

  /** <p>Adds the given objects contents to the given
   * {@link IndentationTarget}.</p>
   */
  public void write(IndentationTarget pTarget, Object pObject) throws IOException;

  /** <p>Clears the IndentationEngine's contents.</p>
   */
  public void clear();
  /** <p>Sets the current level of indentation.</p>
   */
  public void setLevel(int pLevel);
  /** <p>Returns the current level of indentation.</p>
   */
  public int getLevel();

  /** <p>Adds the given tokens as a complete line, using the
   * given level of indentation.</p>
   */
  public void addLine(int pLevel, Object[] pTokens);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(), pTokens)</code>.</p>
   */
  public void addLine(Object[] pTokens);
  /** <p>Adds an empty line, shortcut for
   * <code>addLine(getIndentationLevel, new Object[0])</<code>.</p>
   */
  public void addLine();
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pLine})</code>.</p>
   */
  public void addLine(Object pLine);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2})</code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3})</code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4})</code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5})</code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6}) </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7}) </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8}) </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9}) </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9, pToken10}) </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9,
                       Object pToken10);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9, pToken10,
   *              pToken11})  </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9,
                       Object pToken10, Object pToken11);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9, pToken10,
   *              pToken11, pToken12})  </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9,
                       Object pToken10, Object pToken11, Object pToken12);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9, pToken10,
   *              pToken11, pToken12, pToken13})  </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9,
                       Object pToken10, Object pToken11, Object pToken12,
                       Object pToken13);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9, pToken10,
   *              pToken11, pToken12, pToken13, pToken14})  </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9,
                       Object pToken10, Object pToken11, Object pToken12,
                       Object pToken13, Object pToken14);
  /** <p>Shortcut for <code>addLine(getIndentationLevel(),
   * new Object[]{pToken1, pToken2, pToken3, pToken4, pToken5,
   *              pToken6, pToken7, pToken8, pToken9, pToken10,
   *              pToken11, pToken12, pToken13, pToken15})  </code>.</p>
   */
  public void addLine(Object pToken1, Object pToken2, Object pToken3,
                       Object pToken4, Object pToken5, Object pToken6,
                       Object pToken7, Object pToken8, Object pToken9,
                       Object pToken10, Object pToken11, Object pToken12,
                       Object pToken13, Object pToken14, Object pToken15);

  /** <p>Moves the cursor to the top of the method.</p>
   */
  public void moveToTop();

  /** <p>Moves the cursor to the bottom of the method.</p>
   */
  public void moveToBottom();

  /** <p>Sets a placeholder with the given name.</p>
   * @param pName The placeholders name
   * @param pAutoRemove Whether the placeholder must be removed by invoking {@link PlaceHolder#remove()} (false)
   * or not (true).
   */
  public PlaceHolder newPlaceHolder(String pName, boolean pAutoRemove);

  /** <p>Searches for the placeholder with the given name. The cursor
   * will be set to the line after the placeholder, if it is found.
   * In that case subsequent invocations of {@link IndentationEngine#addLine()}
   * will add code to the lines following the placeholder. Otherwise
   * the cursor is unchanged.</p>
   * @param pName The placeholders name
   * @return The placeholder or null, if it wasn't found.
   */
  public PlaceHolder getPlaceHolder(String pName);
}
