/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.js;

import java.io.Serializable;


/** <p>A qualified class name, including package name. Instances
 * of JavaQName are obtained by invoking private methods of the
 * class JavaQNameImpl.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JavaQName.java 231559 2003-09-23 12:37:47Z jochen $
 */
public interface JavaQName extends Comparable, Serializable {
  /** <p>Returns the JavaQName's package name. The empty string
   * represents the default package.</p>
   */
  public String getPackageName();

  /** <p>Returns the JavaQName's class name. This is the composition of
   * {@link #getOuterClassName()} and {@link #getInnerClassName}.</p>
   */
  public String getClassName();

  /** <p>If the class is an inner class: Returns the name of the enclosing
   * class. Otherwise returns null.</p>
   */
  public String getOuterClassName();

  /** <p>If the class is an inner class: Returns the name of the inner
   * class. Otherwise returns {@link #getClassName()}.</p>
   */
  public String getInnerClassName();

  /** <p>Returns whether the class described by the JavaQName is
   * actually an array class. If so, you may use the
   * <code>getInstanceClass()</code> method to determine the
   * JavaQName of the array elements.</p>
   */
  public boolean isArray();

  /** <p>If the method <code>isArray()</code> returns true,
   * you may use this method to obtain the instance class.</p>
   * 
   * @throws IllegalStateException This JavaQName is no array,
   *   and <code>isArray()</code> returns false.
   */
  public JavaQName getInstanceClass();

  /** <p>Returns whether this is a primitive class. Primitive classes
   * are {@link JavaQNameImpl#VOID}, {@link JavaQNameImpl#BOOLEAN},
   * {@link JavaQNameImpl#BYTE}, {@link JavaQNameImpl#SHORT},
   * {@link JavaQNameImpl#INT}, {@link JavaQNameImpl#LONG},
   * {@link JavaQNameImpl#FLOAT}, {@link JavaQNameImpl#DOUBLE}, and
   * {@link JavaQNameImpl#CHAR}.</p>
   */
  public boolean isPrimitive();

  /** <p>Returns whether this class may be imported. For instance,
   * this is not the case for primitive classes.</p>
   */
  public boolean isImportable();

  /** <p>Returns whether this class is an inner class.</p>
   */
  public boolean isInnerClass();
}
