/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.js;


/** <p>This class implements a generic JavaSource object.</p>
 *
 * @author  Jochen Wiedmann
 */
public abstract class JavaSourceObject extends IndentationEngineImpl {
  protected JavaSourceObject(String pName, JavaQName pType, JavaSource.Protection pProtection) {
    setName(pName);
    setType(pType);
    setProtection(pProtection);
  }

  protected JavaSourceObject(String pName, JavaQName pType) {
    this(pName, pType, null);
  }

  protected JavaSourceObject(String pName, String pType, JavaSource.Protection pProtection) {
    setName(pName);
    if (pType == null) {
      throw new NullPointerException("Type must not be null");
    }
    int offset = pType.indexOf('.');
    if (offset == -1) {
      setType(JavaQNameImpl.getInstance(pType));
    } else {
      setType(JavaQNameImpl.getInstance(pType.substring(0, offset), pType.substring(offset+1)));
    }
    setProtection(pProtection);
  }

  protected JavaSourceObject(String pName, String pType) {
    this(pName, pType, null);
  }

  private String name;
  /** <p>Returns this JavaSource objects name.</p>
   *
   * @see #setName
   */
  public String getName() { return name; }
  /** <p>Sets this JavaSource objects name.</p>
   *
   * @see #getName
   */
  public void setName(String n) { name = n; }

  private boolean isFinal = false;
  /** <p>Returns whether this is a final JavaSource object.</p>
   *
   * @see #setFinal
   */
  public boolean isFinal() { return isFinal; }
  /** <p>Sets whether this is a final JavaSource object.</p>
   *
   * @see #isFinal
   */
  public void setFinal(boolean pFinal) { isFinal = pFinal; }

  private boolean isStatic = false;
  /** <p>Returns whether this is a static JavaSource object.</p>
   *
   * @see #setStatic
   */
  public boolean isStatic() { return isStatic; }
  /** <p>Sets whether this is a static JavaSource object.</p>
   *
   * @see #isStatic
   */
  public void setStatic(boolean pStatic) { isStatic = pStatic; }

  private JavaQName type;
  /** <p>Returns this JavaSource objects type.</p>
   *
   * @see #setType
   */
  public JavaQName getType() { return type; }
  /** <p>Sets this JavaSource objects type.</p>
   *
   * @see #getType
   */
  public void setType(JavaQName t) { type = t; }

  private JavaSource.Protection protection = JavaSource.DEFAULT_PROTECTION;
  /** <p>Returns this JavaSource objects protection.</p>
   * @see #setProtection
   */
  public JavaSource.Protection getProtection() { return protection; }
  /** <p>Sets this JavaSource objects protection.</p>
   *
   * @param p null, "public", "protected" or "private"
   * @see #getProtection
   */
  public void setProtection(JavaSource.Protection p) {
  	 protection = (p == null) ? JavaSource.DEFAULT_PROTECTION : p;
  }

  private JavaComment comment;
  /** <p>Returns a comment describing this JavaSource object.</p>
   *
   * @see #newComment
   */
  public JavaComment getComment() { return comment; }
  /** <p>Creates a new Javadoc comment describing this JavaSource object.</p>
   *
   * @see #getComment
   */
  public JavaComment newComment() {
    if (comment == null) {
	   comment = new JavaComment();
	   return comment;
	 } else {
	   throw new IllegalStateException("A Javadoc comment has already been created for this object.");
	 }
  }

  private boolean bAbstract = false;
  /** <p>Returns whether this JavaSource object is abstract.</p>
   */
  public boolean isAbstract() {
    return bAbstract;
  }
  /** <p>Sets whether this JavaSource object is abstract,</p>
   */
  public void setAbstract(boolean isAbstract) {
    this.bAbstract = isAbstract;
  }

  private JavaSource javaSource;
  protected void setJavaSource(JavaSource pSource) {
    javaSource = pSource;
  }
  public JavaSource getJavaSource() {
    return javaSource;
  }
}