/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.js;

import java.io.IOException;
import java.io.Writer;

/** <p>An IndentationTarget writing into a given Writer.</p>
 * 
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: WriterTarget.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class WriterTarget implements IndentationTarget {
  public static final String INDENTATION_STRING = "  ";
  public static final String LINE_SEPARATOR = "\n";
  private Writer target;
  private String indentationString;
  private String lineSeparator;

  public WriterTarget() {}

  public WriterTarget(Writer pTarget) {
    target = pTarget;
  }

  public void setTarget(Writer pTarget) {
    target = pTarget;
  }

  public Writer getTarget() {
    return target;
  }

  public void setIndentationString(String pIndentationString) {
    indentationString = pIndentationString;
  }

  public String getIndentationString() {
    return indentationString == null ? INDENTATION_STRING : indentationString;
  }

  public void setLineSeparator(String pLineSeparator) {
    lineSeparator = pLineSeparator;
  }

  public String getLineSeparator() {
    return lineSeparator == null ? LINE_SEPARATOR : lineSeparator;
  }

  public boolean isInterface() {
    return false;
  }

  public void indent(int pLevel) throws IOException {
    for (int i = 0;  i < pLevel;  i++) {
      target.write(getIndentationString());
    }
  }

  public String asString(JavaQName pQName) {
    return pQName.toString();
  }

  public void write(String pValue) throws IOException {
    target.write(pValue);
  }

  public void write() throws IOException {
    target.write(getLineSeparator());
  }
}
