/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.js.junit;

import junit.framework.TestCase;


/** <p>This example demonstrates implementation of multiple
 * inheritance with the ProxyGenerator. The class MyObservableList,
 * an extension of {@link org.apache.ws.jaxme.js.junit.ObservableList},
 * is a subclass of {@link java.util.Observable}, but can also be viewed
 * as a subclass of {@link java.util.ArrayList} (or whatever
 * implementation of {@link java.util.List} you choose in the constructor.
 * The {@link java.util.Observer Observers} are notified whenever an object
 * is added to the list.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: TypesafeEnumerationTest.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class TypesafeEnumerationTest extends TestCase {
  public TypesafeEnumerationTest(String arg0) {
    super(arg0);
  }

  public void testJOE() {
	 assertEquals("JOE", EnumExample.JOE.getName());
	 assertEquals("John Doe", EnumExample.JOE.getValue());
  }

  public void testPOPEYE() {
	 assertEquals("POPEYE", EnumExample.POPEYE.getName());
	 assertEquals("Olivia's Lover", EnumExample.POPEYE.getValue());
  }

  public void testDONALD() {
	 assertEquals("DONALD", EnumExample.DONALD.getName());
	 assertEquals("The Duck King", EnumExample.DONALD.getValue());
  }

  public void testgetInstanceByName() {
	 EnumExample joe = EnumExample.getInstanceByName("JOE");
	 assertEquals(joe, EnumExample.JOE);
	 assertTrue(joe == EnumExample.JOE);
	 EnumExample popeye = EnumExample.getInstanceByName("POPEYE");
	 assertEquals(popeye, EnumExample.POPEYE);
	 assertTrue(popeye == EnumExample.POPEYE);
	 EnumExample donald = EnumExample.getInstanceByName("DONALD");
	 assertEquals(donald, EnumExample.DONALD);
	 assertTrue(donald == EnumExample.DONALD);
	 Throwable ok = null;
	 try {
		EnumExample.getInstanceByName("foo");
	 } catch (Throwable t) {
		ok = t;
	 }
	 assertTrue(ok != null  &&  ok instanceof IllegalArgumentException);
  }

  public void testgetInstanceByValue() {
	 EnumExample joe = EnumExample.getInstanceByValue("John " + "Doe");
	 assertEquals(joe, EnumExample.JOE);
	 assertTrue(joe == EnumExample.JOE);
	 EnumExample popeye = EnumExample.getInstanceByValue("Olivia's " + "Lover");
	 assertEquals(popeye, EnumExample.POPEYE);
	 assertTrue(popeye == EnumExample.POPEYE);
	 EnumExample donald = EnumExample.getInstanceByValue("The Duck" + " King");
	 assertEquals(donald, EnumExample.DONALD);
	 assertTrue(donald == EnumExample.DONALD);
	 Throwable ok = null;
	 try {
		EnumExample.getInstanceByValue("bar");
	 } catch (Throwable t) {
		ok = t;
	 }
	 assertTrue(ok != null  &&  ok instanceof IllegalArgumentException);
  }

  public void testGetInstances() {
  	 EnumExample[] instances = EnumExample.getInstances();
  	 assertEquals(instances.length, 3);
    assertEquals(EnumExample.JOE, instances[0]);
	 assertEquals(EnumExample.POPEYE, instances[1]);
	 assertEquals(EnumExample.DONALD, instances[2]);
  }

  public void testEquals() {
	 assertTrue(!EnumExample.JOE.equals(EnumExample.POPEYE));
	 assertTrue(!EnumExample.JOE.equals(EnumExample.DONALD));
	 assertTrue(!EnumExample.POPEYE.equals(EnumExample.DONALD));
  }

  public void testHashCode() {
	 assertTrue(EnumExample.JOE.hashCode() == EnumExample.JOE.getName().hashCode());
	 assertTrue(EnumExample.POPEYE.hashCode() == EnumExample.POPEYE.getName().hashCode());
	 assertTrue(EnumExample.DONALD.hashCode() == EnumExample.DONALD.getName().hashCode());
  }
}
