/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.js.util;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.logging.AntProjectLoggerFactory;
import org.apache.ws.jaxme.logging.LoggerAccess;
import org.apache.ws.jaxme.logging.LoggerFactory;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.TaskAdapter;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class AntLinkChecker extends TaskAdapter {
  public class CheckedURL {
    private URL name;
    public void setName(URL pName) {
      if (name != null) {
        throw new IllegalStateException("An 'URL' element must have exactly one 'name' or 'file' attribute. These attributes are mutually exclusive.");
      }
      name = pName;
    }
    public void setFile(File pName) throws MalformedURLException {
      if (name != null) {
        throw new IllegalStateException("An 'URL' element must have exactly one 'name' or 'file' attribute. These attributes are mutually exclusive.");
      }
      name = pName.toURL();
    }
    public URL getName() {
      return name;
    }
    public void finish() {
      if (name == null) {
        throw new IllegalStateException("An 'URL' element must have exactly one 'name' or 'file' attribute.");
      }
    }
  }

  public class MyLinkChecker extends LinkChecker {
    private boolean isSettingLoggerFactory = true;
    public CheckedURL createURL() {
      CheckedURL url = new CheckedURL();
      AntLinkChecker.this.addURL(url);
      return url;
    }
    public boolean isSettingLoggerFactory() {
      return isSettingLoggerFactory;
    }
    public void setSettingLoggerFactory(boolean pSettingLoggerFactory) {
      isSettingLoggerFactory = pSettingLoggerFactory;
    }
  }

  private MyLinkChecker checker = new MyLinkChecker();
  private List urls = new ArrayList();

  void addURL(CheckedURL pURL) {
     urls.add(pURL);
  }

  public AntLinkChecker() {
    setProxy(checker);
  }

  protected LoggerFactory initLogging() {
    if (!checker.isSettingLoggerFactory()) {
      return null;
    }
    LoggerFactory loggerFactory = LoggerAccess.getLoggerFactory();
    if (loggerFactory instanceof AntProjectLoggerFactory) {
      return null;
    }
    LoggerAccess.setLoggerFactory(new AntProjectLoggerFactory(this));
    return loggerFactory;
  }

  protected void stopLogging(LoggerFactory pLoggerFactory) {
    if (pLoggerFactory != null) {
      LoggerAccess.setLoggerFactory(pLoggerFactory);
    }
  }

  public void execute() {
    log("execute: ->", Project.MSG_VERBOSE);
    LoggerFactory loggerFactory = initLogging();
    checker.setLogger(LoggerAccess.getLogger(LinkChecker.class));
    try {
      for (Iterator iter = urls.iterator();  iter.hasNext();  ) {
        CheckedURL url = (CheckedURL) iter.next();
        checker.addURL(url.getName());
      }
      checker.parse();
    } finally {
      stopLogging(loggerFactory);
    }
    log("execute: <-", Project.MSG_VERBOSE);
  }
}
