/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.logging;

import java.io.PrintWriter;
import java.io.StringWriter;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class AntProjectLogger implements Logger {
   private final String cName;
   private final Task task;

	public AntProjectLogger(String pName, Project pProject) {
      cName = pName;
      task = pProject.createTask("echo");
	}

   public AntProjectLogger(String pName, Task pTask) {
      this(pTask.getTaskName() + "." + pName, pTask.getProject());
   }

   public boolean isFinestEnabled() { return true; }
   public boolean isFinerEnabled() { return true; }
   public boolean isFineEnabled() { return true; }
   public boolean isInfoEnabled() { return true; }
   public boolean isWarnEnabled() { return true; }
   public boolean isErrorEnabled() { return true; }

   protected String asString(Object[] pDetails) {
      if (pDetails == null) {
         return "";
      }
      StringBuffer sb = new StringBuffer();
      for (int i = 0;  i < pDetails.length;  i++) {
          if (i > 0) {
             sb.append(", ");
          }
          sb.append(pDetails[i]);
      }
      return sb.toString();
   }

   protected void log(int pLevel, String mName, String pMsg) {
      task.setTaskName(cName + "." + mName);
      task.log(pMsg, pLevel);
   }

	public void entering(String mName, Object[] pDetails) {
    log(Project.MSG_VERBOSE, mName, "-> " + asString(pDetails));
	}

	public void entering(String mName) {
    log(Project.MSG_VERBOSE, mName, "->");
	}

	public void entering(String mName, Object pDetails) {
    log(Project.MSG_VERBOSE, mName, "-> " + pDetails);
	}

	public void exiting(String mName, Object[] pDetails) {
    log(Project.MSG_VERBOSE, mName, "<- " + asString(pDetails));
	}

	public void exiting(String mName) {
    log(Project.MSG_VERBOSE, mName, "<-");
	}

	public void exiting(String mName, Object pDetails) {
    log(Project.MSG_VERBOSE, mName, "<- " + pDetails);
	}

	public void throwing(String mName, Throwable pThrowable) {
      StringWriter sw = new StringWriter();
      pThrowable.printStackTrace(new PrintWriter(sw));
      error(mName, sw.toString());
	}

	public void finest(String mName, String pMsg, Object[] pDetails) {
      finest(mName, pMsg + ", " + asString(pDetails));
	}

	public void finest(String mName, String pMsg) {
      log(Project.MSG_DEBUG, mName, pMsg);
	}

	public void finest(String mName, String pMsg, Object pDetails) {
      finest(mName, pMsg + ", " + pDetails);
	}

	public void finer(String mName, String pMsg, Object[] pDetails) {
      finer(mName, pMsg + ", " + asString(pDetails));
	}

	public void finer(String mName, String pMsg) {
      log(Project.MSG_DEBUG, mName, pMsg);
	}

	public void finer(String mName, String pMsg, Object pDetails) {
      finer(mName, pMsg + ", " + pDetails);
	}

	public void fine(String mName, String pMsg, Object[] pDetails) {
      fine(mName, pMsg + ", " + asString(pDetails));
	}

	public void fine(String mName, String pMsg) {
      log(Project.MSG_VERBOSE, mName, pMsg);
	}

	public void fine(String mName, String pMsg, Object pDetails) {
      fine(mName, pMsg + ", " + pDetails);
	}

	public void info(String mName, String pMsg, Object[] pDetails) {
      info(mName, pMsg + ", " + asString(pDetails));
	}

	public void info(String mName, String pMsg) {
      log(Project.MSG_INFO, mName, pMsg);
	}

	public void info(String mName, String pMsg, Object pDetails) {
      info(mName, pMsg + ", " + pDetails);
	}

	public void warn(String mName, String pMsg, Object[] pDetails) {
      warn(mName, pMsg + ", " + asString(pDetails));
	}

	public void warn(String mName, String pMsg) {
      log(Project.MSG_WARN, mName, pMsg);
	}

	public void warn(String mName, String pMsg, Object pDetails) {
      warn(mName, pMsg + ", " + pDetails);
	}

	public void error(String mName, String pMsg, Object[] pDetails) {
      error(mName, pMsg + ", " + asString(pDetails));
	}

	public void error(String mName, String pMsg) {
      log(Project.MSG_ERR, mName, pMsg);
	}

	public void error(String mName, String pMsg, Object pDetails) {
      error(mName, pMsg + ", " + pDetails);
	}
}
