/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.logging;

import java.util.logging.Level;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class JavaUtilLogger implements Logger {
   private final java.util.logging.Logger myLogger;
   private final String cName;

   public JavaUtilLogger(String pCName) {
      cName = pCName;
      myLogger = java.util.logging.Logger.getLogger(cName);
   }

   public void entering(String mName, Object[] pDetails) {
      myLogger.entering(cName, mName, pDetails);
   }

   public void entering(String mName) {
      myLogger.entering(cName, mName);
   }

   public void entering(String mName, Object pDetails) {
      myLogger.entering(cName, mName, pDetails);
   }

   public void exiting(String mName, Object[] pDetails) {
      myLogger.exiting(cName, mName, pDetails);
   }

   public void exiting(String mName) {
      myLogger.exiting(cName, mName);
   }

   public void exiting(String mName, Object pDetails) {
      myLogger.exiting(cName, mName, pDetails);
   }

   public void throwing(String mName, Throwable t) {
      myLogger.throwing(cName, mName, t);
   }

   public void finest(String mName, String pMsg, Object[] pDetails) {
      myLogger.logp(Level.FINEST, cName, mName, pMsg, pDetails);
   }

   public void finest(String mName, String pMsg) {
      myLogger.logp(Level.FINEST, cName, mName, pMsg);
   }

   public void finest(String mName, String pMsg, Object pDetails) {
      myLogger.logp(Level.FINEST, cName, mName, pMsg, pDetails);
   }

   public void finer(String mName, String pMsg, Object[] pDetails) {
      myLogger.logp(Level.FINER, cName, mName, pMsg, pDetails);
   }

   public void finer(String mName, String pMsg) {
      myLogger.logp(Level.FINER, cName, mName, pMsg);
   }

   public void finer(String mName, String pMsg, Object pDetails) {
      myLogger.logp(Level.FINER, cName, mName, pMsg, pDetails);
   }

   public void fine(String mName, String pMsg, Object[] pDetails) {
      myLogger.logp(Level.FINE, cName, mName, pMsg, pDetails);
   }

   public void fine(String mName, String pMsg) {
      myLogger.logp(Level.FINE, cName, mName, pMsg);
   }

   public void fine(String mName, String pMsg, Object pDetails) {
      myLogger.logp(Level.FINE, cName, mName, pMsg, pDetails);
   }

   public void info(String mName, String pMsg, Object[] pDetails) {
      myLogger.logp(Level.INFO, cName, mName, pMsg, pDetails);
   }

   public void info(String mName, String pMsg) {
      myLogger.logp(Level.INFO, cName, mName, pMsg);
   }

   public void info(String mName, String pMsg, Object pDetails) {
      myLogger.logp(Level.INFO, cName, mName, pMsg, pDetails);
   }

   public void warn(String mName, String pMsg, Object[] pDetails) {
      myLogger.logp(Level.WARNING, cName, mName, pMsg, pDetails);
   }

   public void warn(String mName, String pMsg) {
      myLogger.logp(Level.WARNING, cName, mName, pMsg);
   }

   public void warn(String mName, String pMsg, Object pDetails) {
      myLogger.logp(Level.WARNING, cName, mName, pMsg, pDetails);
   }

   public void error(String mName, String pMsg, Object[] pDetails) {
      myLogger.logp(Level.SEVERE, cName, mName, pMsg, pDetails);
   }

   public void error(String mName, String pMsg) {
      myLogger.logp(Level.SEVERE, cName, mName, pMsg);
   }

   public void error(String mName, String pMsg, Object pDetails) {
      myLogger.logp(Level.SEVERE, cName, mName, pMsg, pDetails);
   }

	public boolean isFinestEnabled() {
      return myLogger.isLoggable(Level.FINEST);
	}

	public boolean isFinerEnabled() {
      return myLogger.isLoggable(Level.FINER);
	}

	public boolean isFineEnabled() {
      return myLogger.isLoggable(Level.FINE);
	}

	public boolean isInfoEnabled() {
      return myLogger.isLoggable(Level.INFO);
	}

	public boolean isWarnEnabled() {
      return myLogger.isLoggable(Level.WARNING);
	}

	public boolean isErrorEnabled() {
      return myLogger.isLoggable(Level.SEVERE);
	}
}
