/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.logging;

import org.apache.log4j.Level;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class Log4jLogger implements Logger {
   private final org.apache.log4j.Logger logger;

   public Log4jLogger(String pCName) {
      logger = org.apache.log4j.Logger.getLogger(pCName); 
   }

   protected String format(String pMethodName, String pMsg, Object[] pDetails) {
      final StringBuffer sb = new StringBuffer(pMethodName);
      sb.append(": ").append(pMsg);
      if (pDetails != null) {
         for (int i = 0;  i < pDetails.length;  i++) {
            sb.append(", ");
            sb.append(pDetails[i]);
         }
      }
      return sb.toString();
   }

   protected String format(String pMethodName, Object[] pDetails) {
      final StringBuffer sb = new StringBuffer(pMethodName);
      if (pDetails != null) {
         String add = ": ";
         for (int i = 0;  i < pDetails.length;  i++) {
            sb.append(add);
            add = ", ";
            sb.append(pDetails[i]);
         }
      }
      return sb.toString();
   }

	public void entering(String pMethodName, Object[] pDetails) {
      if (logger.isDebugEnabled()) {
         logger.debug(format(pMethodName + " ->", pDetails));
      }
	}

	public void entering(String pMethodName) {
      if (logger.isDebugEnabled()) {
         logger.debug(pMethodName + " ->");
      }
	}

	public void entering(String pMethodName, Object pDetails) {
      if (logger.isDebugEnabled()) {
         logger.debug(pMethodName + " ->: " + pDetails);
      }
	}

	public void exiting(String pMethodName, Object[] pDetails) {
      if (logger.isDebugEnabled()) {
         logger.debug(format(pMethodName + " <-", pDetails));
      }
	}

	public void exiting(String pMethodName) {
      if (logger.isDebugEnabled()) {
         logger.debug(pMethodName + " <-");
      }
	}

	public void exiting(String pMethodName, Object pDetails) {
      if (logger.isDebugEnabled()) {
         logger.debug(pMethodName + " <-: " + pDetails);
      }
	}

	public void throwing(String pMethodName, Throwable pThrowable) {
      logger.error(pMethodName, pThrowable);
	}

	public boolean isFinestEnabled() {
      return logger.isDebugEnabled();
	}

	public void finest(String pMethodName, String pMsg, Object[] pDetails) {
      if (logger.isDebugEnabled()) {
         logger.debug(format(pMethodName, pMsg, pDetails));
      }
	}

	public void finest(String pMethodName, String pMsg) {
      if (logger.isDebugEnabled()) {
         logger.debug(pMethodName + ": " + pMsg);
      }
	}

	public void finest(String pMethodName, String pMsg, Object pDetails) {
      if (logger.isDebugEnabled()) {
         logger.debug(pMethodName + ": " + pMsg + ", " + pDetails);
      }
	}

	public void finer(String pMethodName, String pMsg, Object[] pDetails) {
      finest(pMethodName, pMsg, pDetails);
	}

	public boolean isFinerEnabled() {
      return isFinestEnabled();
	}

	public void finer(String pMethodName, String pMsg) {
      finest(pMethodName, pMsg);
	}

	public void finer(String pMethodName, String pMsg, Object pDetails) {
      finest(pMethodName, pMsg, pDetails);
	}

	public boolean isFineEnabled() {
      return isFinestEnabled();
	}

	public void fine(String pMethodName, String pMsg, Object[] pDetails) {
      finest(pMethodName, pMsg, pDetails);
	}

	public void fine(String pMethodName, String pMsg) {
      finest(pMethodName, pMsg);
	}

	public void fine(String pMethodName, String pMsg, Object pDetails) {
      finest(pMethodName, pMsg, pDetails);
	}

	public boolean isInfoEnabled() {
      return logger.isInfoEnabled();
	}

	public void info(String pMethodName, String pMsg, Object[] pDetails) {
      if (logger.isInfoEnabled()) {
         logger.info(format(pMethodName, pMsg, pDetails));
      }
	}

	public void info(String pMethodName, String pMsg) {
      if (logger.isInfoEnabled()) {
         logger.info(pMethodName + ": " + pMsg);
      }
	}

	public void info(String pMethodName, String pMsg, Object pDetails) {
      if (logger.isInfoEnabled()) {
         logger.info(pMethodName + ": " + pMsg + ", " + pDetails);
      }
	}

	public boolean isWarnEnabled() {
      return logger.isEnabledFor(Level.WARN);
	}

	public void warn(String pMethodName, String pMsg, Object[] pDetails) {
      if (logger.isEnabledFor(Level.WARN)) {
         logger.warn(format(pMethodName, pMsg, pDetails));
      }
	}

	public void warn(String pMethodName, String pMsg) {
      if (logger.isEnabledFor(Level.WARN)) {
         logger.warn(pMethodName + ": " + pMsg);
      }
	}

	public void warn(String pMethodName, String pMsg, Object pDetails) {
      if (logger.isEnabledFor(Level.WARN)) {
         logger.warn(pMethodName + ": " + pMsg + ", " + pDetails);
      }
	}

	public boolean isErrorEnabled() {
      return logger.isEnabledFor(Level.ERROR);
	}

	public void error(String pMethodName, String pMsg, Object[] pDetails) {
      if (logger.isEnabledFor(Level.ERROR)) {
         logger.error(format(pMethodName, pMsg, pDetails));
      }
	}

	public void error(String pMethodName, String pMsg) {
      if (logger.isEnabledFor(Level.ERROR)) {
         logger.error(pMethodName + ": " + pMsg);
      }
	}

	public void error(String pMethodName, String pMsg, Object pDetails) {
      if (logger.isEnabledFor(Level.ERROR)) {
         logger.error(pMethodName + ": " + pMsg + ", " + pDetails);
      }
	}
}
