/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.logging;

/** <p>The Logger interface describes an object which is able to log
 * a message.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface Logger {
   /** <p>Logs the message that a method is entered.</p>
    */
   public void entering(String pMethodName, Object[] pDetails);

   /** <p>Logs the message that a method is entered.</p>
    */
   public void entering(String pMethodName);

   /** <p>Logs the message that a method is entered.</p>
    */
   public void entering(String pMethodName, Object pDetails1);

   /** <p>Logs the message that a method is exiting.</p>
    */
   public void exiting(String pMethodName, Object[] pDetails);

   /** <p>Logs the message that a method is exiting.</p>
    */
   public void exiting(String pMethodName);

   /** <p>Logs the message that a method is exiting.</p>
    */
   public void exiting(String pMethodName, Object pDetails1);

   /** <p>Logs the given Throwable.</p>
    */
   public void throwing(String pMethodName, Throwable pThrowable);

   /** <p>Returns whether finest logging is enabled.</p>
    */
   public boolean isFinestEnabled();

   /** <p>Logs the given message with finest level.</p>
    */
   public void finest(String pMethodName, String pMsg, Object[] pDetails);

   /** <p>Logs the given message with finest level.</p>
    */
   public void finest(String pMethodName, String pMsg);

   /** <p>Logs the given message with finest level.</p>
    */
   public void finest(String pMethodName, String pMsg, Object pDetails);

   /** <p>Logs the given message with finer level.</p>
    */
   public void finer(String pMethodName, String pMsg, Object[] pDetails);

   /** <p>Returns whether fine logging is enabled.</p>
    */
   public boolean isFinerEnabled();

   /** <p>Logs the given message with finer level.</p>
    */
   public void finer(String pMethodName, String pMsg);

   /** <p>Logs the given message with finer level.</p>
    */
   public void finer(String pMethodName, String pMsg, Object pDetails);

   /** <p>Returns whether fine logging is enabled.</p>
    */
   public boolean isFineEnabled();

   /** <p>Logs the given message with fine level.</p>
    */
   public void fine(String pMethodName, String pMsg, Object[] pDetails);

   /** <p>Logs the given message with fine level.</p>
    */
   public void fine(String pMethodName, String pMsg);

   /** <p>Logs the given message with fine level.</p>
    */
   public void fine(String pMethodName, String pMsg, Object pDetails);

   /** <p>Returns whether info logging is enabled.</p>
    */
   public boolean isInfoEnabled();

   /** <p>Logs the given message with info level.</p>
    */
   public void info(String pMethodName, String pMsg, Object[] pDetails);

   /** <p>Logs the given message with info level.</p>
    */
   public void info(String pMethodName, String pMsg);

   /** <p>Logs the given message with info level.</p>
    */
   public void info(String pMethodName, String pMsg, Object pDetails);

   /** <p>Returns whether warning logging is enabled.</p>
    */
   public boolean isWarnEnabled();

   /** <p>Logs the given message with warning level.</p>
    */
   public void warn(String pMethodName, String pMsg, Object[] pDetails);

   /** <p>Logs the given message with warning level.</p>
    */
   public void warn(String pMethodName, String pMsg);

   /** <p>Logs the given message with warning level.</p>
    */
   public void warn(String pMethodName, String pMsg, Object pDetails);

   /** <p>Returns whether error logging is enabled.</p>
    */
   public boolean isErrorEnabled();

   /** <p>Logs the given message with error level.</p>
    */
   public void error(String pMethodName, String pMsg, Object[] pDetails);

   /** <p>Logs the given message with error level.</p>
    */
   public void error(String pMethodName, String pMsg);

   /** <p>Logs the given message with error level.</p>
    */
   public void error(String pMethodName, String pMsg, Object pDetails);
}
