/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.logging;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.Date;


/** <p>Base implementation of a Logger.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class LoggerImpl implements Logger {
   private final String cName;
   private boolean loggingTime, loggingThread;

   public LoggerImpl(String pCName) {
      cName = pCName;
   }

   public boolean isLoggingTime() {
      return loggingTime;
   }

   public boolean isLoggingThread() {
      return loggingThread;
   }

   public void setLoggingTime(boolean pLoggingTime) {
      loggingTime = pLoggingTime;
   }

   public void setLoggingThread(boolean pLoggingThread) {
      loggingThread = pLoggingThread;
   }

   protected void log(String pMsg) {
      System.err.println(pMsg);
   }

   protected void log(String pLevel, String pCName, String pMName, String pMsg) {
      log(pLevel, pCName, pMName, new Object[]{pMsg});
   }

   protected void log(String pLevel, String pCName, String pMName,
                       String pMsg, Object[] pDetails) {
      if (pDetails == null) {
         log(pLevel, pCName, pMName, new Object[]{pMsg});
      } else {
         Object[] o = new Object[pDetails.length+1];
         o[0] = pMsg;
         for (int i = 0;  i < pDetails.length;  i++) {
            o[i+1] = pDetails[i];
         }
         log(pLevel, pCName, pMName, o);
      }
   }

   protected void log(String pLevel, String pCName, String pMName,
                       Object[] pDetails) {
      StringBuffer sb = new StringBuffer();
      if (loggingTime) {
         sb.append(new Date());
         sb.append(", ");
      }
      if (loggingThread) {
         sb.append(Thread.currentThread().getName());
         sb.append(", ");
      }
      sb.append(": ");
      sb.append(pLevel).append(", ").append(pMName).append(", ");
      if (pDetails != null) {
         for (int i = 0;  i < pDetails.length;  i++) {
            sb.append(", ").append(pDetails[i]);
         }
      }
      log(sb.toString());
   }

   public boolean isFinestEnabled() { return true; }
   public boolean isFinerEnabled() { return true; }
   public boolean isFineEnabled() { return true; }
   public boolean isInfoEnabled() { return true; }
   public boolean isWarnEnabled() { return true; }
   public boolean isErrorEnabled() { return true; }

   public void finest(String mName, String pMsg, Object[] pDetails) {
      log("FINEST", cName, mName, pMsg, pDetails);
   }

   public void finest(String mName, String pMsg) {
      log("FINEST", cName, mName, pMsg);
   }

   public void finest(String mName, String pMsg, Object pDetails) {
      log("FINEST", cName, mName, new Object[]{pMsg, pDetails});
   }

   public void finer(String mName, String pMsg, Object[] pDetails) {
      log("FINER", cName, mName, pMsg, pDetails);
   }

   public void finer(String mName, String pMsg) {
      log("FINER", cName, mName, pMsg);
   }

   public void finer(String mName, String pMsg, Object pDetails) {
      log("FINER", cName, mName, new Object[]{pMsg, pDetails});
   }

   public void fine(String mName, String pMsg, Object[] pDetails) {
      log("FINE", cName, mName, pMsg, pDetails);
   }

   public void fine(String mName, String pMsg) {
      log("FINE", cName, mName, pMsg);
   }

   public void fine(String mName, String pMsg, Object pDetails) {
      log("FINE", cName, mName, new Object[]{pMsg, pDetails});
   }

   public void info(String mName, String pMsg, Object[] pDetails) {
      log("INFO", cName, mName, pMsg, pDetails);
   }

   public void info(String mName, String pMsg) {
      log("INFO", cName, mName, pMsg);
   }

   public void info(String mName, String pMsg, Object pDetails) {
      log("INFO", cName, mName, new Object[]{pMsg, pDetails});
   }

   public void warn(String mName, String pMsg, Object[] pDetails) {
      log("WARN", cName, mName, pMsg, pDetails);
   }

   public void warn(String mName, String pMsg) {
      log("WARN", cName, mName, pMsg);
   }

   public void warn(String mName, String pMsg, Object pDetails) {
      log("WARN", cName, mName, new Object[]{pMsg, pDetails});
   }

   public void error(String mName, String pMsg, Object[] pDetails) {
      log("ERROR", cName, mName, pMsg, pDetails);
   }

   public void error(String mName, String pMsg) {
      log("ERROR", cName, mName, pMsg);
   }

   public void error(String mName, String pMsg, Object pDetails) {
      log("ERROR", cName, mName, new Object[]{pMsg, pDetails});
   }

	public void entering(String mName, Object[] pDetails) {
      log("->", cName, mName, pDetails);
	}

	public void entering(String mName) {
      log("->", cName, mName, (Object[]) null);
	}

	public void entering(String mName, Object pDetails) {
      log("->", cName, mName, new Object[]{pDetails});
	}

	public void exiting(String mName, Object[] pDetails) {
      log("<-", cName, mName, pDetails);
	}

	public void exiting(String mName) {
      log("<-", cName, mName, (Object[]) null);
	}

	public void exiting(String mName, Object pDetails) {
      log("<-", cName, mName, new Object[]{pDetails});
	}

	public void throwing(String mName, Throwable pThrowable) {
      StringWriter sw = new StringWriter();
      pThrowable.printStackTrace(new PrintWriter(sw));
      log("THROWABLE", cName, mName, sw.toString());
	}
}
