/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls;

import java.util.Iterator;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface Parts {
  /** <p>Inserts a constant value.</p>
   */
  public void addPart(Value pValue);

  /** <p>Inserts a column reference.</p>
   */
  public void addPart(ColumnReference pColumn);

  /** <p>Inserts a set of column references.</p>
   */
  public void addPart(ColumnReference[] pPart);
  
  /** <p>Inserts a subselect.</p>
   */
  public void addPart(SelectStatement pPart);
  
  /** <p>Inserts a String. The String will be properly escaped.</p>
   * @throws NullPointerException The paremeter <code>pString</code> is null.
   */
  public void addPart(String pString);
  
  /** <p>Inserts a NULL value.</p>
   */
  public void addPart();
  
  /** <p>Inserts a byte value, which will be inserted without quotes.</p>
   */
  public void addPart(byte pByte);
  
  /** <p>Inserts an int value, which will be inserted without quotes.</p>
   */
  public void addPart(int pInt);
  
  /** <p>Inserts a long value, which will be inserted without quotes.</p>
   */
  public void addPart(long pLong);
  
  /** <p>Inserts a short value, which will be inserted without quotes.</p>
   */
  public void addPart(short pShort);
  
  /** <p>Inserts a float value, which will be inserted without quotes.</p>
   */
  public void addPart(float pFloat);
  
  /** <p>Inserts a double value, which will be inserted without quotes.</p>
   */
  public void addPart(double pDouble);
  
  /** <p>Inserts a boolean value, which will be inserted as the word
   * <code>TRUE</code>, or <code>FALSE</code>, respectively.</p>
   */
  public void addPart(boolean pBoolean);

  /** <p>Inserts a function.</p>
   */
  public void addPart(Function pFunction);

  /** <p>Inserts raw SQL code.</p>
   */ 
  public void addRawSQLPart(String pRawSQL);
  
  /** <p>Inserts a placeholder.</p>
   */
  public void addPlaceholder();
  
  /** <p>Returns the number of parts.</p>
   */
  public int getNumParts();
  
  /** <p>Returns an Iterator to the parts that have been added.</p>
   */
  public Iterator getParts();
}
