/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls;

import java.util.Iterator;


/** <p>Interface of a SELECT statement.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface SelectStatement extends ConstrainedStatement {
   public interface OrderColumn {
      /** <p>Returns the ordered column.</p>
       */
      public ColumnReference getColumn();
      /** <p>Returns whether ascending (false) or descending (true)
       * sorting is requested.</p>
       */
      public boolean isDescending();
   }

   /** <p>Shortcut for <code>(SelectTableReference) getTable()</code>.</p>
    */
   public SelectTableReference getSelectTableReference();

   /** <p>Returns an Iterator over all the table references.</p>
    */
   public Iterator getSelectTableReferences();

   /** <p>Adds a column to the ORDER BY clause.</p>
    */
   public void addOrderColumn(OrderColumn pColumn);

   /** <p>Adds a column to the ORDER BY clause. The column is sorted in
    * ascending order.</p>
    */
   public void addOrderColumn(ColumnReference pColumn);

   /** <p>Adds a column to the ORDER BY clause. The column is sorted in
    * ascending or descending order, depending on the parameter
    * <code>pDescending</code>.</p>
    * @param pDescending True for descending or false for ascending
    */
   public void addOrderColumn(ColumnReference pColumn, boolean pDescending);

   /** <p>Adds a result column to the statement. By default all columns
    * are returned.</p>
    */
   public void addResultColumn(ColumnReference pColumn);

   /** <p>Returns the list of result columns.</p>
    */
   public Iterator getResultColumns();

   /** <p>Sets whether the statement should have a DISTINCT clause. By
    * default no DISTINCT clause is present.</p>
    */
   public void setDistinct(boolean pDistinct);

   /** <p>Returns whether the statement should have a DISTINCT clause. By
    * default no DISTINCT clause is present.</p>
    */
   public boolean isDistinct();

   /** <p>Limits the size of the result set to the given number of rows.
    * Defaults to zero, in which case the size of the result set is
    * unlimited.</p>
    */
   public void setMaxRows(int pMaxRows);

   /** <p>Returns the limit of the number of rows in the result set, or
    * zero, if the size of the result set is unlimited.</p>
    */
   public int getMaxRows();

   /** <p>Indicates that the given number of rows should be skipped at the
    * result sets beginning. The default is zero, in which case no rows
    * are skipped.</p>
    */
   public void setSkippedRows(int pSkippedRows);

   /** <p>Returns the number of rows to skip at the result sets beginning.
    * The default is zero, in which case no rows are skipped.</p>
    */
   public int getSkippedRows();
}
