/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls;

import java.util.Calendar;
import java.util.Iterator;


/** <p>A common base interface for {@link org.apache.ws.jaxme.sqls.InsertStatement}
 * and {@link org.apache.ws.jaxme.sqls.UpdateStatement}.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface SetStatement extends Statement {
  public interface SetValue {
     /** <p>Returns the column being set.</p>
      */
     public ColumnReference getColumnReference();
     /** <p>Returns the value to which the column is being set.</p>
      */
     public Value getValue();
  }

  /** <p>Returns an {@link Iterator} to all values being set.
   * Any element in the iterator is an instance of {@link SetValue}.</p>
   */
  public Iterator getSetValues();

  /** <p>Adds a SET clause setting the given column to NULL.</p>
   */
  public void addSetNull(Column pColumn);
  /** <p>Adds a SET clause setting the given column to NULL.</p>
   */
  public void addSetNull(Column.Name pColumn);
  /** <p>Adds a SET clause setting the given column to NULL.</p>
   */
  public void addSetNull(String pColumn);

  /** <p>Adds a SET clause setting the given column to a value
   * given by a placeholder.</p>
   */
  public void addSet(Column pColumn);
  /** <p>Adds a SET clause setting the given column to a value
   * given by a placeholder.</p>
   */
  public void addSet(Column.Name pColumn);
  /** <p>Adds a SET clause setting the given column to a value
   * given by a placeholder.</p>
   */
  public void addSet(String pColumn);

  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, byte pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(Column.Name pColumn, byte pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(String pColumn, byte pValue);

  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, short pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(Column.Name pColumn, short pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(String pColumn, short pValue);

  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, int pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(Column.Name pColumn, int pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(String pColumn, int pValue);

  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, long pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(Column.Name pColumn, long pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(String pColumn, long pValue);


  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, float pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(Column.Name pColumn, float pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(String pColumn, float pValue);
 
  /** <p>Adds a SET clause setting the given column to the value
   * TRUE or FALSE, depending on <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, boolean pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * TRUE or FALSE, depending on <code>pValue<code>.</p>
   */
  public void addSet(Column.Name pColumn, boolean pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * TRUE or FALSE, depending on <code>pValue<code>.</p>
   */
  public void addSet(String pColumn, boolean pValue);

  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue<code>.</p>
   */
  public void addSet(Column pColumn, String pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(Column.Name pColumn, String pValue);
  /** <p>Adds a SET clause setting the given column to the value
   * <code>pValue</code>.</p>
   */
  public void addSet(String pColumn, String pValue);

  /** <p>Adds a SET clause setting the given column to the datetime
   * value <code>pValue<code>.</p>
   */
  public void addSetDateTime(Column pColumn, Calendar pValue);
  /** <p>Adds a SET clause setting the given column to the datetime
   * value <code>pValue</code>.</p>
   */
  public void addSetDateTime(Column.Name pColumn, Calendar pValue);
  /** <p>Adds a SET clause setting the given column to the datetime
   * value <code>pValue</code>.</p>
   */
  public void addSetDateTime(String pColumn, Calendar pValue);

  /** <p>Adds a SET clause setting the given column to the time value
   * <code>pValue<code>. Shortcut for
   * <code>addSet(getTable().newColumnReference(pColumn), pValue)</code>.</p>
   */
  public void addSetTime(Column pColumn, Calendar pValue);
  /** <p>Adds a SET clause setting the given column to the time value
   * <code>pValue</code>. Shortcut for
   * <code>addSet(getTable().newColumnReference(pColumn), pValue)</code>.</p>
   */
  public void addSetTime(Column.Name pColumn, Calendar pValue);
  /** <p>Adds a SET clause setting the given column to the time value
   * <code>pValue</code>.</p>
   */
  public void addSetTime(String pColumn, Calendar pValue);

  /** <p>Adds a SET clause setting the given column to the date value
   * <code>pValue<code>.</p>
   */
  public void addSetDate(Column pColumn, Calendar pValue);
  /** <p>Adds a SET clause setting the given column to the date value
   * <code>pValue</code>.</p>
   */
  public void addSetDate(Column.Name pColumn, Calendar pValue);
  /** <p>Adds a SET clause setting the given column to the date value
   * <code>pValue</code>.</p>
   */
  public void addSetDate(String pColumn, Calendar pValue);
}
