/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls;

/** <p>An abstract value.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface Value {
  public class Type {
    private String name;
    protected Type(String pName) {
      name = pName;
    }
    public String toString() { return name; }
    public String getName() { return name; }
    public int hashCode() { return name.hashCode(); }
    public boolean equals(Object o) {
      return o != null  &&  o instanceof Type  &&
          ((Type) o).name.equals(name);
    }
    public final static Type PLACEHOLDER = new Type("PLACEHOLDER");
    public final static Type NULL = new Type("NULL");
    public final static Type BOOLEAN = new Type("BOOLEAN");
    public final static Type FLOAT = new Type("FLOAT");
    public final static Type DOUBLE = new Type("DOUBLE");
    public final static Type BYTE = new Type("BYTE");
    public final static Type SHORT = new Type("SHORT");
    public final static Type INT = new Type("INT");
    public final static Type LONG = new Type("LONG");
    public final static Type DATETIME = new Type("DATETIME");
    public final static Type DATE = new Type("DATE");
    public final static Type TIME = new Type("TIME");
    public final static Type STRING = new Type("STRING");
  }

  /** <p>Returns the values type.</p>
   */
  public Type getType();

  /** <p>Returns the actual value. This may be null.</p>
   */
  public Object getValue();
}
