/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.db2;

import java.util.Iterator;

import org.apache.ws.jaxme.sqls.SQLFactory;


/** <p>Interface of an SQL factory for DB2 databases.</p>
*
* @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
*/
public interface DB2SQLFactory extends SQLFactory {
  /** <p>Creates a new {@link TableSpace} with the given name.</p>
   */
  public TableSpace newTableSpace(String pName, TableSpace.Type pType);

  /** <p>Creates a new {@link TableSpace} with the given name.</p>
   */
  public TableSpace newTableSpace(TableSpace.Name pName, TableSpace.Type pType);

  /** <p>Returns the tablespace with the given name or null, if no such
   * tablespace exists.</p>
   */
  public TableSpace getTableSpace(TableSpace.Name pName);

  /** <p>Returns the tablespace with the given name or null, if no such
   * tablespace exists.</p>
   */
  public TableSpace getTableSpace(String pName);

  /** <p>Returns a list of all tablespaces.
   * This Iterator does <em>not</em> include the predefined table spaces
   * <code>SYSCATSPACE</code>, <code>TEMPSPACE1</code>, or
   * <code>USERSPACE1</code>. These table spaces are accessible via
   * {@link #getTableSpace(TableSpace.Name)} only.</p>
   */
  public Iterator getTableSpaces();
}
