/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.db2;

import org.apache.ws.jaxme.sqls.Table;


/** <p>Interface of a table in a DB2 database.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface DB2Table extends Table {
  /** <p>Sets the {@link TableSpace}, in which the table should be
   * created physically. Null, if the database may choose a
   * {@link TableSpace}.</p>
   */
  public void setTableSpace(TableSpace pTableSpace);

  /** <p>Returns the {@link TableSpace}, in which the table should be
   * created physically. Null, if the database may choose a
   * {@link TableSpace}.</p>
   */
  public TableSpace getTableSpace();

  /** <p>Sets the {@link TableSpace}, in which the tables indexes
   * should be created physically. Null, if the tables
   * main {@link TableSpace} should be choosen.</p>
   */
  public void setIndexTableSpace(TableSpace pTableSpace);

  /** <p>Returns the {@link TableSpace}, in which the tables
   * indexes should be created physically. Null, if the tables
   * main {@link TableSpace} should be choosen.</p>
   */
  public TableSpace getIndexTableSpace();

  /** <p>Sets the {@link TableSpace}, in which the tables indexes
   * should be created physically. Null, if the tables
   * main {@link TableSpace} should be choosen.</p>
   */
  public void setLongTableSpace(TableSpace pTableSpace);

  /** <p>Returns the {@link TableSpace}, in which the tables
   * LOB data should be physically stored. Null, if the tables
   * main {@link TableSpace} should be choosen.</p>
   */
  public TableSpace getLongTableSpace();
}
