/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.db2;

/** <p>A DB2 page size is limited to certain values.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class PageSize {
   /** <p>The default page size: 4096 bytes</p>
    */
   public static final PageSize PAGESIZE_4096 = new PageSize(4096);
   /** <p>The default page size: 8192 bytes</p>
    */
   public static final PageSize PAGESIZE_8192 = new PageSize(8192);
   /** <p>The default page size: 16384 bytes</p>
    */
   public static final PageSize PAGESIZE_16384 = new PageSize(16384);
   /** <p>The default page size: 32768 bytes</p>
    */
   public static final PageSize PAGESIZE_32768 = new PageSize(32768);

   private static final PageSize[] instances = new PageSize[]{
      PAGESIZE_4096, PAGESIZE_8192, PAGESIZE_16384, PAGESIZE_32768
   };

   private long size;

   private PageSize(long pSize) {
      size = pSize;
   }
 
   public long getSize() { return size; }
   public String toString() { return "PAGESIZE_" + size; }
   public boolean equals(Object pOther) {
      return pOther != null  &&  pOther instanceof PageSize  &&
         size == ((PageSize) pOther).size;
   }
   public static PageSize[] getInstances() { return instances; }
   public static PageSize valueOf(String pSize) {
      long l;
      try {
         l = Long.parseLong(pSize);
      } catch (Exception e) {
         throw new IllegalArgumentException("PageSize is no long value: " + pSize);
      }
      return valueOf(l);
   }
   public static PageSize valueOf(long pSize) {
      for (int i = 0;  i < instances.length;  i++) {
         if (instances[i].size == pSize) {
            return instances[i];
         }
      }
      throw new IllegalArgumentException("Invalid page size: " + pSize);
   }
   public int hashCode() {
      return (int) size / 4096;
   }
}
