/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.db2;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.sqls.impl.SQLFactoryImpl;


/** <p>Default implementation of a DB2 tablespace.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class TableSpaceImpl implements TableSpace {
  public static class NameImpl extends SQLFactoryImpl.IdentImpl
      implements TableSpace.Name {
    public NameImpl(String pName) { super(pName); }
  }

  public static class SystemManagedContainerImpl implements TableSpace.SystemManagedContainer {
    private String file;
    public boolean isSystemManaged() { return true; }
    public boolean isDatabaseManaged() { return false; }
    public String getFile() { return file; }
    public void setFile(String pFile) { file = pFile; }
  }

  public static class DatabaseManagedContainerImpl implements TableSpace.DatabaseManagedContainer {
    private String file;
    private String device;
    private long numPages;
    public boolean isSystemManaged() { return false; }
    public boolean isDatabaseManaged() { return true; }
    public void setFile(String pFile) { file = pFile; }
    public String getFile() { return file; }
    public void setDevice(String pDevice) { device = pDevice; }
    public String getDevice() { return device; }
    public long getNumOfPages() { return numPages; }
    public void setNumOfPages(long pNumOfPages) { numPages = pNumOfPages; }
  }

  private DB2SQLFactory sqlFactory;
  private BufferPool bufferPool;
  private TableSpace.Name name;
  private TableSpace.Type type;
  private List containers = new ArrayList();
  private Long extentSize, prefetchSize;
  private PageSize pageSize;
  private Number overhead, transferRate;
  private Boolean droppedTableRecovery;

  protected TableSpaceImpl(DB2SQLFactory pFactory, TableSpace.Name pName,
                            TableSpace.Type pType) {
    sqlFactory = pFactory;
    name = pName;
    type = pType;
  }

  public DB2SQLFactory getSQLFactory() { return sqlFactory; }
  public TableSpace.Name getName() { return name; }
  public TableSpace.Type getType() { return type; }
  public PageSize getPageSize() {
     BufferPool bPool = getBufferPool();
     return bPool == null ? pageSize : bPool.getPageSize();
  }
  public void setPageSize(PageSize pSize) { pageSize = pSize; }
  public Long getExtentSize() { return extentSize; }
  public void setExtentSize(Long pSize) { extentSize = pSize; }
  public Long getPrefetchSize() { return prefetchSize; }
  public void setPrefetchSize(Long pSize) { prefetchSize = pSize; }
  public Number getOverhead() { return overhead; }
  public void setOverhead(Number pOverhead) { overhead = pOverhead; }
  public Number getTransferRate() { return transferRate; }
  public void setTransferRate(Number pTransferRate) { transferRate = pTransferRate; }
  public Boolean hasDroppedTableRecovery() { return droppedTableRecovery; }
  public void setDroppedTableRecovery(Boolean pRecoverable) { droppedTableRecovery = pRecoverable; }
  public boolean isPredefined() { return false; }

  public Container newSystemManagedContainer(String pFile) {
    SystemManagedContainerImpl container = new SystemManagedContainerImpl();
    container.setFile(pFile);
    containers.add(container);
    return container;
  }

  public Container newDatabaseManagedContainerInFile(String pFile, long pNumPages) {
    DatabaseManagedContainerImpl container = new DatabaseManagedContainerImpl();
    container.setFile(pFile);
    container.setNumOfPages(pNumPages);
    containers.add(container);
    return container;
  }

  public Container newDatabaseManagedContainerInDevice(String pDevice, long pNumPages) {
    DatabaseManagedContainerImpl container = new DatabaseManagedContainerImpl();
    container.setDevice(pDevice);
    container.setNumOfPages(pNumPages);
    containers.add(container);
    return container;
  }

  public Iterator getContainers() {
    return containers.iterator();
  }

  public void setBufferPool(BufferPool pBufferPool) {
    bufferPool = pBufferPool;
  }

  public BufferPool getBufferPool() {
    return bufferPool;
  }
}
