/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.impl;

import org.apache.ws.jaxme.sqls.BinaryColumn;
import org.apache.ws.jaxme.sqls.Column;
import org.apache.ws.jaxme.sqls.StringColumn;
import org.apache.ws.jaxme.sqls.Table;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public abstract class AbstractColumn implements Column, StringColumn, BinaryColumn {
  private final Column.Name name;
  private final Column.Type type;
  private boolean nullable;
  private Long length;
  private Object customData;

  protected AbstractColumn(Column.Name pName, Column.Type pType) {
    if (pName == null) {
      throw new NullPointerException("The column name must not be null.");
    }
    if (pType == null) {
      throw new NullPointerException("The column type must not be null.");
    }
    name = pName;
    type = pType;
  }

  public Column.Name getName() { return name; }
  public Column.Type getType() { return type; }
  public boolean isNullable() { return nullable; }
  public void setNullable(boolean pNullable) { nullable = pNullable; }


  public boolean equals(Object o) {
    if (o == null  ||  !(o instanceof Column)) {
      return false;
    }
    Column other = (Column) o;
    Table table = getTable();
    if (table == null) {
      if (other.getTable() != null) {
        return false;
      }
    } else {
      if (!table.equals(other.getTable())) {
        return false;
      }
    }
    return getName().equals(other.getName());
  }

  public int hashCode() {
    return getTable().hashCode() + getName().hashCode();
  }

  public boolean hasFixedLength() {
    Column.Type myType = getType();
    if (Column.Type.CHAR.equals(myType)  ||
        Column.Type.BINARY.equals(myType)) {
      return true;
    } else if (Column.Type.VARCHAR.equals(myType)
               ||  Column.Type.VARBINARY.equals(myType)
               ||  Column.Type.BLOB.equals(myType)
               ||  Column.Type.OTHER.equals(myType)
               ||  Column.Type.CLOB.equals(myType)) {
      return false;
    } else {
      throw new IllegalStateException("Invalid data type for fixed length.");
    }
  }

  public boolean isStringColumn() {
    Column.Type myType = getType();
    return Column.Type.CHAR.equals(myType) || Column.Type.VARCHAR.equals(myType) ||
            Column.Type.CLOB.equals(myType);
  }

  public boolean isBinaryColumn() {
    Column.Type myType = getType();
    return Column.Type.BINARY.equals(myType) || Column.Type.VARBINARY.equals(myType) ||
            Column.Type.BLOB.equals(myType) || Column.Type.OTHER.equals(myType);
  }

  public void setLength(Long pLength) {
    length = pLength;
  }

  public void setLength(long pLength) {
    setLength(new Long(pLength));
  }

  public Long getLength() {
    return length;
  }

  public Object getCustomData() {
    return customData;
  }

  public void setCustomData(Object pCustomData) {
    customData = pCustomData;
  }
}
