/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.sqls.Column;
import org.apache.ws.jaxme.sqls.Index;
import org.apache.ws.jaxme.sqls.Table;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class IndexImpl extends ColumnSetImpl implements Index {
  public static class NameImpl extends SQLFactoryImpl.IdentImpl implements Index.Name {
    public NameImpl(String pName) {
      super(pName);
    }
  }

  private final List columns = new ArrayList();
  private final boolean unique;
  private final boolean primaryKey;
  private Index.Name name;

	IndexImpl(Table pTable, boolean pUnique, boolean pPrimaryKey) {
      super(pTable);
      unique = pUnique;
      primaryKey = pPrimaryKey;
      if (primaryKey && !unique) {
         throw new IllegalArgumentException("A primary key must be unique.");
      }
    setName(pTable.getName() + "_" + "I" + ((TableImpl) pTable).indexNameCounter++);
  }

  public void setName(Index.Name pName) {
    if (pName == null) {
      throw new NullPointerException("An index name must not be null.");
    }
    name = pName;
  }

  public void setName(String pName) {
    if (pName == null) {
      throw new NullPointerException("An index name must not be null.");
    }
    setName(new IndexImpl.NameImpl(pName));
  }

  public Index.Name getName() {
    return name;
	}

	public void addColumn(Column pColumn) {
      if (columns.contains(pColumn)) {
         throw new IllegalStateException("The column " + pColumn.getName() + " was already added to the key.");
      }
      columns.add(pColumn);
	}

   public void addColumn(Column.Name pName) {
      Column column = getTable().getColumn(pName);
      if (column == null) {
         throw new NullPointerException("The table " + getTable().getName() + " doesn't contain a column " + pName);
      }
      addColumn(column);
   }

   public void addColumn(String pName) {
      addColumn(new ColumnImpl.NameImpl(pName));
   }

	public boolean isUnique() {
      return unique;
	}

	public boolean isPrimaryKey() {
      return primaryKey;
	}

   public Iterator getColumns() {
      return columns.iterator();
   }
}
