/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.sqls.SQLFactory;
import org.apache.ws.jaxme.sqls.Schema;
import org.apache.ws.jaxme.sqls.Table;


/** <p>Implementation of a schema.</p>
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class SchemaImpl implements Schema {
   public static class NameImpl extends SQLFactoryImpl.IdentImpl implements Schema.Name {
      NameImpl(String pName) {
         super(pName);
      }
      public boolean equals(Object o) {
         if (o == null  ||  !(o instanceof Schema.Name)) {
            return false;
         }
         return super.equals(o);
      }
   }

   private SQLFactory sqlFactory;
   private Schema.Name name;
   private List tables = new ArrayList();

   /** <p>Creates a new instance of SchemaImpl.</p>
    * @param pFactory The {@link org.apache.ws.jaxme.sqls.SQLFactory}
    *   creating this instance.
    * @param pName The schema name.
    */
	protected SchemaImpl(SQLFactory pFactory, Schema.Name pName) {
      sqlFactory = pFactory;
      name = pName;      
	}

   public SQLFactory getSQLFactory() {
      return sqlFactory;
   }

   public Schema.Name getName() {
      return name;
   }

   public Table newTable(String pName) {
      return newTable(new TableImpl.NameImpl(pName));
   }

	public Table newTable(Table.Name pName) {
      if (pName == null) {
         throw new NullPointerException("A table name must not be null.");
      }
      Integer maxLength = getSQLFactory().getMaxTableNameLength();
      if (maxLength != null  &&  pName.getName().length() > maxLength.intValue()) {
         throw new IllegalArgumentException("The length of the table name " + pName +
                                             " exceeds the maximum length of " + maxLength);
      }
      Table table = getTable(pName);
      if (table != null) {
         throw new IllegalStateException("A table named " + table.getName() +
                                          " already exists in the schema " + getName());
      }
      table = ((SQLFactoryImpl) getSQLFactory()).newTableImpl(this, pName);
      tables.add(table);
      return table;
   }

	public Table getTable(Table.Name pName) {
      if (pName == null) {
         throw new NullPointerException("A table name must not be null.");
      }
      for (Iterator iter = getTables();  iter.hasNext();  ) {
         Table table = (Table) iter.next();
         if (getSQLFactory().isTableNameCaseSensitive()) {
            if (pName.getName().equalsIgnoreCase(table.getName().getName())) {
               return table;
            }
         } else {
            if (pName.equals(table.getName())) {
               return table; 
            }
         }
      }
      return null;
	}

   public Table getTable(String pName) {
      return getTable(new TableImpl.NameImpl(pName));
   }

	public Iterator getTables() {
      return tables.iterator();
	}

   public boolean equals(Object o) {
      if (o == null  ||  !(o instanceof Schema)) {
         return false;
      }
      Schema other = (Schema) o;
      if (getName() == null) {
         return other.getName() == null;
      } else {
         return getName().equals(other.getName());
      }
   }

   public int hashCode() {
      return getName() == null ? 0 : getName().hashCode();
   }
}
