/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.impl;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.sqls.ColumnReference;
import org.apache.ws.jaxme.sqls.SQLFactory;
import org.apache.ws.jaxme.sqls.SelectStatement;
import org.apache.ws.jaxme.sqls.SelectTableReference;
import org.apache.ws.jaxme.sqls.Table;
import org.apache.ws.jaxme.sqls.TableReference;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class SelectStatementImpl extends ConstrainedStatementImpl implements SelectStatement {
   public static class OrderColumnImpl implements SelectStatement.OrderColumn {
      private ColumnReference columnReference;
      private boolean descending;
      public OrderColumnImpl(ColumnReference pColumnReference, boolean pDescending) {
         columnReference = pColumnReference;
         descending = pDescending;
      }
      public ColumnReference getColumn() {
         return columnReference;
      }
      public boolean isDescending() {
         return descending;
      }
   }

   private List orderColumns = new ArrayList();
   private List resultColumns = new ArrayList();
   private boolean distinct;
   private int maxRows, skippedRows;

	/** <p>Creates a new SelectStatement and sets the creating
   * {@link org.apache.ws.jaxme.sqls.SQLFactory}.</p>
	 */
	public SelectStatementImpl(SQLFactory pFactory) {
		super(pFactory);
	}

	public void addOrderColumn(ColumnReference pColumn) {
      addOrderColumn(pColumn, false);
	}

	public void addOrderColumn(ColumnReference pColumn, boolean pDescending) {
      addOrderColumn(new OrderColumnImpl(pColumn, pDescending));
	}

   public void addOrderColumn(SelectStatement.OrderColumn pColumn) {
      for (Iterator iter = orderColumns.iterator();  iter.hasNext();  ) {
         SelectStatement.OrderColumn column = (SelectStatement.OrderColumn) iter.next();
         if (column.getColumn().equals(pColumn)  &&
             pColumn.getColumn().getTableReference() == column.getColumn().getTableReference()) {
           throw new NullPointerException("The column " + pColumn.getColumn().getColumn().getName() +
                                           " is  already used for sorting.");
         }
      }
      orderColumns.add(pColumn);
   }

	public void addResultColumn(ColumnReference pColumn) {
      resultColumns.add(pColumn);
	}

   public Iterator getResultColumns() {
      return resultColumns.iterator();
   }

	public void setDistinct(boolean pDistinct) {
      distinct = pDistinct;
	}

	public boolean isDistinct() {
      return distinct;
	}

	public void setMaxRows(int pMaxRows) {
      maxRows = pMaxRows;
	}

	public int getMaxRows() {
      return maxRows;
	}

	public void setSkippedRows(int pSkippedRows) {
      skippedRows = pSkippedRows;
	}

	public int getSkippedRows() {
      return skippedRows;
	}

   protected TableReference newTableReference(Table pTable) {
      return new SelectTableReferenceImpl(this, pTable);
   }

   public SelectTableReference getSelectTableReference() {
      return (SelectTableReference) getTableReference();
   }

   public Iterator getSelectTableReferences() {
      return new Iterator() {
         SelectTableReference reference = getSelectTableReference();
         public boolean hasNext() { return reference != null; }
         public Object next() {
            SelectTableReference result = reference;
            reference = result.getRightJoinedTableReference();
            return result;
         }
         public void remove() {
            throw new UnsupportedOperationException();
         }
      };
   }
}
