/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.impl;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.sqls.Column;
import org.apache.ws.jaxme.sqls.ColumnReference;
import org.apache.ws.jaxme.sqls.SQLFactory;
import org.apache.ws.jaxme.sqls.SetStatement;
import org.apache.ws.jaxme.sqls.Value;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public abstract class SetStatementImpl extends StatementImpl implements SetStatement {
  public static class SetValueImpl implements SetStatement.SetValue {
    private final ColumnReference columnReference;
    private final Value value;
    public SetValueImpl(ColumnReference pColumn, Value pValue) {
      if (pColumn == null) {
        throw new NullPointerException("Column reference must not be null.");
      }
      if (pValue == null) {
        throw new NullPointerException("Value must not be null.");
      }
      columnReference = pColumn;
      value = pValue;
    }

    public ColumnReference getColumnReference() { return columnReference; }
    public Value getValue() { return value; }
  }

  private List setValues = new ArrayList();

  protected SetStatementImpl(SQLFactory pFactory) {
    super(pFactory);
  }

  public Iterator getSetValues() { return setValues.iterator(); }

  public void addSet(ColumnReference pColumn, Value pValue) {
    if (!pColumn.getTableReference().equals(getTableReference())) {
      throw new IllegalArgumentException("The column has an invalid table reference.");
    }
    setValues.add(new SetValueImpl(pColumn, pValue));
  }
  public void addSet(Column pColumn, Value pValue) {
    setValues.add(new SetValueImpl(getTableReference().newColumnReference(pColumn), pValue));
  }
  public void addSet(Column.Name pColumn, Value pValue) {
    setValues.add(new SetValueImpl(getTableReference().newColumnReference(pColumn), pValue));
  }
  public void addSet(String pColumn, Value pValue) {
    setValues.add(new SetValueImpl(getTableReference().newColumnReference(pColumn), pValue));
  }

  public void addSetNull(Column pColumn) {
    addSet(pColumn, new ValueImpl(Value.Type.NULL, null));
  }
  public void addSetNull(Column.Name pColumn) {
    addSet(pColumn, new ValueImpl(Value.Type.NULL, null));
  }
  public void addSetNull(String pColumn) {
    addSet(pColumn, new ValueImpl(Value.Type.NULL, null));
  }

  public void addSet(Column pColumn) {
    if (pColumn == null) {
      throw new NullPointerException("The column being set must not be null.");
    }
    addSet(pColumn, new ValueImpl(Value.Type.PLACEHOLDER, null));
  }
  public void addSet(Column.Name pColumn) {
    addSet(pColumn, new ValueImpl(Value.Type.PLACEHOLDER, null));
  }
  public void addSet(String pColumn) {
    addSet(pColumn, new ValueImpl(Value.Type.PLACEHOLDER, null));
  }

  public void addSet(Column pColumn, byte pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.BYTE, new Byte(pValue)));
  }
  public void addSet(Column.Name pColumn, byte pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.BYTE, new Byte(pValue)));
  }
  public void addSet(String pColumn, byte pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.BYTE, new Byte(pValue)));
  }

  public void addSet(Column pColumn, short pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.SHORT, new Short(pValue)));
  }
  public void addSet(Column.Name pColumn, short pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.SHORT, new Short(pValue)));
  }
  public void addSet(String pColumn, short pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.SHORT, new Short(pValue)));
  }

  public void addSet(Column pColumn, int pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.INT, new Integer(pValue)));
  }
  public void addSet(Column.Name pColumn, int pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.INT, new Integer(pValue)));
  }
  public void addSet(String pColumn, int pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.INT, new Integer(pValue)));
  }

  public void addSet(Column pColumn, long pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.LONG, new Long(pValue)));
  }
  public void addSet(Column.Name pColumn, long pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.LONG, new Long(pValue)));
  }
  public void addSet(String pColumn, long pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.LONG, new Long(pValue)));
  }

  public void addSet(Column pColumn, float pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.FLOAT, new Float(pValue)));
  }
  public void addSet(Column.Name pColumn, float pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.FLOAT, new Float(pValue)));
  }
  public void addSet(String pColumn, float pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.FLOAT, new Float(pValue)));
  }

  public void addSet(Column pColumn, boolean pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.BOOLEAN, pValue ? Boolean.TRUE : Boolean.FALSE));
  }
  public void addSet(Column.Name pColumn, boolean pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.BOOLEAN, pValue ? Boolean.TRUE : Boolean.FALSE));
  }
  public void addSet(String pColumn, boolean pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.BOOLEAN, pValue ? Boolean.TRUE : Boolean.FALSE));
  }

  public void addSet(Column pColumn, String pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.STRING, pValue));
  }
  public void addSet(Column.Name pColumn, String pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.STRING, pValue));
  }
  public void addSet(String pColumn, String pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.STRING, pValue));
  }

  public void addSetDateTime(Column pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.DATETIME, pValue));
  }
  public void addSetDateTime(Column.Name pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.DATETIME, pValue));
  }
  public void addSetDateTime(String pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.DATETIME, pValue));
  }

  public void addSetTime(Column pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.TIME, pValue));
  }
  public void addSetTime(Column.Name pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.TIME, pValue));
  }
  public void addSetTime(String pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.TIME, pValue));
  }

  public void addSetDate(Column pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.DATE, pValue));
  }
  public void addSetDate(Column.Name pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.DATE, pValue));
  }
  public void addSetDate(String pColumn, Calendar pValue) {
    addSet(pColumn, new ValueImpl(Value.Type.DATE, pValue));
  }
}
