package org.apache.ws.jaxme.sqls.impl;

import org.apache.ws.jaxme.sqls.Column;
import org.apache.ws.jaxme.sqls.ColumnReference;
import org.apache.ws.jaxme.sqls.Table;
import org.apache.ws.jaxme.sqls.TableReference;


/** <p>A virtual column is a named item that can be added
 * to the result set. For example:</p>
 * <pre>
 *   SELECT name, vorname, MAX(a) AS max FROM ...
 * </pre>
 * <p>The example uses a virtual column max. The value of
 * max is calculated from other values.</p>
 *
 * @author <a href="mailto:jwi@softwareag.com">Jochen Wiedmann</a>
 */
public class VirtualColumn extends AbstractColumn implements ColumnReference {
  private Column.Name alias;
  private String value;

  public VirtualColumn(Column.Name pName, Column.Type pType) {
    super(pName, pType);
  }

  public VirtualColumn(String pName, Column.Type pType) {
    super(new ColumnImpl.NameImpl(pName), pType);
  }

  public Table getTable() { return null; }
  public String getQName() { return getName().toString(); }
  public boolean isPrimaryKeyPart() { return false; }
  public TableReference getTableReference() { return null; }
  public Column getColumn() { return this; }
  public boolean isVirtual() { return true; }

  public void setAlias(String pName) {
    setAlias(new ColumnImpl.NameImpl(pName));
  }

  public void setAlias(Name pName) {
    alias = pName;
  }

  public Name getAlias() {
    return alias;
  }

  public void setValue(String pValue) {
    value = pValue;
  }

  public String getValue() {
    return value;
  }
}
