/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.sqls.oracle;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.ws.jaxme.sqls.ColumnReference;
import org.apache.ws.jaxme.sqls.JoinReference;
import org.apache.ws.jaxme.sqls.SelectStatement;
import org.apache.ws.jaxme.sqls.SelectTableReference;
import org.apache.ws.jaxme.sqls.impl.SQLGeneratorImpl;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class OraSQLGeneratorImpl extends SQLGeneratorImpl implements OraSQLGenerator {
  private boolean isOracle8Compatibility;

  protected boolean isTableAliasUsingAs() { return false; }

  /** <p>Enables compatibility mode for Oracle 8.</p>
   */
  public void setOracle8Compatibility(boolean pOracle8Compatibility) {
    isOracle8Compatibility = pOracle8Compatibility;
  }

  /** <p>Returns whether compatibility mode for Oracle 8 is enabled.</p>
   */
  public boolean isOracle8Compatibility() {
    return isOracle8Compatibility;
  }

  protected String getSelectQuery(SelectStatement pQuery, SQLGeneratorImpl.SelectStatementMetaData pData) {
    if (!isOracle8Compatibility()) {
      return super.getSelectQuery(pQuery, pData);
    }

    StringBuffer sb = new StringBuffer("SELECT");
    if (pQuery.isDistinct()) {
      sb.append(" DISTINCT");
    }

    Iterator columnIter = pQuery.getResultColumns();
    if (!columnIter.hasNext()) {
      sb.append(" *");
    } else {
      boolean first = true;
      do {
        ColumnReference column = (ColumnReference) columnIter.next();
        if (first) {
          sb.append(" ");
          first = false;
        } else {
          sb.append(", ");
        }
        sb.append(getColumnAlias(pData, column));
      } while (columnIter.hasNext());
    }

    SelectTableReference selectTableReference = pQuery.getSelectTableReference();
    List whereClauses = new ArrayList();
    if (selectTableReference != null) {
      sb.append(" FROM ");
      sb.append(getTableAlias(selectTableReference));
      for (JoinReference joinReference = selectTableReference.getRightJoinedTableReference();
           joinReference != null;
           joinReference = joinReference.getRightJoinedTableReference()) {
        sb.append(", ");
        sb.append(getTableAlias(joinReference));
        OraJoinReferenceImpl oraJoin = null;
        if (joinReference instanceof OraJoinReferenceImpl) {
          oraJoin = (OraJoinReferenceImpl) joinReference;
        }
        if (oraJoin != null) {
          oraJoin.setIsOracle8LeftOuterJoin(true);
        }
        String onClause = getWhereClause(pData, joinReference.getOn());
        if (oraJoin != null) {
          oraJoin.setIsOracle8LeftOuterJoin(false);
        }
        whereClauses.add(onClause);
      }
    }

    String whereClause = getWhereClause(pData, pQuery.getWhere());
    if (whereClause != null) {
      whereClauses.add(whereClause);
    }

    for (int i = 0;  i < whereClauses.size();  i++) {
      if (i == 0) {
        sb.append(" WHERE ");
      } else {
        sb.append(" AND ");
      }
      sb.append(whereClauses.get(i));
    }
    
    return sb.toString();
  }

  protected String getColumnAlias(SelectStatementMetaData pData, ColumnReference pColumn) {
    String s = super.getColumnAlias(pData, pColumn);
    if (pColumn.getTableReference() instanceof OraJoinReferenceImpl) {
      OraJoinReferenceImpl oraJoin = (OraJoinReferenceImpl) pColumn.getTableReference();
      if (oraJoin.isOracle8LeftOuterJoin()) {
        return s + "(+)";
      }
    }
    return s;
  }
}
