/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.pm.impl;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import javax.xml.bind.Element;
import javax.xml.bind.JAXBException;

import org.apache.ws.jaxme.JMManager;
import org.apache.ws.jaxme.PMException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public abstract class PMIdImpl extends PMImpl {
  private static final Class[] ZERO_CLASSES = new Class[0];
  private static final Object[] ZERO_OBJECTS = new Object[0];
  private String getIdMethodName;

  public void init(JMManager pManager) throws JAXBException {
    String methodName = pManager.getProperty("xmldb.getIdMethodName");
    if (methodName == null  ||  methodName.length() == 0) {
      throw new JAXBException("Missing property: 'xmldb.getIdMethodName' (method name for reading the object ID)");
    }
    setGetIdMethodName(methodName);
  }

  /** <p>Sets the name of the method fetching the object ID.</p>
   */
  public void setGetIdMethodName(String pProperty) {
    getIdMethodName = pProperty;
  }

  /** <p>Returns the name of the method fetching the object ID.</p>
   */
  public String getGetIdMethodName() {
    return getIdMethodName;
  }

  protected String getId(Element pElement)
      throws NoSuchMethodException, IllegalAccessException, InvocationTargetException,
              PMException {
    String getMethodName = getGetIdMethodName();
    Method m = pElement.getClass().getMethod(getMethodName, ZERO_CLASSES);
    Object o = m.invoke(pElement, ZERO_OBJECTS);
    if (o == null) {
      throw new PMException("The method " + getMethodName + " returned null, which is no valid ID.");
    }
    return o.toString();
  }
}
