/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.webapp;

import java.io.File;

import javax.servlet.ServletException;
import javax.servlet.UnavailableException;
import javax.servlet.http.HttpServlet;


public abstract class BaseServlet extends HttpServlet {
	private static File workDir;
	
	public File getWorkDir() {
		return workDir;
	}

	public void cleanDirectory(File pDirectory) throws ServletException {
		File[] files = pDirectory.listFiles();
		for (int i = 0;  i < files.length;  i++) {
			File f = files[i];
			if (f.isFile()) {
				if (!f.delete()) {
					throw new UnavailableException("Unable to delete file " + f.getAbsolutePath());
				}
			} else if (f.isDirectory()) {
				cleanDirectory(f);
				if (!f.delete()) {
					throw new UnavailableException("Unable to delete directory " + f.getAbsolutePath());
				}
			} else {
				throw new UnavailableException("Unable to determine how to remove " + f.getAbsolutePath());
			}
		}
	}

	public void createDirectory(File pDirectory) throws ServletException {
		if (!pDirectory.mkdir()) {
			throw new UnavailableException("Unable to create working directory " + pDirectory);
		}
	}

	public void init() throws ServletException {
		synchronized (BaseServlet.class) {
			if (workDir == null) {
				String p = getServletContext().getInitParameter("http.proxyHost");
				if (p != null  &&  p.length() > 0) {
					String v = getServletContext().getInitParameter("http.proxyPort");
					if (v != null  &&  v.length() > 0) {
						log("http.proxyHost parameter detected, setting host=" + p + ", port=" + v);
						System.setProperty("http.proxyHost", p);
						System.setProperty("http.proxyPort", v);
					} else {
						throw new UnavailableException("The http.proxyHost parameter is set, but the http.proxyPort parameter is not set.");
					}
				} else {
					log("http.proxyHost parameter is not set");
				}
				String s = getServletContext().getInitParameter("work.dir");
				File f;
				if (s == null  ||  s.length() == 0) {
					s = System.getProperty("java.io.tmpdir");
					if (s == null  ||  s.length() == 0) {
						throw new UnavailableException("Neither the servlet context parameter work.dir nor the system property java.io.tmpdir are set.");
					}
					f = new File(s);
					if (!f.isDirectory()) {
						throw new UnavailableException("The directory " + s + " (specified by the system property java.io.tmpdir) does not exist.");
					}
				} else {
					f = new File(s);
					if (!f.isDirectory()) {
						throw new UnavailableException("The directory " + s + " (specified by the servlet context parameter work.dir) does not exist.");
					}
				}

				File g = new File(f, "jaxme");
				if (g.isDirectory()) {
					cleanDirectory(g);
				} else {
					createDirectory(g);
				}
				workDir = g;
			}
		}
	}
}
