/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs;

import org.apache.ws.jaxme.xs.xml.*;


/** <p>Details of a complex type.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSComplexType {
  /** <p>Returns whether the complex type has simple content. If so,
   * you may use the method {@link #getSimpleContent()} to fetch the
   * simple contents type. If not, you may use
   * {@link #getComplexContentType()}, {@link #isEmpty()},
   * {@link #isElementOnly()}, {@link #isMixed()}, and
   * {@link #getParticle()}. The method {@link #getAttributes()}
   * is always valid.</p>
   */
  public boolean hasSimpleContent();

  /** <p>If the complex type has simple content, returns the contents
   * type. This is, of course, a simple type.</p>
   */
  public XSSimpleContentType getSimpleContent();

  /** <p>If the element hasn't simple content: Returns the element contents
   * type.</p>
   * @throws IllegalStateException The element does not have
   *   complex content
   * @see XsComplexContentType#EMPTY
   * @see XsComplexContentType#ELEMENT_ONLY
   * @see XsComplexContentType#MIXED
   * @see #isEmpty()
   * @see #isElementOnly()
   * @see #isMixed()
   */
  public XsComplexContentType getComplexContentType();

  /** <p>If the element hasn't simple content: Returns whether the
   * elements content is empty. Shortcut for
   * <code>getComplexContentType().equals(EMPTY)</code>.</p>
   * @throws IllegalStateException The element does not have
   *   complex content
   * @see XsComplexContentType#EMPTY
   */
  public boolean isEmpty();

  /** <p>If the element hasn't simple content: Returns whether the
   * elements content is elementOnly. Shortcut for
   * <code>getComplexContentType().equals(ELEMENT_ONLY)</code>.</p>
   * @throws IllegalStateException The element does not have
   *   complex content
   * @see XsComplexContentType#ELEMENT_ONLY
   */
  public boolean isElementOnly();

  /** <p>If the element hasn't simple content: Returns whether the
   * elements content is mixed. Shortcut for
   * <code>getComplexContentType().equals(MIXED)</code>.</p>
   * @throws IllegalStateException The element does not have
   *   complex content
   * @see XsComplexContentType#MIXED
   */
  public boolean isMixed();

  /** <p>If the element hasn't simple content: Returns the complex
   * elements particle.</p>
   * @throws IllegalStateException The element has simple content
   */
  public XSParticle getParticle();

  /** <p>Returns the complex types attributes.</p>
   */
  public XSAttributable[] getAttributes();

  /** <p>Returns whether the element is a extension of another element.</p>
   */
  public boolean isExtension();

  /** <p>If the element is an extension: Returns the extended type.</p>
   * @throws IllegalStateException The element is no extension.
   */
  public XSType getExtendedType();

  /** <p>Returns whether the element is a restriction of another element.</p>
   */
  public boolean isRestriction();

  /** <p>If the element is an restriction: Returns the restricted type.</p>
   * @throws IllegalStateException The element is no restriction.
   */
  public XSType getRestrictedType();
}
