/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs;

import org.xml.sax.Locator;
import org.xml.sax.SAXException;


/** <p>Interface of a model group. A model group is, for example,
 * defined by an <code>xs:group</code> element, or by a complex type
 * without simpleContent or complexContent.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSModelGroup {
  public class Compositor {
    private String name;
    Compositor(String pName) {
      name = pName;
    }
    public String toString() { return name; }
    public boolean equals(Object o) {
      return o != null  &&  o instanceof Compositor  &&  ((Compositor) o).name.equals(name);
    }
    public int hashCode() { return name.hashCode(); }
  }

  /** <p>The sequence compositor.</p>
   */
  public static final Compositor SEQUENCE = new Compositor("sequence");

  /** <p>The choice compositor.</p>
   */
  public static final Compositor CHOICE = new Compositor("choice");

  /** <p>The all compositor.</p>
   */
  public static final Compositor ALL = new Compositor("all");

  /** <p>Returns the model groups compositor.</p>
   */
  public Compositor getCompositor();

  /** <p>Shortcut for <code>getCompositor().equals(SEQUENCE)</code>.</p>
   * @see #getCompositor()
   * @see #SEQUENCE
   */
  public boolean isSequence();

  /** <p>Shortcut for <code>getCompositor().equals(CHOICE)</code>.</p>
   * @see #getCompositor()
   * @see #CHOICE
   */
  public boolean isChoice();

  /** <p>Shortcut for <code>getCompositor().equals(ALL)</code>.</p>
   * @see #getCompositor()
   * @see #ALL
   */
  public boolean isAll();

  /** <p>Returns the model groups particles.</p>
   */
  public XSParticle[] getParticles();

  /** <p>Returns the model groups locator.</p>
   */
  public Locator getLocator();

  /** <p>Validates the particles contents.</p>
   */
  public void validate() throws SAXException;
}
