/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs;

import org.apache.ws.jaxme.xs.impl.XSLogicalParser;
import org.apache.ws.jaxme.xs.parser.XSContext;
import org.apache.ws.jaxme.xs.xml.*;
import org.xml.sax.SAXException;


/** <p>An object factory for the logical XSParser.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSObjectFactory {
  /** <p>Returns a new instance of {@link XSLogicalParser}.</p>
   */
  public XSLogicalParser newXSLogicalParser();
  /** <p>Returns a new instance of {@link XSSchema}.</p>
   */
  public XSSchema newXSSchema(XSContext pContext, XsESchema pSchema) throws SAXException;
  /** <p>Returns a new instance of {@link XSAnnotation}.</p>
   */
  public XSAnnotation newXSAnnotation(XSObject pParent, XsEAnnotation pAnnotation) throws SAXException;
  /** <p>Returns a new instance of {@link XSAppinfo}.</p>
   */
  public XSAppinfo newXSAppinfo(XSObject pParent, XsEAppinfo pAppinfo);
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSAtomicType(XSType pParent, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSAtomicType(XSType pParent, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException;
  /** <p>Returns a new instance of {@link XSAttribute}.</p>
   */
  public XSAttribute newXSAttribute(XSObject pParent, XsTAttribute pAttribute) throws SAXException;
  /** <p>Returns a new instance of {@link XSAttributeGroup}.</p>
   */
  public XSAttributeGroup newXSAttributeGroup(XSObject pParent, XsTAttributeGroup pGroup) throws SAXException;
  /** <p>Returns a new instance of {@link XSDocumentation}.</p>
   */
  public XSDocumentation newXSDocumentation(XSObject pParent, XsEDocumentation pDocumentation) throws SAXException;
  /** <p>Returns a new instance of {@link XSElement}.</p>
   */
  public XSElement newXSElement(XSObject pParent, XsTElement pElement) throws SAXException;
  /** <p>Returns a new instance of {@link XSEnumeration}.</p>
   */
  public XSEnumeration newXSEnumeration(XSObject pParent, XsEEnumeration pEnumeration) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSListType(XSType pParent, XsEList pList) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSListType(XSType pParent, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSListType(XSType pParent, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException;
  /** <p>Returns a new instance of {@link XSGroup}.</p>
   */
  public XSGroup newXSGroup(XSObject pParent, XsTNamedGroup pGroup) throws SAXException;
  /** <p>Returns a new instance of {@link XSGroup}.</p>
   */
  public XSGroup newXSGroup(XSObject pParent, XsTAll pAll) throws SAXException;
  /** <p>Returns a new instance of {@link XSGroup}.</p>
   */
  public XSGroup newXSGroup(XSObject pParent, XsTGroupRef pGroup) throws SAXException;
  /** <p>Returns a new instance of {@link XSGroup}.</p>
   */
  public XSGroup newXSGroup(XSObject pParent, XsEChoice pChoice) throws SAXException;
  /** <p>Returns a new instance of {@link XSGroup}.</p>
   */
  public XSGroup newXSGroup(XSObject pParent, XsESequence pSequence) throws SAXException;
  /** <p>Returns a new instance of {@link XSType}.</p>
   */
  public XSType newXSType(XSObject pParent, XsETopLevelSimpleType pType) throws SAXException;
  /** <p>Returns a new instance of {@link XSType}.</p>
   */
  public XSType newXSType(XSObject pParent, XsTComplexType pType) throws SAXException;
  /** <p>Returns a new instance of {@link XSType}.</p>
   */
  public XSType newXSType(XSObject pParent, XsTLocalComplexType pType) throws SAXException;
  /** <p>Returns a new instance of {@link XSType}.</p>
   */
  public XSType newXSType(XSObject pParent, XsTLocalSimpleType pType) throws SAXException;
  /** <p>Returns a new instance of {@link XSType}.</p>
   */
  public XSType newXSType(XSObject pParent, XsTSimpleRestrictionType pType) throws SAXException;
  /** <p>Returns a new instance of {@link XSNotation}.</p>
   */
  public XSNotation newXSNotation(XSObject pParent, XsENotation pType) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleContentType}.</p>
   */
  public XSSimpleContentType newXSSimpleContentType(XSType pComplexType, XSType pSimpleType, XsObject pBaseObject) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSUnionType(XSType pParent, XsEUnion pUnion) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSUnionType(XSType pParent, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException;
  /** <p>Returns a new instance of {@link XSSimpleType}.</p>
   */
  public XSSimpleType newXSUnionType(XSType pParent, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException;
  /** <p>Returns a new instance of {@link XSWildcard}.</p>
   */
  public XSWildcard newXSWildcard(XSObject pParent, XsTWildcard pWildcard) throws SAXException;
  /** <p>Returns a new instance of {@link XSAny}.</p>
   */
  public XSAny newXSAny(XSObject pParent, XsEAny pAny) throws SAXException;
}
