/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs;

import org.xml.sax.Locator;


/** <p>Interface of a model groups particle.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSParticle {
  public class Type {
    private final String name;
    public Type(String pName) {
      name = pName;
    }
    public String toString() { return name; }
    public boolean equals(Object o) {
      return o != null  &&  o instanceof Type  &&  ((Type) o).name.equals(name);
    }
    public int hashCode() { return name.hashCode(); }
  }

  /** <p>The particle type "group".</p>
   */
  public Type GROUP = new Type("group");

  /** <p>The particle type "wildcard".</p>
   */
  public Type WILDCARD = new Type("wildcard");

  /** <p>The particle type "element".</p>
   */
  public Type ELEMENT = new Type("element");

  /** <p>Returns the particle type.</p>
   */
  public Type getType();

  /** <p>Shortcut for <code>getType().equals(GROUP)</code>.</p>
   * @see #getType()
   * @see #GROUP
   */
  public boolean isGroup();

  /** <p>If the particle type is group: Returns the group.</p>
   * @throws IllegalStateException {@link #isGroup()} returns false
   */
  public XSGroup getGroup();

  /** <p>Shortcut for <code>getType().equals(WILDCARD)</code>.</p>
   * @see #getType()
   * @see #WILDCARD
   */
  public boolean isWildcard();

  /** <p>If the particle type is wildcard: Returns the wildcard.</p>
   * @throws IllegalStateException {@link #isWildcard()} returns false
   */
  public XSAny getWildcard();

  /** <p>Shortcut for <code>getType().equals(ELEMENT)</code>.</p>
   * @see #getType()
   * @see #ELEMENT
   */
  public boolean isElement();

  /** <p>If the particle type is element: Returns the element.</p>
   * @throws IllegalStateException {@link #isElement()} returns false
   */
  public XSElement getElement();

  /** <p>Returns the particles minOccurs value.</p>
   */
  public int getMinOccurs();

  /** <p>Returns the particles maxOccurs value or -1 for unbounded.</p>
   */
  public int getMaxOccurs();

  /** <p>Returns the particles Locator.</p>
   */
  public Locator getLocator();
}
