/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs;

import org.apache.ws.jaxme.xs.parser.XSContext;
import org.apache.ws.jaxme.xs.xml.XsQName;
import org.xml.sax.SAXException;

/** <p>This interface is what you are probably most interested in: The
 * logical XML Schema representation.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSSchema extends XSOpenAttrs {
  /** <p>Returns the schemas object factory.</p>
   */
  public XSObjectFactory getXSObjectFactory();

  /** <p>Returns the schemas context.</p>
   */
  public XSContext getContext();

  /** <p>Returns the array of annotations.</p>
   */
  public XSAnnotation[] getAnnotations();

  /** <p>Returns the array of global types. This includes simple
   * and complex types. The builtin types are not included.</p>
   * @see #getType(XsQName)
   */
  public XSType[] getTypes();

  /** <p>Returns the array of builtin types. This includes simple
   * and complex types.</p>
   * @see #getTypes()
   */
  public XSType[] getBuiltinTypes();

  /** <p>Returns the type with the given name. This may be a builtin
   * type or a type defined by the schema.</p>
   */
  public XSType getType(XsQName pName);

  /** <p>Returns the array of global groups.</p>
   */
  public XSGroup[] getGroups();

  /** <p>Returns the group with the given name.</p>
   */
  public XSGroup getGroup(XsQName pName);

  /** <p>Returns the array of global attribute groups.</p>
   */
  public XSAttributeGroup[] getAttributeGroups();

  /** <p>Returns the attribute group with the given name.</p>
   */
  public XSAttributeGroup getAttributeGroup(XsQName pName);

  /** <p>Returns the array of global elements.</p>
   */
  public XSElement[] getElements();

  /** <p>Returns the element with the given name.</p>
   */
  public XSElement getElement(XsQName pName);

  /** <p>Returns the array of global attributes.</p>
   */
  public XSAttribute[] getAttributes();

  /** <p>Returns the attribute with the given name.</p>
   */
  public XSAttribute getAttribute(XsQName pName);

  /** <p>Returns all the schema annotations, types, groups,
   * attribute groups, elements, and attributes, in the
   * order of declaration.</p>
   */
  public Object[] getChilds();

  /** <p>Adds a new annotation to the schema.</p>
   */
  public void add(XSAnnotation pAnnotation);

  /** <p>Adds a new type to the schema.</p>
   */
  public void add(XSType pType) throws SAXException;

  /** <p>Redefines an existing type in the schema.</p>
   */
  public void redefine(XSType pType) throws SAXException;

  /** <p>Adds a new group to the schema.</p>
   */
  public void add(XSGroup pGroup) throws SAXException;

  /** <p>Redefines an existing group in the schema.</p>
   */
  public void redefine(XSGroup pGroup) throws SAXException;

  /** <p>Adds a new attribute group to the schema.</p>
   */
  public void add(XSAttributeGroup pGroup) throws SAXException;

  /** <p>Redefines an existing attribute group in the schema.</p>
   */
  public void redefine(XSAttributeGroup pGroup) throws SAXException;

  /** <p>Adds a new attribute to the schema.</p>
   */
  public void add(XSAttribute pAttribute) throws SAXException;

  /** <p>Adds a new element to the schema.</p>
   */
  public void add(XSElement pElement) throws SAXException;

  /** <p>Adds a new notation to the schema.</p>
   */
  public void add(XSNotation pNotation) throws SAXException;
}
