/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs;


/** <p>Details of a simple type.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSSimpleType {
  /** <p>Returns whether the simple type is atomic.</p>
   */
  public boolean isAtomic();
  /** <p>Returns the atomic type details.</p>
   * @throws IllegalStateException The type is a list or union.
   */
  public XSAtomicType getAtomicType();
  /** <p>Returns whether the simple type is a list.</p>
   */
  public boolean isList();
  /** <p>Returns the list type details.</p>
   * @throws IllegalStateException The type is atomic or a union.
   */
  public XSListType getListType();
  /** <p>Returns whether the simple type is a union.</p>
   */
  public boolean isUnion();
  /** <p>Returns the union type details.</p>
   * @throws IllegalStateException The type is atomic or a list.
   */
  public XSUnionType getUnionType();

  /** <p>Returns the value of the "pattern" facet or null, if the pattern has not been set.</p>
   * <p>The returned value is an array of pattern arrays. The latter arrays are the
   * patterns defined in one restriction step. These have to be combined by "OR".
   * The resulting, combined arrays are being grouped by an "AND". This is according to
   * <a href="http://www.w3.org/TR/xmlschema-2/index.html#rf-pattern">
   *   http://www.w3.org/TR/xmlschema-2/index.html#rf-pattern, 4.3.4.3</a>.</p>
   */
  public String[][] getPattern();

  /** <p>Returns the values of the "enumeration" facets.</p>
   */
  public XSEnumeration[] getEnumerations();

  /** <p>Returns whether the type is a restriction of another
   * simple type. (Almost all simple types are, the exception being
   * the ur type {@link org.apache.ws.jaxme.xs.types.XSAnySimpleType}.</p>
   */
  public boolean isRestriction();

  /** <p>If the simple type is a restriction, returns the restricted
   * simple type.</p>
   *
   * @throws IllegalStateException This type is no restriction of
   *   another simple type.
   */
  public XSType getRestrictedType();
}
