/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.impl;

import org.apache.ws.jaxme.xs.XSAtomicType;
import org.apache.ws.jaxme.xs.XSType;
import org.apache.ws.jaxme.xs.xml.XsEFractionDigits;
import org.apache.ws.jaxme.xs.xml.XsELength;
import org.apache.ws.jaxme.xs.xml.XsEMaxExclusive;
import org.apache.ws.jaxme.xs.xml.XsEMaxInclusive;
import org.apache.ws.jaxme.xs.xml.XsEMaxLength;
import org.apache.ws.jaxme.xs.xml.XsEMinExclusive;
import org.apache.ws.jaxme.xs.xml.XsEMinInclusive;
import org.apache.ws.jaxme.xs.xml.XsEMinLength;
import org.apache.ws.jaxme.xs.xml.XsETotalDigits;
import org.apache.ws.jaxme.xs.xml.XsEWhiteSpace;
import org.apache.ws.jaxme.xs.xml.XsGSimpleRestrictionModel;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XSAtomicTypeRestrictionImpl extends XSSimpleTypeRestrictionImpl implements XSAtomicType {
  private final XSAtomicType atomicBaseType;

  public XSAtomicTypeRestrictionImpl(XSType pParent,
                                      XSType pBaseType, XsGSimpleRestrictionModel pRestriction)
      throws SAXException {
    super(pParent, pBaseType, pRestriction);
    atomicBaseType = pBaseType.getSimpleType().getAtomicType();
  }

  public boolean isAtomic() { return true; }

  public XSAtomicType getAtomicType() {
    return this;
  }

  public Long getFractionDigits() {
    XsEFractionDigits fractionDigits = getRestriction().getFractionDigits();
    if (fractionDigits == null) {
      return atomicBaseType.getFractionDigits();
    } else {
      return new Long(fractionDigits.getValue());
    }
  }

  public Long getLength() {
    XsELength length = getRestriction().getLength();
    if (length == null) {
      return atomicBaseType.getLength();
    } else {
      return new Long(length.getValue());
    }
  }

  public String getMaxExclusive() {
    XsEMaxExclusive maxExclusive = getRestriction().getMaxExclusive();
    if (maxExclusive == null) {
      return atomicBaseType.getMaxExclusive();
    } else {
      return maxExclusive.getValue();
    }
  }

  public String getMaxInclusive() {
    XsEMaxInclusive maxInclusive = getRestriction().getMaxInclusive();
    if (maxInclusive == null) {
      return atomicBaseType.getMaxInclusive();
    } else {
      return maxInclusive.getValue();
    }
  }

  public Long getMaxLength() {
    XsEMaxLength length = getRestriction().getMaxLength();
    if (length == null) {
      return atomicBaseType.getMaxLength();
    } else {
      return new Long(length.getValue());
    }
  }

  public String getMinExclusive() {
    XsEMinExclusive minExclusive = getRestriction().getMinExclusive();
    if (minExclusive == null) {
      return atomicBaseType.getMinExclusive();
    } else {
      return minExclusive.getValue();
    }
  }

  public String getMinInclusive() {
    XsEMinInclusive minInclusive = getRestriction().getMinInclusive();
    if (minInclusive == null) {
      return atomicBaseType.getMinInclusive();
    } else {
      return minInclusive.getValue();
    }
  }

  public Long getMinLength() {
    XsEMinLength length = getRestriction().getMinLength();
    if (length == null) {
      return atomicBaseType.getMinLength();
    } else {
      return new Long(length.getValue());
    }
  }

  public Long getTotalDigits() {
    XsETotalDigits totalDigits = getRestriction().getTotalDigits();
    if (totalDigits == null) {
      return atomicBaseType.getTotalDigits();
    } else {
      return new Long(totalDigits.getValue());
    }
  }

  public boolean isReplacing() {
    XsEWhiteSpace whiteSpace = getRestriction().getWhiteSpace();
    if (whiteSpace == null) {
      return atomicBaseType.isReplacing();
    } else {
      return whiteSpace.isReplacing() || whiteSpace.isCollapsing();
    }
  }

  public boolean isCollapsing() {
    XsEWhiteSpace whiteSpace = getRestriction().getWhiteSpace();
    if (whiteSpace == null) {
      return atomicBaseType.isReplacing();
    } else {
      return whiteSpace.isCollapsing();
    }
  }
}
