/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.impl;

import org.apache.ws.jaxme.xs.XSAnnotation;
import org.apache.ws.jaxme.xs.XSAny;
import org.apache.ws.jaxme.xs.XSAppinfo;
import org.apache.ws.jaxme.xs.XSAttribute;
import org.apache.ws.jaxme.xs.XSAttributeGroup;
import org.apache.ws.jaxme.xs.XSDocumentation;
import org.apache.ws.jaxme.xs.XSElement;
import org.apache.ws.jaxme.xs.XSEnumeration;
import org.apache.ws.jaxme.xs.XSGroup;
import org.apache.ws.jaxme.xs.XSNotation;
import org.apache.ws.jaxme.xs.XSObject;
import org.apache.ws.jaxme.xs.XSObjectFactory;
import org.apache.ws.jaxme.xs.XSSchema;
import org.apache.ws.jaxme.xs.XSSimpleContentType;
import org.apache.ws.jaxme.xs.XSSimpleType;
import org.apache.ws.jaxme.xs.XSType;
import org.apache.ws.jaxme.xs.XSWildcard;
import org.apache.ws.jaxme.xs.parser.XSContext;
import org.apache.ws.jaxme.xs.xml.*;
import org.xml.sax.SAXException;


/** <p>Default implementation of the {@link XSObjectFactory}.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XSObjectFactoryImpl implements XSObjectFactory {
  public XSLogicalParser newXSLogicalParser() {
    return new XSLogicalParser();
  }

  public XSSchema newXSSchema(XSContext pContext, XsESchema pSchema) throws SAXException {
    return new XSSchemaImpl(pContext, pSchema);
  }

  public XSAnnotation newXSAnnotation(XSObject pParent, XsEAnnotation pAnnotation) throws SAXException {
    return new XSAnnotationImpl(pParent, pAnnotation);
  }

  public XSAppinfo newXSAppinfo(XSObject pParent, XsEAppinfo pAppinfo) {
    return new XSAppinfoImpl(pParent, pAppinfo);
  }

  public XSSimpleType newXSAtomicType(XSType pParent, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException {
    return new XSAtomicTypeRestrictionImpl(pParent, pRestrictedType, pRestriction);
  }

  public XSSimpleType newXSAtomicType(XSType pParent, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException {
    return new XSAtomicTypeRestrictionImpl(pParent, pRestrictedType, pRestriction);
  }

  public XSAttribute newXSAttribute(XSObject pParent, XsTAttribute pAttribute) throws SAXException {
    return new XSAttributeImpl(pParent, pAttribute);
  }

  public XSAttributeGroup newXSAttributeGroup(XSObject pParent, XsTAttributeGroup pGroup) throws SAXException {
    return new XSAttributeGroupImpl(pParent, pGroup);
  }

  public XSDocumentation newXSDocumentation(XSObject pParent, XsEDocumentation pDocumentation) throws SAXException {
    return new XSDocumentationImpl(pParent, pDocumentation);
  }

  public XSElement newXSElement(XSObject pParent, XsTElement pElement) throws SAXException {
    return new XSElementImpl(pParent, pElement);
  }

  public XSEnumeration newXSEnumeration(XSObject pParent, XsEEnumeration pEnumeration) throws SAXException {
    return new XSEnumerationImpl(pParent, pEnumeration);
  }

  public XSGroup newXSGroup(XSObject pParent, XsTAll pAll) throws SAXException {
    return new XSGroupImpl(pParent, pAll);
  }

  public XSGroup newXSGroup(XSObject pParent, XsEChoice pChoice) throws SAXException {
    return new XSGroupImpl(pParent, pChoice);
  }

  public XSGroup newXSGroup(XSObject pParent, XsESequence pSequence) throws SAXException {
    return new XSGroupImpl(pParent, pSequence);
  }

  public XSGroup newXSGroup(XSObject pParent, XsTGroupRef pGroupRef) throws SAXException {
    return new XSGroupImpl(pParent, pGroupRef);
  }

  public XSGroup newXSGroup(XSObject pParent, XsTNamedGroup pNamedGroup) throws SAXException {
    return new XSGroupImpl(pParent, pNamedGroup);
  }

  public XSSimpleType newXSListType(XSType pParent, XsEList pList) throws SAXException {
    return new XSListTypeImpl(pParent, pList);
  }

  public XSSimpleType newXSListType(XSType pParent, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException {
    return new XSListTypeRestrictionImpl(pParent, pRestrictedType, pRestriction);
  }

  public XSSimpleType newXSListType(XSType pParent, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException {
    return new XSListTypeRestrictionImpl(pParent, pRestrictedType, pRestriction);
  }

  public XSType newXSType(XSObject pParent, XsETopLevelSimpleType pType) throws SAXException {
    return new XSTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTComplexType pType) throws SAXException {
    return new XSTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTLocalComplexType pType) throws SAXException {
    return new XSTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTLocalSimpleType pType) throws SAXException {
    return new XSTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTSimpleRestrictionType pType) throws SAXException {
    return new XSTypeImpl(pParent, pType);
  }

  public XSSimpleType newXSUnionType(XSType pParent, XsEUnion pUnion) throws SAXException {
    return new XSUnionTypeImpl(pParent, pUnion);
  }

  public XSSimpleType newXSUnionType(XSType pParent, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException {
    return new XSUnionTypeRestrictionImpl(pParent, pRestrictedType, pRestriction);
  }

  public XSSimpleType newXSUnionType(XSType pParent, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException {
    return new XSUnionTypeRestrictionImpl(pParent, pRestrictedType, pRestriction);
  }

  public XSNotation newXSNotation(XSObject pParent, XsENotation pNotation) throws SAXException {
    return new XSNotationImpl(pParent, pNotation);
  }

  public XSAny newXSAny(XSObject pParent, XsEAny pAny) throws SAXException {
    return new XSAnyImpl(pParent, pAny);
  }

  public XSSimpleContentType newXSSimpleContentType(XSType pParent, XSType pSimpleType, XsObject pBaseType) throws SAXException {
    return new XSSimpleContentTypeImpl(pParent, pSimpleType, pBaseType);
  }

  public XSWildcard newXSWildcard(XSObject pParent, XsTWildcard pWildcard) throws SAXException {
    return new XSWildcardImpl(pParent, pWildcard);
  }
}
