/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.impl;

import org.apache.ws.jaxme.xs.XSEnumeration;
import org.apache.ws.jaxme.xs.XSSimpleType;
import org.apache.ws.jaxme.xs.XSType;
import org.apache.ws.jaxme.xs.xml.XsEEnumeration;
import org.apache.ws.jaxme.xs.xml.XsEPattern;
import org.apache.ws.jaxme.xs.xml.XsGSimpleRestrictionModel;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public abstract class XSSimpleTypeRestrictionImpl extends XSSimpleTypeImpl {
  private final XSSimpleType baseType;
  private final XSType restrictedType;
  private final XsGSimpleRestrictionModel restriction;
  private final XSEnumeration[] enumerations;

  protected XSSimpleTypeRestrictionImpl(XSType pParent,
                                         XSType pRestrictedType,
                                         XsGSimpleRestrictionModel pRestriction)
      throws SAXException {
    restrictedType = pRestrictedType;
    baseType = pRestrictedType.getSimpleType();
    restriction = pRestriction;

    XsEEnumeration[] enums = restriction.getEnumerations();
    if (enums.length == 0) {
      enumerations = getBaseType().getEnumerations();
    } else {
      enumerations = new XSEnumeration[enums.length];
      for (int i = 0;  i < enums.length;  i++) {
        enumerations[i] = pParent.getXSSchema().getXSObjectFactory().newXSEnumeration(pParent, enums[i]);
      }
    }
  }

  protected XSSimpleType getBaseType() {
    return baseType;
  }

  public boolean isRestriction() { return true; }
  public XSType getRestrictedType() { return restrictedType; }

  protected XsGSimpleRestrictionModel getRestriction() {
    return restriction;
  }

  public String[][] getPattern() {
    XsEPattern[] patterns = restriction.getPatterns();
    String[][] base = getBaseType().getPattern();
    if (patterns.length == 0) {
      return base;
    } else {
      String[][] result = new String[base.length+1][];
      for (int i = 0;  i < base.length;  i++) {
        result[i+1] = base[i];
      }
      String[] thisStepsPatterns = new String[patterns.length];
      for (int i = 0;  i < patterns.length;  i++) {
        thisStepsPatterns[i] = patterns[i].getValue();
      }
      result[0] = thisStepsPatterns;
      return result;
    }
  }

  public XSEnumeration[] getEnumerations() {
    return enumerations;
  }
}
