/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb;

import org.apache.ws.jaxme.xs.xml.XsQName;


/** <p>This interface implements the JAXB global bindings.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JAXBGlobalBindings.java 231559 2003-09-23 12:37:47Z jochen $
 */
public interface JAXBGlobalBindings {
  /** <p>Enumeration class holding possible values for {@link JAXBGlobalBindings#getUnderscoreBinding()}.</p>
   */
  public class UnderscoreBinding {
    private final String name;
    private UnderscoreBinding(String pName) {
      name = pName;
    }
    public String toString() { return name; }
    public String getName() { return name; }
    public static final UnderscoreBinding AS_WORD_SEPARATOR = new UnderscoreBinding("asWordSeparator");
    public static final UnderscoreBinding AS_CHAR_IN_WORD = new UnderscoreBinding("asCharInWord");
    public static UnderscoreBinding valueOf(String pName) {
      if (AS_WORD_SEPARATOR.name.equals(pName)) {
        return AS_WORD_SEPARATOR;
      } else if (AS_CHAR_IN_WORD.name.equals(pName)) {
        return AS_CHAR_IN_WORD;
      } else {
        throw new IllegalArgumentException("Invalid value for underscoreBinding: " + pName +
                                            ", expected either of asWordSeparator|asCharInWord");
      }
    }
  }

  /** <p>Returns the collection type; either of null ("indexed",
   * default) or an implementation of <code>java.util.List</code>.</p>
   */
  public String getCollectionType();

  /** <p>Returns whether fixed attributes are implemented as a
   * constant property. Defaults to false.</p>
   */
  public boolean isFixedAttributeAsConstantProperty();

  /** <p>Returns whether a <code>isSet()</code> method is being
   * generated. Defaults to false.</p>
   */
  public boolean isGenerateIsSetMethod();

  /** <p>Returns whether FailFastCheck is enabled. Defaults to
   * false.</p>
   */
  public boolean isEnableFailFastCheck();

  /** <p>Returns the <code>choiceContentProperty</code> value. Defaults
   * to false. This value is ignored, if <code>bindingStyle</code> is
   * defined as <code>elementBinding</code>. In this case, setting
   * <code>choiceContentProperty</code> is an error. Defaults to false.</p>
   */
  public boolean isChoiceContentProperty();

  /** <p>Returns the binding of underscores. Defaults to "asWordSeparator"
   * (false). The value true indicates "asCharInWord".
   */
  public UnderscoreBinding getUnderscoreBinding();

  /** <p>Returns whether Java naming conventions are enabled. Defaults to
   * true.</p>
   */
  public boolean isEnableJavaNamingConventions();

  /** <p>Returns a list of QNames, which are being implemented as type
   * safe enumerations, if the <code>xs:enumeration</code> facet is
   * used. Defaults to <code>xs:NCName</code> (single element list).</p>
   */
  public XsQName[] getTypesafeEnumBase();

  /** <p>Returns whether the typesafeEnumMemberName generates an
   * error (false, default) or a name.</p>
   */
  public boolean isTypesafeEnumMemberName();

  /** <p>Returns whether the <code>elementBinding</code> style is
   * being used (true, default) or not.</p>
   */
  public boolean isBindingStyleModelGroup();

  /** <p>Returns the list of <code>javaType</code> declarations.</p>
   */
  public JAXBJavaType.JAXBGlobalJavaType[] getJavaType();
}
