/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import org.apache.ws.jaxme.xs.jaxb.*;
import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.XsEAnnotation;
import org.apache.ws.jaxme.xs.xml.XsObject;
import org.apache.ws.jaxme.xs.xml.XsTSimpleType;
import org.apache.ws.jaxme.xs.xml.impl.XsEAppinfoImpl;
import org.xml.sax.ContentHandler;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class JAXBAppinfoImpl extends XsEAppinfoImpl {
  /** <p>Creates a new instance of JAXBAppinfo.</p>
   */
  public JAXBAppinfoImpl(XsObject pParent) {
    super(pParent);
  }

  protected JAXBXsObjectFactory getJAXBXsObjectFactory() { return (JAXBXsObjectFactory) getObjectFactory(); }

  /** <p>Creates a new instance of {@link JAXBClass}.</p>
   */
  public JAXBClass createClass() {
    JAXBClass jaxbClass = getJAXBXsObjectFactory().newJAXBClass(this);
    addChild(jaxbClass);
    return jaxbClass;
  }

  /** <p>Creates a new instance of {@link JAXBGlobalBindings}.</p>
   */
  public JAXBGlobalBindings createGlobalBindings() {
    JAXBGlobalBindings jaxbGlobalBindings = getJAXBXsObjectFactory().newJAXBGlobalBindings(this);
    addChild(jaxbGlobalBindings);
    return jaxbGlobalBindings;
  }

  /** <p>Creates a new instance of {@link JAXBJavadoc}.</p>
   */
  public JAXBJavadoc createJavadoc() {
    JAXBJavadoc jaxbJavadoc = getJAXBXsObjectFactory().newJAXBJavadoc(this);
    addChild(jaxbJavadoc);
    return jaxbJavadoc;
  }

  /** <p>Creates a new instance of {@link JAXBJavaType}.</p>
   */
  public JAXBJavaType createJavaType() {
    JAXBJavaType jaxbJavaType = getJAXBXsObjectFactory().newJAXBJavaType(this);
    addChild(jaxbJavaType);
    return jaxbJavaType;
  }

  /** <p>Creates a new instance of {@link JAXBProperty}.</p>
   */
  public JAXBProperty createProperty() {
    JAXBProperty jaxbProperty = getJAXBXsObjectFactory().newJAXBProperty(this);
    addChild(jaxbProperty);
    return jaxbProperty;
  }

  /** <p>Creates a new instance of {@link JAXBSchemaBindings}.</p>
   */
  public JAXBSchemaBindings createSchemaBindings() {
    JAXBSchemaBindings jaxbSchemaBindings = getJAXBXsObjectFactory().newJAXBSchemaBindings(this);
    addChild(jaxbSchemaBindings);
    return jaxbSchemaBindings;
  }

  /** <p>Creates a new instance of {@link JAXBTypesafeEnumClass}.</p>
   */
  public JAXBTypesafeEnumClass createTypesafeEnumClass() throws SAXException {
    XsObject annotationParent = getParentObject();
    if (annotationParent instanceof XsEAnnotation) {
      XsObject simpleTypeParent = annotationParent.getParentObject();
      if (simpleTypeParent instanceof XsTSimpleType) {
        JAXBTypesafeEnumClass jaxbTypesafeEnumClass = getJAXBXsObjectFactory().newJAXBTypesafeEnumClass(this);
        addChild(jaxbTypesafeEnumClass);
        return jaxbTypesafeEnumClass;
      }
    }
    System.err.println("this = " + this);
    System.err.println("AnnotationParent = " + annotationParent);
    System.err.println("annotationParent.parent = " + annotationParent.getParentObject());
    throw new LocSAXException("The declaration of a typesafeEnumClass is only allowed in xs:simpleType/xs:annotation/xs:appinfo.", getLocator());
  }

  /** <p>Creates a new instance of {@link JAXBTypesafeEnumMember}.</p>
   */
  public JAXBTypesafeEnumMember createTypesafeEnumMember() {
    JAXBTypesafeEnumMember jaxbTypesafeEnumMember = getJAXBXsObjectFactory().newJAXBTypesafeEnumMember(this);
    addChild(jaxbTypesafeEnumMember);
    return jaxbTypesafeEnumMember;
  }

  public ContentHandler getChildHandler(String pQName, String pNamespaceURI, String pLocalName) throws SAXException {
    if (JAXBParser.JAXB_SCHEMA_URI.equals(pNamespaceURI)) {
      return null;
    } else {
      return super.getChildHandler(pQName, pNamespaceURI, pLocalName);
    }
  }
}
