/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import org.apache.ws.jaxme.xs.jaxb.JAXBClass;
import org.apache.ws.jaxme.xs.jaxb.JAXBJavadoc;
import org.apache.ws.jaxme.xs.xml.XsObject;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JAXBClassImpl.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class JAXBClassImpl extends JAXBXsObjectImpl implements JAXBClass {
  /** <p>Creates a new instance of ClassImpl.</p>
   */
  protected JAXBClassImpl(XsObject pParent) {
    super(pParent);
  }

  private String name;
  private String implClass;
  private JAXBJavadoc javadoc;

  /** <p>Sets the interfaces class name, not including the package name.
   * The package name is set in the schema bindings or
   * derived from the target namespace.</p>
   */
  public void setName(String pName) {
    name = pName;
  }

  /** <p>Returns the interfaces class name, not including the package name.
   * The package name is set in the schema bindings or
   * derived from the target namespace.</p>
   */
  public String getName() {
    return name;
  }

  /** <p>Sets the implementation classes name, including the package
   * name.</p>
   */
  public void setImplClass(String pImplClass) {
    implClass = pImplClass;
  }

  /** <p>Returns the implementation classes name, including the package
   * name.</p>
   */
  public String getImplClass() {
    return implClass;
  }

  /** <p>Sets the classes Javadoc documentation.</p>
   */
  public JAXBJavadoc createJavadoc() {
    if (javadoc == null) {
      javadoc = getJAXBXsObjectFactory().newJAXBJavadoc(this);
      return javadoc;
    } else {
      throw new IllegalStateException("Multiple Javadoc elements are not supported.");
    }
  }

  /** <p>Returns the classes Javadoc documentation.</p>
   */
  public JAXBJavadoc getJavadoc() {
    return javadoc;
  }
}
