/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import org.apache.ws.jaxme.xs.XSObject;
import org.apache.ws.jaxme.xs.impl.XSElementImpl;
import org.apache.ws.jaxme.xs.impl.XSUtil;
import org.apache.ws.jaxme.xs.jaxb.JAXBClass;
import org.apache.ws.jaxme.xs.jaxb.JAXBElement;
import org.apache.ws.jaxme.xs.jaxb.JAXBProperty;
import org.apache.ws.jaxme.xs.jaxb.JAXBSchemaBindings;
import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.XsTElement;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class JAXBElementImpl extends XSElementImpl implements JAXBElement {
  private JAXBClass jaxbClass;
  private JAXBProperty jaxbProperty;

  /** <p>Creates a new instance of JAXBElementImpl.</p>
   */
  protected JAXBElementImpl(XSObject pParent, XsTElement pBaseElement)
      throws SAXException {
    super(pParent, pBaseElement);
  }

  public JAXBSchemaBindings getJAXBSchemaBindings() {
    return ((JAXBXsSchemaImpl) getXsObject().getXsESchema()).getJAXBSchemaBindings();
  }


  public JAXBClass getJAXBClass() { return jaxbClass; }
  public JAXBProperty getJAXBProperty() { return jaxbProperty; }

  public void validate() throws SAXException {
    if (isValidated()) {
      return;
    }
    super.validate();
    jaxbClass = (JAXBClass) XSUtil.getSingleAppinfo(getAnnotations(), JAXBClass.class);
    jaxbProperty = (JAXBProperty) XSUtil.getSingleAppinfo(getAnnotations(), JAXBProperty.class);

    if (jaxbProperty == null) {
      XsTElement elem = (XsTElement) getXsObject();
      if (elem.getRef() != null) {
        JAXBElement refElem = (JAXBElement) getXSSchema().getAttribute(elem.getRef());
        if (refElem != null) {
          jaxbProperty = refElem.getJAXBProperty();
        }
      }
    } else {
      if (isGlobal()) {
        if (jaxbProperty != null  &&  jaxbProperty.getBaseType() != null) {
          throw new LocSAXException("The element jaxb:property/jaxb:baseType is forbidden in global elements." +
                                     " You may set it in the reference using the element locally. [JAXB 6.8.1.2.1]",
                                     jaxbProperty.getLocator());
        }
      }
    }

    if (jaxbClass != null  &&  jaxbClass.getImplClass() != null) {
      if (isGlobal()) {
        if (jaxbClass != null  &&  jaxbClass.getImplClass() != null) {
          throw new LocSAXException("The implClass attribute is invalid for global elements. [JAXB 6.7.3.4]",
                                     jaxbClass.getLocator());
        }
      } else {
        if (jaxbClass != null  &&  jaxbClass.getImplClass() != null) {
          throw new LocSAXException("The implClass attribute is invalid for local elements. [JAXB 6.7.3.5]",
                                     jaxbClass.getLocator());
        }
      }
    }
  }
}
