/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import org.apache.ws.jaxme.xs.jaxb.JAXBJavaType;
import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.XsObject;
import org.apache.ws.jaxme.xs.xml.XsQName;
import org.apache.ws.jaxme.xs.xml.impl.XsObjectImpl;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JAXBJavaTypeImpl.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class JAXBJavaTypeImpl extends XsObjectImpl implements JAXBJavaType {
  public static class JAXBGlobalJavaTypeImpl extends JAXBJavaTypeImpl implements JAXBJavaType.JAXBGlobalJavaType {
    /** <p>Creates a new instance of JAXBJavaTypeImpl.java.</p>
     */
    protected JAXBGlobalJavaTypeImpl(XsObject pParent) {
      super(pParent);
    }

    private XsQName xmlType;
    public void setXmlType(XsQName pType) { xmlType = pType; }
    public void setXmlType(String pType) throws SAXException {
      String[] parts = new String[3];
      getNamespaceSupport().processName(pType, parts, false);
      setXmlType(new XsQName(parts[0], parts[1], XsQName.prefixOf(pType)));
    }
    public XsQName getXmlType() { return xmlType; }
    public void validate() throws SAXException {
      super.validate();
      if (getXmlType() == null) {
        throw new LocSAXException("Missing attribute: 'xmlType'", getLocator());
      }
    }
  }

  private String name;
  private boolean hasNsContext;
  private String parseMethod, printMethod;

  /** <p>Creates a new instance of JAXBJavaTypeImpl.java.</p>
   */
  protected JAXBJavaTypeImpl(XsObject pParent) {
    super(pParent);
  }

  public void setName(String pName) { name = pName; }
  public String getName() { return name; }

  public void setHasNsContext(boolean pHasNsContext) {
    hasNsContext = pHasNsContext;
  }

  public boolean hasNsContext() {
    return hasNsContext;
  }

  public void setParseMethod(String pParseMethod) {
    parseMethod = pParseMethod;
  }

  public String getParseMethod() {
    return parseMethod;
  }

  public void setPrintMethod(String pPrintMethod) {
    printMethod = pPrintMethod;
  }

  public String getPrintMethod() {
    return printMethod;
  }
}
