/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import org.apache.ws.jaxme.xs.XSAttribute;
import org.apache.ws.jaxme.xs.XSElement;
import org.apache.ws.jaxme.xs.XSEnumeration;
import org.apache.ws.jaxme.xs.XSGroup;
import org.apache.ws.jaxme.xs.XSObject;
import org.apache.ws.jaxme.xs.XSSchema;
import org.apache.ws.jaxme.xs.XSSimpleType;
import org.apache.ws.jaxme.xs.XSType;
import org.apache.ws.jaxme.xs.impl.XSObjectFactoryImpl;
import org.apache.ws.jaxme.xs.parser.XSContext;
import org.apache.ws.jaxme.xs.xml.XsEChoice;
import org.apache.ws.jaxme.xs.xml.XsEEnumeration;
import org.apache.ws.jaxme.xs.xml.XsEList;
import org.apache.ws.jaxme.xs.xml.XsERestriction;
import org.apache.ws.jaxme.xs.xml.XsESchema;
import org.apache.ws.jaxme.xs.xml.XsESequence;
import org.apache.ws.jaxme.xs.xml.XsETopLevelSimpleType;
import org.apache.ws.jaxme.xs.xml.XsEUnion;
import org.apache.ws.jaxme.xs.xml.XsTAll;
import org.apache.ws.jaxme.xs.xml.XsTAttribute;
import org.apache.ws.jaxme.xs.xml.XsTComplexType;
import org.apache.ws.jaxme.xs.xml.XsTElement;
import org.apache.ws.jaxme.xs.xml.XsTGroupRef;
import org.apache.ws.jaxme.xs.xml.XsTLocalComplexType;
import org.apache.ws.jaxme.xs.xml.XsTLocalSimpleType;
import org.apache.ws.jaxme.xs.xml.XsTNamedGroup;
import org.apache.ws.jaxme.xs.xml.XsTSimpleRestrictionType;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class JAXBObjectFactoryImpl extends XSObjectFactoryImpl {
  public XSSimpleType newXSAtomicType(XSType pResultType, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSAtomicType(pResultType, pRestrictedType, pRestriction));
  }

  public XSSimpleType newXSAtomicType(XSType pResultType, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSAtomicType(pResultType, pRestrictedType, pRestriction));
  }

  public XSAttribute newXSAttribute(XSObject pParent, XsTAttribute pAttribute) throws SAXException {
    return new JAXBAttributeImpl(pParent, pAttribute);
  }

  public XSEnumeration newXSEnumeration(XSObject pParent, XsEEnumeration pEnumeration) throws SAXException {
    return new JAXBEnumerationImpl(pParent, pEnumeration);
  }

  public XSSchema newXSSchema(XSContext pContext, XsESchema pSchema) throws SAXException {
    return new JAXBSchemaImpl(pContext, pSchema);
  }

  public XSGroup newXSGroup(XSObject pParent, XsTAll pAll) throws SAXException {
    return new JAXBGroupImpl(pParent, pAll);
  }

  public XSGroup newXSGroup(XSObject pParent, XsEChoice pChoice) throws SAXException {
    return new JAXBGroupImpl(pParent, pChoice);
  }

  public XSGroup newXSGroup(XSObject pParent, XsESequence pSequence) throws SAXException {
    return new JAXBGroupImpl(pParent, pSequence);
  }

  public XSGroup newXSGroup(XSObject pParent, XsTGroupRef pGroupRef) throws SAXException {
    return new JAXBGroupImpl(pParent, pGroupRef);
  }

  public XSGroup newXSGroup(XSObject pParent, XsTNamedGroup pNamedGroup) throws SAXException {
    return new JAXBGroupImpl(pParent, pNamedGroup);
  }

  public XSSimpleType newXSListType(XSType pResultType, XsEList pList) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSListType(pResultType, pList));
  }

  public XSSimpleType newXSListType(XSType pResultType, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSListType(pResultType, pRestrictedType, pRestriction));
  }

  public XSSimpleType newXSListType(XSType pResultType, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSListType(pResultType, pRestrictedType, pRestriction));
  }

  public XSType newXSType(XSObject pParent, XsETopLevelSimpleType pType) throws SAXException {
    return new JAXBTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTComplexType pType) throws SAXException {
    return new JAXBTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTLocalComplexType pType) throws SAXException {
    return new JAXBTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTLocalSimpleType pType) throws SAXException {
    return new JAXBTypeImpl(pParent, pType);
  }

  public XSType newXSType(XSObject pParent, XsTSimpleRestrictionType pType) throws SAXException {
    return new JAXBTypeImpl(pParent, pType);
  }

  public XSElement newXSElement(XSObject pParent, XsTElement pElement) throws SAXException {
    return new JAXBElementImpl(pParent, pElement);
  }

  public XSSimpleType newXSUnionType(XSType pResultType, XsEUnion pUnion) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSUnionType(pResultType, pUnion));
  }

  public XSSimpleType newXSUnionType(XSType pResultType, XSType pRestrictedType, XsERestriction pRestriction) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSUnionType(pResultType, pRestrictedType, pRestriction));
  }

  public XSSimpleType newXSUnionType(XSType pResultType, XSType pRestrictedType, XsTSimpleRestrictionType pRestriction) throws SAXException {
    return new JAXBSimpleTypeImpl(pResultType, super.newXSUnionType(pResultType, pRestrictedType, pRestriction));
  }
}
