/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import org.apache.ws.jaxme.xs.jaxb.JAXBJavaType;
import org.apache.ws.jaxme.xs.jaxb.JAXBJavadoc;
import org.apache.ws.jaxme.xs.jaxb.JAXBProperty;
import org.apache.ws.jaxme.xs.jaxb.JAXBXsObjectFactory;
import org.apache.ws.jaxme.xs.xml.XsObject;


/** <p>Implementation of the Property interface.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JAXBPropertyImpl.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class JAXBPropertyImpl extends JAXBXsObjectImpl implements JAXBProperty {
  public static class BaseTypeImpl extends JAXBXsObjectImpl implements JAXBProperty.BaseType {
    /** <p>Creates a new instance of JAXBPropertyImpl.</p>
     */
    protected BaseTypeImpl(XsObject pParent) {
      super(pParent);
    }

    private JAXBJavaType javaType;

    public JAXBJavaType createJavaType() {
      if (javaType != null) {
        throw new IllegalStateException("Only one instance of javaType supported.");
      }
      javaType = ((JAXBXsObjectFactory) getObjectFactory()).newJAXBJavaType(this);
      return javaType;
    }

    public JAXBJavaType getJavaType() {
      return javaType;
    }
  }

  private String name;
  private String collectionType;
  private Boolean fixedAttributeAsConstantProperty, generateIsSetMethod, enableFailFastCheck;
  private JAXBJavadoc javadoc;
  private BaseType baseType;

  /** <p>Creates a new instance of JAXBPropertyImpl.</p>
   */
  protected JAXBPropertyImpl(XsObject pParent) {
    super(pParent);
  }

  public void setName(String pName) {
    name = pName;
  }

  public String getName() {
    return name;
  }

  public void setCollectionType(String pType) throws ClassNotFoundException {
    collectionType = pType;
  }

  public String getCollectionType() { return collectionType; }

  public void setFixedAttributeAsConstantProperty(Boolean pFixedAttributeAsConstantProperty) {
    fixedAttributeAsConstantProperty = pFixedAttributeAsConstantProperty;
  }

  public Boolean isFixedAttributeAsConstantProperty() {
    return fixedAttributeAsConstantProperty;
  }

  public void setGenerateIsSetMethod(Boolean pGenerateIsSetMethod) {
    generateIsSetMethod = pGenerateIsSetMethod;
  }

  public Boolean isGenerateIsSetMethod() {
    return generateIsSetMethod;
  }

  public void setEnableFailFastCheck(Boolean pEnableFailFastCheck) {
    enableFailFastCheck = pEnableFailFastCheck;
  }

  public Boolean isEnableFailFastCheck() {
    return enableFailFastCheck;
  }

  public JAXBJavadoc createJavadoc() {
    if (javadoc != null) {
      throw new IllegalStateException("Multiple javadoc elements are not supported.");
    }
    javadoc = getJAXBXsObjectFactory().newJAXBJavadoc(this);
    return javadoc;
  }

  public JAXBJavadoc getJavadoc() {
    return javadoc;
  }

  public BaseType createBaseType() {
    if (baseType != null) {
      throw new IllegalStateException("Multiple instances of baseType are not supported.");
    }
    baseType = ((JAXBXsObjectFactory) getObjectFactory()).newBaseType(this);
    return baseType;
  }

  public BaseType getBaseType() {
    return baseType;
  }
}
