/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.ws.jaxme.xs.jaxb.JAXBJavadoc;
import org.apache.ws.jaxme.xs.jaxb.JAXBSchemaBindings;
import org.apache.ws.jaxme.xs.jaxb.JAXBXsObjectFactory;
import org.apache.ws.jaxme.xs.xml.XsObject;
import org.apache.ws.jaxme.xs.xml.impl.XsObjectImpl;


/** <p>Implementation of the SchemaBindings interface.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 * @version $Id: JAXBSchemaBindingsImpl.java 231559 2003-09-23 12:37:47Z jochen $
 */
public class JAXBSchemaBindingsImpl extends JAXBXsObjectImpl implements JAXBSchemaBindings {
  private Package myPackage;
  private List nameXmlTransformations;

  public static class PackageImpl extends JAXBXsObjectImpl implements JAXBSchemaBindings.Package {
    /** <p>Creates a new instance of JAXBSchemaBindingsImpl.</p>
     */
    protected PackageImpl(XsObject pParent) {
      super(pParent);
    }

    private String name;
    private JAXBJavadoc javadoc;

    public void setName(String pName) {
      name = pName;
    }

    public String getName() {
      return name;
    }

    public JAXBJavadoc createJavadoc() {
      if (javadoc != null) {
        throw new IllegalStateException("Multiple javadoc elements are not supported.");
      }
      javadoc = getJAXBXsObjectFactory().newJAXBJavadoc(this);
      return javadoc;
    }

    public JAXBJavadoc getJavadoc() {
      return javadoc;
    }
  }

  public static class NameXmlTransformationImpl extends XsObjectImpl
      implements JAXBSchemaBindings.NameXmlTransformation {
    public static class NameTransformationImpl extends XsObjectImpl
        implements JAXBSchemaBindings.NameTransformation {
      /** <p>Creates a new instance of JAXBSchemaBindingsImpl.</p>
       */
      protected NameTransformationImpl(XsObject pParent) {
        super(pParent);
      }

      private String suffix, prefix;

      public void setSuffix(String pSuffix) {
        suffix = pSuffix;
      }

      public String getSuffix() {
        return suffix;
      }

      public void setPrefix(String pPrefix) {
        prefix = pPrefix;
      }

      public String getPrefix() {
        return prefix;
      }
    }

    /** <p>Creates a new instance of JAXBSchemaBindingsImpl.</p>
     */
    protected NameXmlTransformationImpl(XsObject pParent) {
      super(pParent);
    }

    private NameTransformation typeName, elementName, modelGroupName, anonymousTypeName;

    public NameTransformation createTypeName() {
      if (typeName != null) {
        throw new IllegalStateException("Multiple instances of typeName are not supported.");
      }
      typeName = ((JAXBXsObjectFactory) getObjectFactory()).newNameTransformation(this);
      return typeName;
    }

    public NameTransformation getTypeName() {
      return typeName;
    }

    public NameTransformation createElementName() {
      if (elementName != null) {
        throw new IllegalStateException("Multiple instances of elementName are not supported.");
      }
      elementName = ((JAXBXsObjectFactory) getObjectFactory()).newNameTransformation(this);
      return elementName;
    }

    public NameTransformation getElementName() {
      return elementName;
    }

    public NameTransformation createModelGroupName() {
      if (modelGroupName != null) {
        throw new IllegalStateException("Multiple instances of modelGroupName are not supported.");
      }
      modelGroupName = ((JAXBXsObjectFactory) getObjectFactory()).newNameTransformation(this);
      return modelGroupName;
    }

    public NameTransformation getModelGroupName() {
      return modelGroupName;
    }

    public NameTransformation createAnonymousTypeName() {
      if (anonymousTypeName != null) {
        throw new IllegalStateException("Multiple instances of anonymousTypeName are not supported.");
      }
      anonymousTypeName = ((JAXBXsObjectFactory) getObjectFactory()).newNameTransformation(this);
      return anonymousTypeName;
    }

    public NameTransformation getAnonymousTypeName() {
      return anonymousTypeName;
    }
  }

  /** <p>Creates a new instance of SchemaBindings with the given
   * GlobalBindings.</p>
   */
  protected JAXBSchemaBindingsImpl(XsObject pParent) {
    super(pParent);
  }

  /** <p>Creates a new Package implementation.</p>
   */
  public Package createPackage() {
    if (myPackage != null) {
      throw new IllegalStateException("Multiple package declarations are not supported.");
    }
    myPackage = ((JAXBXsObjectFactory) getObjectFactory()).newPackage(this);
    return myPackage;
  }

  public Package getPackage() {
    return myPackage;
  }

  /** <p>Creates a new NameXmlTransformation implementation.</p>
   */
  public NameXmlTransformation createNameXmlTransformation() {
    if (nameXmlTransformations == null) {
      nameXmlTransformations = new ArrayList();
    }
    NameXmlTransformation result = ((JAXBXsObjectFactory) getObjectFactory()).newNameXmlTransformation(this);
    nameXmlTransformations.add(result);
    return result;
  }

  private static final NameXmlTransformation[] DEFAULT_NAME_XML_TRANSFORMATION = new NameXmlTransformation[0];
  public NameXmlTransformation[] getNameXmlTransformation() {
    if (nameXmlTransformations == null) {
      return DEFAULT_NAME_XML_TRANSFORMATION;
    } else {
      return (NameXmlTransformation[]) nameXmlTransformations.toArray(new NameXmlTransformation[nameXmlTransformations.size()]);
    }
  }
}
