/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.jaxb.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.StringTokenizer;

import org.apache.ws.jaxme.xs.jaxb.*;
import org.apache.ws.jaxme.xs.jaxb.JAXBSchemaBindings;
import org.apache.ws.jaxme.xs.jaxb.JAXBXsObjectFactory;
import org.apache.ws.jaxme.xs.parser.XSContext;
import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.XsEAnnotation;
import org.apache.ws.jaxme.xs.xml.XsEAppinfo;
import org.apache.ws.jaxme.xs.xml.impl.XsESchemaImpl;
import org.xml.sax.SAXException;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class JAXBXsSchemaImpl extends XsESchemaImpl implements JAXBXsSchema {
  private JAXBSchemaBindings schemaBindings;
  private String jaxbVersion;
  private String[] jaxbExtensionBindingPrefixes;

  public void setJaxbVersion(String pVersion) {
    jaxbVersion = pVersion;
  }

  public void setJaxbExtensionBindingPrefixes(String pExtensionBindingPrefixes) {
    List result = new ArrayList();
    for (StringTokenizer st = new StringTokenizer(pExtensionBindingPrefixes);  st.hasMoreTokens();  ) {
      result.add(st.nextToken());
    }
    jaxbExtensionBindingPrefixes = (String[]) result.toArray(new String[result.size()]);
  }

  public String[] getJaxbExtensionBindingPrefixes() {
    return jaxbExtensionBindingPrefixes == null ? new String[0] : jaxbExtensionBindingPrefixes;
  }

  public String getJaxbVersion() {
    return jaxbVersion;
  }

  /** <p>Creates a new instance of JAXBXsSchemaImpl.</p>
   */
  public JAXBXsSchemaImpl(XSContext pContext) {
    super(pContext);
  }

  public void validate() throws SAXException {
    if (isValidated()) {
      return;
    }
    super.validate();
    Object[] childs = getChilds();
    for (int i = 0;  i < childs.length;  i++) {
      if (!(childs[i] instanceof XsEAnnotation)) {
        continue;
      }
      XsEAnnotation annotation = (XsEAnnotation) childs[i];
      XsEAppinfo[] appinfos = annotation.getAppinfos();
      for (int j = 0;  j < appinfos.length;  j++) {
        Object[] appinfoChilds = appinfos[j].getChilds();
        for (int k = 0;  k < appinfoChilds.length;  k++) {
          if (!(appinfoChilds[k] instanceof JAXBSchemaBindings)) {
            continue;
          }
          if (schemaBindings == null) {
            schemaBindings = (JAXBSchemaBindings) appinfoChilds[k];
          } else {
            throw new LocSAXException("A schema must have at most a single instance of 'schemaBindings'",
                                       appinfos[j].getLocator());
          }
        }
      }
    }

    if (schemaBindings == null) {
      schemaBindings = ((JAXBXsObjectFactory) getObjectFactory()).newJAXBSchemaBindings(this);
    }
  }

  public JAXBSchemaBindings getJAXBSchemaBindings() {
    return schemaBindings;
  }

  public boolean setAttribute(String pQName, String pNamespaceURI, String pLocalName,
                                String pValue) throws SAXException {
    if (JAXBParser.JAXB_SCHEMA_URI.equals(pNamespaceURI)) {
      if ("version".equals(pLocalName)) {
        setJaxbVersion(pValue);
        return true;
      } else if ("extensionBindingPrefixes".equals(pLocalName)) {
        setJaxbExtensionBindingPrefixes(pValue);
        return true;
      } else {
        throw new LocSAXException("Invalid attribute: " + pQName, getLocator());
      }
    } else {
      return super.setAttribute(pQName, pNamespaceURI, pLocalName, pValue);
    }
  }
}
