/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.junit;

import junit.framework.TestCase;
import org.apache.ws.jaxme.xs.XSAtomicType;
import org.apache.ws.jaxme.xs.XSComplexType;
import org.apache.ws.jaxme.xs.XSElement;
import org.apache.ws.jaxme.xs.XSGroup;
import org.apache.ws.jaxme.xs.XSListType;
import org.apache.ws.jaxme.xs.XSModelGroup;
import org.apache.ws.jaxme.xs.XSParser;
import org.apache.ws.jaxme.xs.XSParticle;
import org.apache.ws.jaxme.xs.XSSimpleContentType;
import org.apache.ws.jaxme.xs.XSSimpleType;
import org.apache.ws.jaxme.xs.XSType;
import org.apache.ws.jaxme.xs.XSUnionType;
import org.apache.ws.jaxme.xs.jaxb.impl.JAXBParser;
import org.apache.ws.jaxme.xs.xml.XsComplexContentType;
import org.xml.sax.SAXException;

/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public abstract class ParserTestBase extends TestCase {
  protected ParserTestBase(String pName) {
    super(pName);
  }

  protected XSParser newXSParser() {
    XSParser parser = new XSParser();
    parser.setValidating(false);
    return parser;
  }

  protected JAXBParser newJAXBParser() {
    JAXBParser parser = new JAXBParser();
    parser.setValidating(false);
    return parser;
  }

  protected XSComplexType assertComplexType(XSType pType) throws SAXException {
    assertTrue(!pType.isSimple());
    XSComplexType result = pType.getComplexType();
    assertNotNull(result);
    boolean haveException = false;
    try {
      pType.getSimpleType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    return result;
  }

  protected XSSimpleType assertSimpleType(XSType pType) throws SAXException {
    assertTrue(pType.isSimple());
    XSSimpleType result = pType.getSimpleType();
    assertNotNull(result);
    boolean haveException = false;
    try {
      pType.getComplexType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    return result;
  }

  protected XSAtomicType assertAtomicType(XSSimpleType pType) throws SAXException {
    assertTrue(pType.isAtomic());
    assertTrue(!pType.isList());
    assertTrue(!pType.isUnion());
    XSAtomicType result = pType.getAtomicType();
    assertNotNull(result);
    boolean haveException = false;
    try {
      pType.getListType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    haveException = false;
    try {
      pType.getUnionType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    return result;
  }

  protected XSListType assertListType(XSSimpleType pType) throws SAXException {
    assertTrue(!pType.isAtomic());
    assertTrue(pType.isList());
    assertTrue(!pType.isUnion());
    XSListType result = pType.getListType();
    assertNotNull(result);
    boolean haveException = false;
    try {
      pType.getAtomicType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    haveException = false;
    try {
      pType.getUnionType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    return result;
  }

  protected XSUnionType assertUnionType(XSSimpleType pType) throws SAXException {
    assertTrue(!pType.isAtomic());
    assertTrue(!pType.isList());
    assertTrue(pType.isUnion());
    XSUnionType result = pType.getUnionType();
    assertNotNull(result);
    boolean haveException = false;
    try {
      pType.getListType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    haveException = false;
    try {
      pType.getAtomicType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    return result;
  }

  protected XSType assertRestriction(XSSimpleType pType) throws SAXException {
    assertTrue(pType.isRestriction());
    XSType result = pType.getRestrictedType();
    assertNotNull(result);
    assertSimpleType(result);
    return result;
  }

  protected XSParticle assertComplexContent(XSComplexType pType) {
    assertTrue(!pType.hasSimpleContent());
    XSParticle result = pType.getParticle();
    assertNotNull(result);
    XsComplexContentType ccType = pType.getComplexContentType();
    assertNotNull(pType.getComplexContentType());
    int num = 0;
    if (pType.isElementOnly()) {
      ++num;
      assertEquals(XsComplexContentType.ELEMENT_ONLY, ccType);
    } 
    if (pType.isEmpty()) {
      ++num;
      assertEquals(XsComplexContentType.EMPTY, ccType);
    } 
    if (pType.isMixed()) {
      ++num;
      assertEquals(XsComplexContentType.MIXED, ccType);
    } 
    assertEquals(1, num);
  
    num = 0;
    if (result.isElement()) {
      ++num;
      assertNotNull(result.getElement());
      assertEquals(XSParticle.ELEMENT, result.getType());
    }
    if (result.isGroup()) {
      ++num;
      assertNotNull(result.getGroup());
      assertEquals(XSParticle.GROUP, result.getType());
    }
    if (result.isWildcard()) {
      ++num;
      assertNotNull(result.getWildcard());
      assertEquals(XSParticle.WILDCARD, result.getType());
    }
    assertEquals(1, num);
  
    return result;
  }

  protected XSGroup assertGroup(XSParticle pParticle) {
    assertTrue(pParticle.isGroup());
    assertEquals(XSParticle.GROUP, pParticle.getType());
    XSGroup result = pParticle.getGroup();
    assertNotNull(result);
    return result;
  }

  protected void assertSequence(XSGroup pGroup) {
    assertTrue(pGroup.isSequence());
    assertTrue(!pGroup.isChoice());
    assertTrue(!pGroup.isAll());
    assertEquals(XSModelGroup.SEQUENCE, pGroup.getCompositor());
  }

  protected XSElement assertElement(XSParticle pParticle) {
    assertTrue(pParticle.isElement());
    assertEquals(XSParticle.ELEMENT, pParticle.getType());
    XSElement result = pParticle.getElement();
    assertNotNull(result);
    return result;
  }

  protected XSSimpleContentType assertSimpleContent(XSComplexType pType) {
    assertTrue(pType.hasSimpleContent());
    XSSimpleContentType result = pType.getSimpleContent();
    assertNotNull(result);
    XSType resultType = result.getType();
    assertNotNull(resultType);
    assertTrue(resultType.isSimple());
    boolean haveException = false;
    try {
      pType.getComplexContentType();
    } catch (IllegalStateException e) {
      haveException = true;
    }
    assertTrue(haveException);
    assertNotNull(result);
    return result;
  }
}
