/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.parser;

import org.apache.ws.jaxme.xs.*;
import org.apache.ws.jaxme.xs.impl.XSLogicalParser;
import org.apache.ws.jaxme.xs.xml.XsObjectFactory;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.helpers.NamespaceSupport;

/** <p>This interface provides access to the parsers context.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XSContext {
  /** <p>Returns the parsers object factory for syntax elements.</p>
   */
  public XsObjectFactory getXsObjectFactory();
  /** <p>Sets the parsers object factory for syntax elements.</p>
   */
  public void setXsObjectFactory(XsObjectFactory pFactory);

  /** <p>Returns the parsers object factory for logical elements.</p>
   */
  public XSObjectFactory getXSObjectFactory();
  /** <p>Sets the parsers object factory for logical elements.</p>
   */
  public void setXSObjectFactory(XSObjectFactory pFactory);

  /** <p>Returns the {@link AttributeSetter}, which is used to
   * configure properties.</p>
   */
  public AttributeSetter getAttributeSetter();
  /** <p>Sets the AttributeSetter, which is used to
   * configure properties.</p>
   */
  public void setAttributeSetter(AttributeSetter pSetter);

  /** <p>Returns the {@link ChildSetter}, which is used to create
   * child elements.</p>
   */
  public ChildSetter getChildSetter();
  /** <p>Sets the ChildSetter, which is used to create
   * child elements.</p>
   */
  public void setChildSetter(ChildSetter pSetter);

  /** <p>Returns the {@link TextSetter}, used to add text sections.</p>
   */
  public TextSetter getTextSetter();
  /** <p>Sets the TextSetter, used to add text sections.</p>
   */
  public void setTextSetter(TextSetter pSetter);

  /** <p>Returns the currently running {@link XSParser} or null,
   * if no such instance is available.</p>
   */
  public XSLogicalParser getXSLogicalParser();
  /** <p>Sets the currently active instance of {@link XSParser}, if any.
   * Returns null, if no such instance is available.</p>
   */
  public void setXSLogicalParser(XSLogicalParser pParser);

  /** <p>Returns the {@link XSSchema}, which is currently being parsed,
   * if any.</p>
   */
  public XSSchema getXSSchema();

  /** <p>Returns the locator, used for error messages.</p>
   */
  public Locator getLocator();    
  /** <p>Sets the locator, used for error messages.</p>
   */
  public void setLocator(Locator pLocator);

  /** <p>Returns the namespace handler.</p>
   */
  public NamespaceSupport getNamespaceSupport();
  /** <p>Sets the namespace handler.</p>
   */
  public void setNamespaceSupport(NamespaceSupport pNamespaceSupport);

  /** <p>Sets the currently active instance of {@link XsSAXParser}.</p>
   */
  public ContentHandler getCurrentContentHandler();
  /** <p>Sets the currently active instance of {@link XsSAXParser}.</p>
   */
  public void setCurrentContentHandler(ContentHandler pParser);
}