/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.parser.impl;

import java.io.PrintStream;
import java.io.PrintWriter;

import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;


/** <p>The <code>locatable SAXException</code>, a subclass of the SAXParseException,
 * provides a human readable representation of the location.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class LocSAXException extends SAXParseException {
  private static String formatMsg(String pMsg, String pPublicId, String pSystemId, int pLineNumber, int pColNumber) {
    StringBuffer sb = new StringBuffer();
    if (pSystemId != null) {
      sb.append(pSystemId);
    }
    if (pLineNumber != -1) {
      if (sb.length() > 0) {
        sb.append(", ");
      }
      sb.append("line ").append(pLineNumber);
    }
    if (pColNumber != -1) {
      if (sb.length() > 0) {
        sb.append(", ");
      }
      sb.append("column ").append(pColNumber);
    }
    if (sb.length() == 0) {
      return "" + pMsg;
    } else {
      return "At " + sb + ": " + pMsg;
    }
  }

  private static String formatMsg(String pMsg, Locator pLocator) {
    if (pLocator == null) {
      return pMsg;
    } else {
      return formatMsg(pMsg, pLocator.getPublicId(), pLocator.getSystemId(), pLocator.getLineNumber(), pLocator.getColumnNumber());
    }
  }

  public LocSAXException(String pMsg, String pPublicId, String pSystemId,
                                int pLineNumber, int pColumnNumber, Exception pException) {
    super(formatMsg(pMsg, pPublicId, pSystemId, pLineNumber, pColumnNumber),
           pPublicId, pSystemId, pLineNumber, pColumnNumber, pException);
  }

  public LocSAXException(String pMsg, String pPublicId, String pSystemId,
                                int pLineNumber, int pColumnNumber) {
    super(formatMsg(pMsg, pPublicId, pSystemId, pLineNumber, pColumnNumber),
           pPublicId, pSystemId, pLineNumber, pColumnNumber);
  }

  public LocSAXException(String pMsg, Locator pLocator, Exception pException) {
    super(formatMsg(pMsg, pLocator), pLocator, pException);
  }

  public LocSAXException(String pMsg, Locator pLocator) {
    super(formatMsg(pMsg, pLocator), pLocator);
  }

  public void printStackTrace(PrintStream pStream) {
    super.printStackTrace(pStream);
    Exception e = getException();
    while (e != null) {
      pStream.println("Caused by:");
      e.printStackTrace(pStream);
      if (e instanceof SAXException) {
        e = ((SAXException) e).getException();
      } else {
        e = null;
      }
    }
  }

  public void printStackTrace(PrintWriter pWriter) {
    super.printStackTrace(pWriter);
    Exception e = getException();
    while (e != null) {
      pWriter.println("Caused by:");
      e.printStackTrace(pWriter);
      if (e instanceof SAXException) {
        e = ((SAXException) e).getException();
      } else {
        e = null;
      }
    }
  }
}
