/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.parser.impl;

import org.apache.ws.jaxme.xs.*;
import org.apache.ws.jaxme.xs.impl.*;
import org.apache.ws.jaxme.xs.parser.*;
import org.apache.ws.jaxme.xs.parser.AttributeSetter;
import org.apache.ws.jaxme.xs.parser.ChildSetter;
import org.apache.ws.jaxme.xs.parser.TextSetter;
import org.apache.ws.jaxme.xs.xml.XsObjectFactory;
import org.apache.ws.jaxme.xs.xml.impl.XsObjectFactoryImpl;
import org.xml.sax.ContentHandler;
import org.xml.sax.Locator;
import org.xml.sax.helpers.NamespaceSupport;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
/** <p>This class provides access to the parsers internal data. The
 * <code>Context</code> instance is stored as a thread local element, thus
 * accessible via a static method.</p>
 */
public class XSContextImpl implements XSContext {
  public static final XsObjectFactory DEFAULT_OBJECT_FACTORY = new XsObjectFactoryImpl();
  public static final XSObjectFactory DEFAULT_XS_OBJECT_FACTORY = new XSObjectFactoryImpl();
  public static final AttributeSetter DEFAULT_ATTRIBUTE_SETTER = new AttributeSetterImpl();
  public static final ChildSetter DEFAULT_CHILD_SETTER = new ChildSetterImpl();
  public static final TextSetter DEFAULT_TEXT_SETTER = new TextSetterImpl();

  private XsObjectFactory objectFactory = DEFAULT_OBJECT_FACTORY;
  private XSObjectFactory xSObjectFactory = DEFAULT_XS_OBJECT_FACTORY;
  private AttributeSetter attributeSetter = DEFAULT_ATTRIBUTE_SETTER;
  private ChildSetter childSetter = DEFAULT_CHILD_SETTER;
  private TextSetter textSetter = DEFAULT_TEXT_SETTER;
  private XSLogicalParser xsParser;
  private Locator locator;
  private NamespaceSupport namespaceSupport = new NamespaceSupport();
  private ContentHandler currentContentHandler;

  public XsObjectFactory getXsObjectFactory() { return objectFactory; }
  public void setXsObjectFactory(XsObjectFactory pFactory) { objectFactory = pFactory; }
  public XSObjectFactory getXSObjectFactory() { return xSObjectFactory; }
  public void setXSObjectFactory(XSObjectFactory pFactory) { xSObjectFactory = pFactory; }
  public AttributeSetter getAttributeSetter() { return attributeSetter; }
  public void setAttributeSetter(AttributeSetter pAttributeSetter) { attributeSetter = pAttributeSetter; }
  public ChildSetter getChildSetter() { return childSetter; }
  public void setChildSetter(ChildSetter pChildSetter) { childSetter = pChildSetter; }
  public TextSetter getTextSetter() { return textSetter; }
  public void setTextSetter(TextSetter pTextSetter) { textSetter = pTextSetter; }
  public XSLogicalParser getXSLogicalParser() { return xsParser; }
  public void setXSLogicalParser(XSLogicalParser pParser) { xsParser = pParser; }
  public XSSchema getXSSchema() { return getXSLogicalParser().getSchema(); }
  public Locator getLocator() { return locator; }
  public void setLocator(Locator pLocator) { locator = pLocator; }
  public void setNamespaceSupport(NamespaceSupport pNamespaceSupport) { namespaceSupport = pNamespaceSupport; }
  public NamespaceSupport getNamespaceSupport() { return namespaceSupport; }

  public void setCurrentContentHandler(ContentHandler pHandler) { currentContentHandler = pHandler; }
  public ContentHandler getCurrentContentHandler() { return currentContentHandler; }
}