/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsComplexContentType {
  private final String name;
  private XsComplexContentType(String pName) {
    name = pName;
  }
  public String toString() { return name; }
  public boolean equals(Object o) {
    return o != null  &&  (o instanceof XsComplexContentType)  &&  ((XsComplexContentType) o).name.equals(name);
  }
  public int hashCode() { return name.hashCode(); }

  /** <p>For elements with 'complexContent' model: The content type empty.</p>
   * @see org.apache.ws.jaxme.xs.XSComplexType#isEmpty()
   * @see org.apache.ws.jaxme.xs.XSComplexType#getComplexContentType()
   */
  public static final XsComplexContentType EMPTY = new XsComplexContentType("empty");

  /** <p>For elements with 'complexContent' model: The content type elementOnly.</p>
   * @see org.apache.ws.jaxme.xs.XSComplexType#isElementOnly()
   * @see org.apache.ws.jaxme.xs.XSComplexType#getComplexContentType()
   */
  public static final XsComplexContentType ELEMENT_ONLY = new XsComplexContentType("elementOnly");

  /** <p>For elements with 'complexContent' model: The content type mixed.</p>
   * @see org.apache.ws.jaxme.xs.XSComplexType#isMixed()
   * @see org.apache.ws.jaxme.xs.XSComplexType#getComplexContentType()
   */
  public static final XsComplexContentType MIXED = new XsComplexContentType("mixed");

  private static final XsComplexContentType[] instances = new XsComplexContentType[]{ EMPTY, ELEMENT_ONLY, MIXED };

  public static XsComplexContentType valueOf(String pValue) {
    for (int i = 0;  i < instances.length;  i++) {
      if (instances[i].toString().equals(pValue)) {
        return instances[i];
      }
    }
    throw new IllegalArgumentException("Invalid complexContent type: " + pValue);
  }
}