/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;

/** <p>Interface of the <code>xs:field</code> element, with the
 * following specification:
 * <pre>
 *   <xs:element name="field" id="field">
 *     <xs:annotation>
 *       <xs:documentation source="http://www.w3.org/TR/xmlschema-1/#element-field"/>
 *     </xs:annotation>
 *     <xs:complexType>
 *       <xs:complexContent>
 *         <xs:extension base="xs:annotated">
 *           <xs:attribute name="xpath" use="required">
 *             <xs:simpleType>
 *               <xs:annotation>
 *                 <xs:documentation>
 *                   A subset of XPath expressions for use in fields
 *                 </xs:documentation>
 *                 <xs:documentation>
 *                   A utility type, not for public use
 *                 </xs:documentation>
 *               </xs:annotation>
 *               <xs:restriction base="xs:token">
 *                 <xs:annotation>
 *                   <xs:documentation>
 *                     The following pattern is intended to allow XPath
 *                     expressions per the same EBNF as for selector,
 *                     with the following change:
 *                       Path    ::=    ('.//')? ( Step '/' )* ( Step | '@' NameTest ) 
 *                   </xs:documentation>
 *                 </xs:annotation>
 *                 <xs:pattern value="(\.//)?((((child::)?((\i\c*:)?(\i\c*|\*)))|\.)/)*((((child::)?((\i\c*:)?(\i\c*|\*)))|\.)|((attribute::|@)((\i\c*:)?(\i\c*|\*))))(\|(\.//)?((((child::)?((\i\c*:)?(\i\c*|\*)))|\.)/)*((((child::)?((\i\c*:)?(\i\c*|\*)))|\.)|((attribute::|@)((\i\c*:)?(\i\c*|\*)))))*">
 *                 </xs:pattern>
 *               </xs:restriction>
 *             </xs:simpleType>
 *           </xs:attribute>
 *         </xs:extension>
 *       </xs:complexContent>
 *     </xs:complexType>
 *   </xs:element>
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XsEField extends XsTAnnotated {
  public void setXpath(XsToken pXpath);
  public XsToken getXpath();
}
