/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;


/** <p>Interface of <code>xs:attrDecls</code>, with the
 * following specification:
 * <pre>
 *  &lt;xs:group name="attrDecls"&gt;
 *    &lt;xs:sequence&gt;
 *      &lt;xs:choice minOccurs="0" maxOccurs="unbounded"&gt;
 *        &lt;xs:element name="attribute" type="xs:attribute"/&gt;
 *        &lt;xs:element name="attributeGroup" type="xs:attributeGroupRef"/&gt;
 *      &lt;/xs:choice&gt;
 *      &lt;xs:element ref="xs:anyAttribute" minOccurs="0"/&gt;
 *    &lt;/xs:sequence&gt;
 *  &lt;/xs:group&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XsGAttrDecls {
  /** <p>Creates a new instance of {@link XsTAttribute}.</p>
   */
  public XsTAttribute createAttribute();

  /** <p>Returns an array of all attributes created by
   * {@link #createAttribute()}.</p>
   */
  public XsTAttribute[] getAttributes();

  /** <p>Creates a new instance of {@link XsTAttributeGroup}.</p>
   */
  public XsTAttributeGroupRef createAttributeGroup();

  /** <p>Returns an array of all attribute groups created by
   * {@link #createAttributeGroup()};
   */
  public XsTAttributeGroupRef[] getAttributeGroups();

  /** <p>Creates a new instance of {@link XsTWildcard}.</p>
   */
  public XsTWildcard createAnyAttribute();

  /** <p>Returns the instance created by {@link #createAnyAttribute()},
   * or null, if the method wasn't called.</p>
   */
  public XsTWildcard getAnyAttribute();

  /** <p>Returns all objects created by {@link #createAttribute()},
   * {@link #createAttributeGroup()}, or {@link #createAnyAttribute()},
   * in the order of the corresponding method calls.</p>
   */
  public Object[] getAllAttributes();
}
