/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;

import javax.xml.parsers.ParserConfigurationException;

import org.apache.ws.jaxme.xs.parser.XsSAXParser;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.XMLReader;


/**
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XsObjectFactory {
  public Locator getLocator();
  public XMLReader newXMLReader(boolean pValidating) throws ParserConfigurationException, SAXException;
  public XsAGDefRef newXsAGDefRef(XsObject pOwner);
  public XsAGOccurs newXsAGOccurs(XsObject pOwner);
  public XsEAnnotation newXsEAnnotation(XsObject pParent);
  public XsEAny newXsEAny(XsObject pParent);
  public XsEAppinfo newXsEAppinfo(XsObject pParent);
  public XsEComplexContent newXsEComplexContent(XsObject pParent);
  public XsEChoice newXsEChoice(XsObject pParent);
  public XsEDocumentation newXsEDocumentation(XsObject pParent);
  public XsEEnumeration newXsEEnumeration(XsObject pParent);
  public XsEField newXsEField(XsObject pParent);
  public XsEFractionDigits newXsEFractionDigits(XsObject pParent);
  public XsEKey newXsEKey(XsObject pParent);
  public XsEImport newXsEImport(XsObject pParent);
  public XsEInclude newXsEInclude(XsObject pParent);
  public XsEKeyref newXsEKeyref(XsObject pParent);
  public XsELength newXsELength(XsObject pParent);
  public XsEList newXsEList(XsObject pParent);
  public XsEMaxExclusive newXsEMaxExclusive(XsObject pParent);
  public XsEMaxInclusive newXsEMaxInclusive(XsObject pParent);
  public XsEMaxLength newXsEMaxLength(XsObject pParent);
  public XsEMinExclusive newXsEMinExclusive(XsObject pParent);
  public XsEMinInclusive newXsEMinInclusive(XsObject pParent);
  public XsEMinLength newXsEMinLength(XsObject pParent);
  public XsENotation newXsENotation(XsObject pParent);
  public XsEPattern newXsEPattern(XsObject pParent);
  public XsERedefine newXsERedefine(XsObject pParent);
  public XsERestriction newXsERestriction(XsObject pParent);
  public XsESchema newXsESchema();
  public XsESelector newXsESelector(XsObject pParent);
  public XsESequence newXsESequence(XsObject pParent);
  public XsESimpleContent newXsESimpleContent(XsObject pParent);
  public XsETopLevelSimpleType newXsETopLevelSimpleType(XsObject pParent);
  public XsETotalDigits newXsETotalDigits(XsObject pParent);
  public XsEUnion newXsEUnion(XsObject pParent);
  public XsEUnique newXsEUnique(XsObject pParent);
  public XsEWhiteSpace newXsEWhiteSpace(XsObject pParent);
  public XsGAllModel newXsGAllModel(XsObject pParent);
  public XsGAttrDecls newXsGAttrDecls(XsObject pOwner);
  public XsGIdentityConstraint newXsGIdentityConstraint(XsObject pOwner);
  public XsGParticle newXsGParticle(XsObject pOwner);
  public XsGComplexTypeModel newXsGComplexTypeModel(XsObject pOwner);
  public XsGSimpleRestrictionModel newXsGSimpleRestrictionModel(XsObject pOwner);
  public XsGTypeDefParticle newXsGTypeDefParticle(XsObject pOwner);
  public XsSAXParser newXsSAXParser();
  public XsSAXParser newXsSAXParser(Object pBean);
  public XsTAll newXsTAll(XsObject pParent);
  public XsTAnnotated newXsTAnnotated(XsObject pParent);
  public XsTAttribute newXsTAttribute(XsObject pParent);
  public XsTAttributeGroup newXsTAttributeGroup(XsObject pParent);
  public XsTAttributeGroupRef newXsTAttributeGroupRef(XsObject pParent);
  public XsTComplexRestrictionType newXsTComplexRestrictionType(XsObject pParent);
  public XsTComplexType newXsTComplexType(XsObject pParent);
  public XsTExtensionType newXsTExtensionType(XsObject pParent);
  public XsTLocalElement newXsTLocalElement(XsObject pParent);
  /** <p>Creates a new instance of {@link XsTLocalElement}, which
   * is located inside of an <code>xs:all</code> group. The
   * element ensures that its <code>minOccurs</code> and
   * <code>maxOccurs</code> values are 0 or 1.</p>
   */
  public XsTLocalElement newXsTLocalAllElement(XsObject pParent);
  public XsTLocalComplexType newXsTLocalComplexType(XsObject pParent);
  public XsTLocalSimpleType newXsTLocalSimpleType(XsObject pParent);
  public XsTNamedGroup newXsTNamedGroup(XsObject pParent);
  public XsTGroup newXsTGroup(XsObject pParent);
  public XsTGroupRef newXsTGroupRef(XsObject pParent);
  public XsTSimpleExplicitGroup newXsTSimpleExplicitGroup(XsObject pParent);
  public XsTSimpleExtensionType newXsTSimpleExtensionType(XsObject pParent);
  public XsTSimpleRestrictionType newXsTSimpleRestrictionType(XsObject pParent);
  public XsTTopLevelElement newXsTTopLevelElement(XsObject pParent);
  public XsTWildcard newXsTWildcard(XsObject pParent);
}