/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;


/** <p>Implementation of <code>xs:qName</code>.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsQName {
  private final String namespaceURI;
  private final String localName;
  private final String prefix;

  public XsQName(XsAnyURI pNamespaceURI, String pLocalName) {
    this(pNamespaceURI == null ? null : pNamespaceURI.getURI(), pLocalName, null);
  }

  public XsQName(XsAnyURI pNamespaceURI, String pLocalName, String pPrefix) {
    this(pNamespaceURI == null ? null : pNamespaceURI.getURI(), pLocalName, pPrefix);
  }

  public XsQName(String pNamespaceURI, String pLocalName) {
    this(pNamespaceURI, pLocalName, null);
  }

  public XsQName(String pNamespaceURI, String pLocalName, String pPrefix) {
    namespaceURI = (pNamespaceURI == null) ? "" : pNamespaceURI;
    if (pLocalName == null) {
      throw new NullPointerException("The localName must not be null.");
    }
    localName = pLocalName;
    prefix = pPrefix;
  }

  public String getNamespaceURI() { return namespaceURI; }
  public String getLocalName() { return localName; }
  public String getPrefix() { return prefix; }

  public boolean equals(Object pObject) {
    if (pObject == null  ||  !(pObject instanceof XsQName)) {
      return false;
    }
    XsQName name = (XsQName) pObject;
    return name.namespaceURI.equals(namespaceURI)  &&  name.localName.equals(localName);
  }

  public int hashCode() {
    return namespaceURI.hashCode() + localName.hashCode();
  }

  public String toString() {
    if ("".equals(namespaceURI)) { return localName; }
    return "{" + namespaceURI + "}" + localName;
  }

  public static String prefixOf(String pQName) {
    int offset = pQName.indexOf(':');
    if (offset > 0) {
      return pQName.substring(0, offset);
    } else {
      return "";
    }
  }
}
