/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2004 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;

/** <p>This interface contains the data contained in the schemas
 * root element.</p>
 */
public interface XsSchemaHeader {
	/** <p>Returns the "form" attributes default value for attributes.</p>
	 */
	public XsFormChoice getAttributeFormDefault();

	/** <p>Returns the "block" attributes default value.</p>
	 */
	public XsBlockSet getBlockDefault();

	/** <p>Returns the "form" attributes default value for elements.</p>
	 */
	public XsFormChoice getElementFormDefault();

	/** <p>Returns the "final" attributes default value.</p>
	 */
	public XsDerivationSet getFinalDefault();

	/** <p>Returns the schemas ID.</p>
	 */
	public XsID getId();

	/** <p>Returns the target namespace.</p>
	 */
	public XsAnyURI getTargetNamespace();

	/** <p>Returns the schema version.</p>
	 */
	public XsToken getVersion();

	/** <p>Returns a prefix associated with the target namespace or null, if
	 * no such prefix is available.</p>
	 */
	String getTargetNamespacePrefix();
}
