/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;

import org.xml.sax.SAXException;


/** <p>Interface of <code>xs:attribute</code>, following
 * this specification:
 * <pre>
 *  &lt;xs:complexType name="attribute"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:extension base="xs:annotated"&gt;
 *        &lt;xs:sequence&gt;
 *          &lt;xs:element name="simpleType" minOccurs="0" type="xs:localSimpleType"/&gt;
 *        &lt;/xs:sequence&gt;
 *        &lt;xs:attributeGroup ref="xs:defRef"/&gt;
 *        &lt;xs:attribute name="type" type="xs:QName"/&gt;
 *        &lt;xs:attribute name="use" use="optional" default="optional"&gt;
 *          &lt;xs:simpleType&gt;
 *            &lt;xs:restriction base="xs:NMTOKEN"&gt;
 *              &lt;xs:enumeration value="prohibited"/&gt;
 *              &lt;xs:enumeration value="optional"/&gt;
 *              &lt;xs:enumeration value="required"/&gt;
 *            &lt;/xs:restriction&gt;
 *          &lt;/xs:simpleType&gt;
 *        &lt;/xs:attribute&gt;
 *        &lt;xs:attribute name="default" type="xs:string"/&gt;
 *        &lt;xs:attribute name="fixed" type="xs:string"/&gt;
 *        &lt;xs:attribute name="form" type="xs:formChoice"/&gt;
 *      &lt;/xs:extension&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XsTAttribute extends XsTAnnotated {
  public static class Use {
    private String value;
    Use(String pValue) { value = pValue; }
    public String toString() { return value; }
    public String getValue() { return value; }
    public static Use valueOf(String pValue) {
      if ("prohibited".equals(pValue)) {
        return PROHIBITED;
      } else if ("optional".equals(pValue)) {
        return OPTIONAL;
      } else if ("required".equals(pValue)) {
        return REQUIRED;
      } else {
        throw new IllegalArgumentException("Invalid value for Use: " + pValue + ", expected 'prohibited', 'optional', or 'use'");
      }
    }
  }

  public static final Use PROHIBITED = new Use("prohibited");
  public static final Use OPTIONAL = new Use("optional");
  public static final Use REQUIRED = new Use("required");

  public XsTLocalSimpleType createSimpleType();

  public XsTLocalSimpleType getSimpleType();

  public void setType(XsQName pType);

  public XsQName getType();

  public void setUse(Use pUse);

  public Use getUse();

  public void setDefault(String pDefault);

  public String getDefault();

  public void setFixed(String pFixed);

  public String getFixed();

  public void setForm(XsFormChoice pForm) throws SAXException;

  public XsFormChoice getForm();

  public void setName(XsNCName pName);

  public XsNCName getName();

  public void setRef(XsQName pRef);

  public XsQName getRef();

  public boolean isGlobal();
}
