/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;


/** <p>Interface of a complex type, to be shared
 * by {@link org.apache.ws.jaxme.xs.xml.XsTLocalComplexType} and
 * {@link XsTComplexType}.
 * Follows this specification:
 * <pre>
 *  &lt;xs:complexType name="complexType" abstract="true"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:extension base="xs:annotated"&gt;
 *        &lt;xs:group ref="xs:complexTypeModel"/&gt;
 *        &lt;xs:attribute name="name" type="xs:NCName"&gt;
 *          &lt;xs:annotation&gt;
 *            &lt;xs:documentation&gt;
 *              Will be restricted to required or forbidden
 *            &lt;/xs:documentation&gt;
 *          &lt;/xs:annotation&gt;
 *        &lt;/xs:attribute&gt;
 *        &lt;xs:attribute name="mixed" type="xs:boolean" use="optional" default="false"&gt;
 *          &lt;xs:annotation&gt;
 *            &lt;xs:documentation&gt;
 *              Not allowed if simpleContent child is chosen.
 *              May be overriden by setting on complexContent child.
 *            &lt;/xs:documentation&gt;
 *          &lt;/xs:annotation&gt;
 *        &lt;/xs:attribute&gt;
 *        &lt;xs:attribute name="abstract" type="xs:boolean" use="optional" default="false"/&gt;
 *        &lt;xs:attribute name="final" type="xs:derivationSet"/&gt;
 *        &lt;xs:attribute name="block" type="xs:derivationSet"/&gt;
 *      &lt;/xs:extension&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 *
 *  &lt;xs:group name="complexTypeModel"&gt;
 *    &lt;xs:choice&gt;
 *      &lt;xs:element ref="xs:simpleContent"/&gt;
 *      &lt;xs:element ref="xs:complexContent"/&gt;
 *      &lt;xs:sequence&gt;
 *        &lt;xs:annotation&gt;
 *          &lt;xs:documentation&gt;
 *            This branch is short for &amp;lt;complexContent&amp;gt;
 *            &amp;lt;restriction base="xs:anyType"&amp;gt;
 *            ...
 *            &amp;lt;/restriction&amp;gt;
 *            &amp;lt;/complexContent&amp;gt;
 *          &lt;/xs:documentation&gt;
 *        &lt;/xs:annotation&gt;
 *        &lt;xs:group ref="xs:typeDefParticle" minOccurs="0"/&gt;
 *        &lt;xs:group ref="xs:attrDecls"/&gt;
 *      &lt;/xs:sequence&gt;
 *    &lt;/xs:choice&gt;
 *  &lt;/xs:group&gt;
 *
 *  &lt;xs:group name="typeDefParticle"&gt;
 *    &lt;xs:annotation&gt;
 *      &lt;xs:documentation&gt;
 *        'complexType' uses this
 *      &lt;/xs:documentation&gt;
 *    &lt;/xs:annotation&gt;
 *    &lt;xs:choice&gt;
 *      &lt;xs:element name="group" type="xs:groupRef"/&gt;
 *      &lt;xs:element ref="xs:all"/&gt;
 *      &lt;xs:element ref="xs:choice"/&gt;
 *      &lt;xs:element ref="xs:sequence"/&gt;
 *    &lt;/xs:choice&gt;
 *  &lt;/xs:group&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XsTComplexType extends XsTAnnotated, XsGTypeDefParticle, XsGAttrDecls, XsRedefinable {
  public void setMixed(boolean pMixed);
  public boolean isMixed();

  public void setAbstract(boolean pAbstract);
  public boolean isAbstract();

  public XsESimpleContent createSimpleContent();

  public XsESimpleContent getSimpleContent();

  public XsEComplexContent createComplexContent();

  public XsEComplexContent getComplexContent();

  public void setName(XsNCName pName);

  public XsNCName getName();
}
