/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml;

import org.xml.sax.SAXException;


/** <p>Implementation of the <code>xs:element</code> type,
 * as specified by the following:
 * <pre>
 *  <xs:complexType name="element" abstract="true">
 *    <xs:annotation>
 *      <xs:documentation>
 *        The element element can be used either
 *        at the top level to define an element-type binding globally,
 *        or within a content model to either reference a globally-defined
 *        element or type or declare an element-type binding locally.
 *        The ref form is not allowed at the top level.
 *      </xs:documentation>
 *    </xs:annotation>
 *    <xs:complexContent>
 *      <xs:extension base="xs:annotated">
 *        <xs:sequence>
 *          <xs:choice minOccurs="0">
 *            <xs:element name="simpleType" type="xs:localSimpleType"/>
 *            <xs:element name="complexType" type="xs:localComplexType"/>
 *          </xs:choice>
 *          <xs:group ref="xs:identityConstraint" minOccurs="0" maxOccurs="unbounded"/>
 *        </xs:sequence>
 *        <xs:attributeGroup ref="xs:defRef"/>
 *        <xs:attribute name="type" type="xs:QName"/>
 *        <xs:attribute name="substitutionGroup" type="xs:QName"/>
 *        <xs:attributeGroup ref="xs:occurs"/>
 *        <xs:attribute name="default" type="xs:string"/>
 *        <xs:attribute name="fixed" type="xs:string"/>
 *        <xs:attribute name="nillable" type="xs:boolean" use="optional" default="false"/>
 *        <xs:attribute name="abstract" type="xs:boolean" use="optional" default="false"/>
 *        <xs:attribute name="final" type="xs:derivationSet"/>
 *        <xs:attribute name="block" type="xs:blockSet"/>
 *        <xs:attribute name="form" type="xs:formChoice"/>
 *      </xs:extension>
 *    </xs:complexContent>
 *  </xs:complexType>
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public interface XsTElement extends XsTAnnotated, XsAGDefRef, XsAGOccurs, XsGIdentityConstraint {
  public XsTLocalSimpleType createSimpleType() throws SAXException;
  public XsTLocalSimpleType getSimpleType();

  public XsTLocalComplexType createComplexType() throws SAXException;
  public XsTLocalComplexType getComplexType();

  public void setType(XsQName pType) throws SAXException;
  public XsQName getType();

  public void setSubstitutionGroup(XsQName pSubstitutionGroup) throws SAXException;
  public XsQName getSubstitutionGroup();

  public void setDefault(String pDefault);
  public String getDefault();

  public void setFixed(String pFixed);
  public String getFixed();

  public void setNillable(boolean pNillable);
  public boolean getNillable();

  public void setAbstract(boolean pAbstract);
  public boolean getAbstract();

  public void setFinal(XsDerivationSet pFinal);
  public XsDerivationSet getFinal();

  public void setBlock(XsBlockSet pBlock);
  public XsBlockSet getBlock();

  public void setForm(XsFormChoice pForm);
  public XsFormChoice getForm();

  public boolean isGlobal();
}
