/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import org.apache.ws.jaxme.xs.parser.XSContext;
import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.*;
import org.apache.ws.jaxme.xs.xml.XsObject;
import org.xml.sax.Locator;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.LocatorImpl;
import org.xml.sax.helpers.NamespaceSupport;

/** <p>Base class for all the types, attributes, elements, ...</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsObjectImpl implements XsObject {
  private final XsObject parent;
  private boolean isValidated;
  private final Locator locator;

  protected XsObjectImpl(XsObject pParent) {
    if (pParent == null) {
      if (!(this instanceof XsESchema)) {
        throw new IllegalStateException("Only the schema may have a null parent.");
      }
    } else {
      if (this instanceof XsESchema) {
        throw new IllegalStateException("The schema must have a null parent.");
      }
    }
    parent = pParent;
    XSContext context = getContext();
    if (context != null) {
      Locator loc = context.getLocator();
      locator = loc == null ? null : new LocatorImpl(getContext().getLocator());
    } else {
      locator = null;
    }
  }

  public XsESchema getXsESchema() {
    if (parent == null) {
      return (XsESchema) this;
    } else {
      return parent.getXsESchema();
    }
  }

  public boolean isTopLevelObject() { return parent == null  ||  parent instanceof XsESchema; }
  public XsObject getParentObject() { return parent; }

  public XsObjectFactory getObjectFactory() { return getContext().getXsObjectFactory(); }
  public Locator getLocator() { return locator; }
  protected NamespaceSupport getNamespaceSupport() { return getContext().getNamespaceSupport(); }
  protected static XsQName asXsQName(Locator pLocator, NamespaceSupport pNss, String pName) throws SAXException {
    String[] parts = pNss.processName(pName, new String[3], false);
    if (parts == null) {
      throw new LocSAXException("Undeclared namespace prefix: " + pName, pLocator);
    }
    return new XsQName(parts[0], parts[1], XsQName.prefixOf(pName));
  }
  public XSContext getContext() { return getXsESchema().getContext(); }

  protected final boolean isValidated() {
    return isValidated;
  }

  public void validate() throws SAXException {
    isValidated = true;
  }
}
