/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import org.apache.ws.jaxme.xs.xml.*;
import org.xml.sax.SAXException;


/** <p>Implementation of the following type:
 * <pre>
 *   &lt;xs:complexType name="all"&gt;
 *     &lt;xs:annotation&gt;
 *       &lt;xs:documentation&gt;
 *         Only elements allowed inside
 *       &lt;/xs:documentation&gt;
 *     &lt;/xs:annotation&gt;
 *     &lt;xs:complexContent&gt;
 *       &lt;xs:restriction base="xs:explicitGroup"&gt;
 *         &lt;xs:group ref="xs:allModel"/&gt;
 *         &lt;xs:attribute name="minOccurs" use="optional" default="1"&gt;
 *           &lt;xs:simpleType&gt;
 *             &lt;xs:restriction base="xs:nonNegativeInteger"&gt;
 *               &lt;xs:enumeration value="0"/&gt;
 *               &lt;xs:enumeration value="1"/&gt;
 *             &lt;/xs:restriction&gt;
 *           &lt;/xs:simpleType&gt;
 *         &lt;/xs:attribute&gt;
 *         &lt;xs:attribute name="maxOccurs" use="optional" default="1"&gt;
 *           &lt;xs:simpleType&gt;
 *             &lt;xs:restriction base="xs:allNNI"&gt;
 *               &lt;xs:enumeration value="1"/&gt;
 *             &lt;/xs:restriction&gt;
 *           &lt;/xs:simpleType&gt;
 *         &lt;/xs:attribute&gt;
 *       &lt;/xs:restriction&gt;
 *     &lt;/xs:complexContent&gt;
 *   &lt;/xs:complexType&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsTAllImpl extends XsTAnnotatedImpl implements XsTAll {
  private final XsAGOccurs occurs;
  private final XsGParticle particle;

  protected XsTAllImpl(XsObject pParent) {
    super(pParent);
    occurs = getObjectFactory().newXsAGOccurs(this);
    particle = getObjectFactory().newXsGParticle(this);
  }

  public void setName(XsNCName pName) {
    throw new IllegalStateException("Use of the 'name' attribute is prohibited in xs:explicitGroup");
  }

  public XsNCName getName() {
    throw new IllegalStateException("Use of the 'name' attribute is prohibited in xs:explicitGroup");
  }

  public void setRef(XsQName pRef) {
    throw new IllegalStateException("Use of the 'name' attribute is prohibited in xs:explicitGroup");
  }

  public void setRef(String pRef) throws SAXException {
    throw new IllegalStateException("Use of the 'name' attribute is prohibited in xs:explicitGroup");
  }

  public XsQName getRef() {
    throw new IllegalStateException("Use of the 'name' attribute is prohibited in xs:explicitGroup");
  }

  public void setMaxOccurs(String pMaxOccurs) {
    try {
      if (Integer.parseInt(pMaxOccurs) != 1) {
        throw new IllegalArgumentException();
      }
    } catch (Exception e) {
      throw new IllegalArgumentException("Invalid value of the 'maxOccurs' attribute: " + pMaxOccurs + "; must be 1");
    }
  }

  public int getMaxOccurs() {
    return 1;
  }

  public void setMinOccurs(int pMinOccurs) {
    occurs.setMinOccurs(pMinOccurs);
  }

  public int getMinOccurs() {
    return occurs.getMinOccurs();
  }

  public XsTLocalElement createElement() {
    return particle.createElement();
  }

  public XsTGroupRef createGroup() {
    return particle.createGroup();
  }

  public XsTAll createAll() {
    return particle.createAll();
  }

  public XsESequence createSequence() {
    return particle.createSequence();
  }

  public XsEChoice createChoice() {
    return particle.createChoice();
  }

  public XsEAny createAny() {
    return particle.createAny();
  }

  public XsTParticle[] getParticles() {
    return particle.getParticles();
  }

  public void validate() throws SAXException {
    super.validate();
  }
}
