/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.*;
import org.xml.sax.SAXException;


/** <p>Implementation of <code>xs:complexRestrictionType</code>,
 * as specified by the following:
 * <pre>
 *  &lt;xs:complexType name="complexRestrictionType"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:restriction base="xs:restrictionType"&gt;
 *        &lt;xs:sequence&gt;
 *          &lt;xs:element ref="xs:annotation" minOccurs="0"/&gt;
 *          &lt;xs:group ref="xs:typeDefParticle" minOccurs="0"/&gt;
 *          &lt;xs:group ref="xs:attrDecls"/&gt;
 *        &lt;/xs:sequence&gt;
 *      &lt;/xs:restriction&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsTComplexRestrictionTypeImpl extends XsTRestrictionTypeImpl
    implements XsTComplexRestrictionType {
  protected XsTComplexRestrictionTypeImpl(XsObject pParent) {
    super(pParent);
  }

  public XsTLocalSimpleType createSimpleType() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'simpleType' child element.", getLocator());
  }

  public XsEMinExclusive createMinExclusive() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'minExclusive' child element.", getLocator());
  }

  public XsEMinInclusive createMinInclusive() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'minInclusive' child element.", getLocator());
  }

  public XsEMaxExclusive createMaxExclusive() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'maxExclusive' child element.", getLocator());
  }

  public XsEMaxInclusive createMaxInclusive() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'maxInclusive' child element.", getLocator());
  }

  public XsETotalDigits createTotalDigits() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'totalDigits' child element.", getLocator());
  }

  public XsEFractionDigits createFractionDigits() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'fractionDigits' child element.", getLocator());
  }

  public XsELength createLength() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'length' child element.", getLocator());
  }

  public XsEMinLength createMinLength() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'minLength' child element.", getLocator());
  }

  public XsEMaxLength createMaxLength() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'maxLength' child element.", getLocator());
  }

  public XsEWhiteSpace createWhiteSpace() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'whiteSpace' child element.", getLocator());
  }

  public XsEPattern createPattern() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'pattern' child element.", getLocator());
  }

  public XsEEnumeration createEnumeration() throws SAXException {
    throw new LocSAXException("A restriction with complex content doesn't support the 'enumeration' child element.", getLocator());
  }
}
