/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.ws.jaxme.xs.xml.*;


/** <p>Implementation of the <code>xs:keybase</code> type, with the
 * following specification:
 * <pre>
 *  &lt;xs:complexType name="keybase"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:extension base="xs:annotated"&gt;
 *        &lt;xs:sequence&gt;
 *          &lt;xs:element ref="xs:selector"/&gt;
 *          &lt;xs:element ref="xs:field" minOccurs="1" maxOccurs="unbounded"/&gt;
 *        &lt;/xs:sequence&gt;
 *        &lt;xs:attribute name="name" type="xs:NCName" use="required"/&gt;
 *      &lt;/xs:extension&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsTKeybaseImpl extends XsTAnnotatedImpl implements XsTKeybase {
  private XsESelector selector;
  private List fields = new ArrayList();
  private XsNCName name;

  protected XsTKeybaseImpl(XsObject pParent) {
    super(pParent);
  }

  public XsESelector createSelector() {
    if (selector != null) {
      throw new IllegalStateException("Multiple 'selector' child elements are forbidden.");
    }
    if (fields.size() > 0) {
      throw new IllegalStateException("The 'selector' child element must precede the 'field' child elements.");
    }
    selector = getObjectFactory().newXsESelector(this);
    return selector;
  }

  public XsESelector getSelector() {
    return selector;
  }

  public XsEField createField() {
    if (selector == null) {
      throw new NullPointerException("This 'field' child element must be preceded by a 'selector' child element.");
    }
    XsEField field = getObjectFactory().newXsEField(this);
    fields.add(field);
    return field;
  }

  public XsEField[] getFields() {
    return (XsEField[]) fields.toArray(new XsEField[fields.size()]);
  }

  public void setName(XsNCName pName) {
    name = pName;
  }

  public XsNCName getName() {
    return name;
  }

  public void validate() {
    if (name == null) {
      throw new NullPointerException("Missing attribute: 'name'");
    }
    if (selector == null) {
      throw new NullPointerException("Missing child element: 'selector'");
    }
    if (fields.size() == 0) {
      throw new NullPointerException("Missing child element: 'field'");
    }
  }
}
