/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import org.apache.ws.jaxme.xs.xml.*;


/** <p>Implementation of the <code>xs:localElement</code> type, as
 * specified by:
 * <pre>
 *  &lt;xs:complexType name="localElement"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:restriction base="xs:element"&gt;
 *        &lt;xs:sequence&gt;
 *          &lt;xs:element ref="xs:annotation" minOccurs="0"/&gt;
 *          &lt;xs:choice minOccurs="0"&gt;
 *            &lt;xs:element name="simpleType" type="xs:localSimpleType"/&gt;
 *            &lt;xs:element name="complexType" type="xs:localComplexType"/&gt;
 *          &lt;/xs:choice&gt;
 *          &lt;xs:group ref="xs:identityConstraint" minOccurs="0" maxOccurs="unbounded"/&gt;
 *        &lt;/xs:sequence&gt;
 *        &lt;xs:attribute name="substitutionGroup" use="prohibited"/&gt;
 *        &lt;xs:attribute name="final" use="prohibited"/&gt;
 *        &lt;xs:attribute name="abstract" use="prohibited"/&gt;
 *      &lt;/xs:restriction&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 * </pre></p>
 * <p><em>Implementation note:</em> This class doesn't specify any
 * additional methods. It only disables the 'substitutionGroup',
 * 'final', and 'abstract' attributes.</p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsTLocalElementImpl extends XsTElementImpl implements XsTLocalElement {
  protected XsTLocalElementImpl(XsObject pParent) {
    super(pParent);
  }

  public void setSubstitutionGroup(XsQName pSubstitutionGroup) {
    throw new IllegalArgumentException("A local element must not have its 'substitutionGroup' attribute set.");
  }

  public void setSubstitutionGroup(String pSubstitutionGroup) {
    throw new IllegalArgumentException("A local element must not have its 'substitutionGroup' attribute set.");
  }

  public void setFinal(XsDerivationSet pFinal) {
    throw new IllegalArgumentException("A local element must not have its 'final' attribute set.");
  }

  public void setAbstract(boolean pAbstract) {
    throw new IllegalArgumentException("A local element must not have its 'abstract' attribute set.");
  }

  public boolean isGlobal() { return false; }
}
