/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import org.apache.ws.jaxme.xs.parser.impl.LocSAXException;
import org.apache.ws.jaxme.xs.xml.*;
import org.xml.sax.SAXException;


/** <p>Implementation of <code>xs:restrictionType</code>,
 * as specified by the following:
 * <pre>
 *  &lt;xs:complexType name="restrictionType"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:extension base="xs:annotated"&gt;
 *        &lt;xs:sequence&gt;
 *          &lt;xs:choice&gt;
 *            &lt;xs:group ref="xs:typeDefParticle" minOccurs="0"/&gt;
 *            &lt;xs:group ref="xs:simpleRestrictionModel" minOccurs="0"/&gt;
 *          &lt;/xs:choice&gt;
 *          &lt;xs:group ref="xs:attrDecls"/&gt;
 *        &lt;/xs:sequence&gt;
 *        &lt;xs:attribute name="base" type="xs:QName" use="required"/&gt;
 *      &lt;/xs:extension&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 * </pre></p>
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsTRestrictionTypeImpl extends XsTAnnotatedImpl
    implements XsTRestrictionType {
  private XsQName base;
  private final XsGTypeDefParticle typeDefParticle;
  private final XsGSimpleRestrictionModel simpleRestrictionModel;
  private final XsGAttrDecls attrDecls;

  protected XsTRestrictionTypeImpl(XsObject pParent) {
    super(pParent);
    typeDefParticle = getObjectFactory().newXsGTypeDefParticle(this);
    simpleRestrictionModel = getObjectFactory().newXsGSimpleRestrictionModel(this);
    attrDecls = getObjectFactory().newXsGAttrDecls(this);
  }

  public void setBase(XsQName pBase) {
    base = pBase;
  }

  public void setBase(String pBase) throws SAXException {
    setBase(XsObjectImpl.asXsQName(getLocator(), getNamespaceSupport(), pBase));
  }

  public XsQName getBase() {
    return base;
  }

  public XsTGroupRef createGroup() {
    return typeDefParticle.createGroup();
  }

  public XsTAll createAll() {
    return typeDefParticle.createAll();
  }

  public XsESequence createSequence() {
    return typeDefParticle.createSequence();
  }

  public XsEChoice createChoice() {
    return typeDefParticle.createChoice();
  }

  public XsTTypeDefParticle getTypeDefParticle() {
    return typeDefParticle.getTypeDefParticle();
  }

  public XsTLocalSimpleType createSimpleType() throws SAXException {
    return simpleRestrictionModel.createSimpleType();
  }

  public XsTLocalSimpleType getSimpleType() {
    return simpleRestrictionModel.getSimpleType();
  }

  public XsEMinExclusive createMinExclusive() throws SAXException {
    return simpleRestrictionModel.createMinExclusive();
  }

  public XsEMinExclusive getMinExclusive() {
    return simpleRestrictionModel.getMinExclusive();
  }

  public XsEMinInclusive createMinInclusive() throws SAXException {
    return simpleRestrictionModel.createMinInclusive();
  }

  public XsEMinInclusive getMinInclusive() {
    return simpleRestrictionModel.getMinInclusive();
  }

  public XsEMaxExclusive createMaxExclusive() throws SAXException {
    return simpleRestrictionModel.createMaxExclusive();
  }

  public XsEMaxExclusive getMaxExclusive() {
    return simpleRestrictionModel.getMaxExclusive();
  }

  public XsEMaxInclusive createMaxInclusive() throws SAXException {
    return simpleRestrictionModel.createMaxInclusive();
  }

  public XsEMaxInclusive getMaxInclusive() {
    return simpleRestrictionModel.getMaxInclusive();
  }

  public XsETotalDigits createTotalDigits() throws SAXException {
    return simpleRestrictionModel.createTotalDigits();
  }

  public XsETotalDigits getTotalDigits() {
    return simpleRestrictionModel.getTotalDigits();
  }

  public XsEFractionDigits createFractionDigits() throws SAXException {
    return simpleRestrictionModel.createFractionDigits();
  }

  public XsEFractionDigits getFractionDigits() {
    return simpleRestrictionModel.getFractionDigits();
  }

  public XsELength createLength() throws SAXException {
    return simpleRestrictionModel.createLength();
  }

  public XsELength getLength() {
    return simpleRestrictionModel.getLength();
  }

  public XsEMinLength createMinLength() throws SAXException {
    return simpleRestrictionModel.createMinLength();
  }

  public XsEMinLength getMinLength() {
    return simpleRestrictionModel.getMinLength();
  }

  public XsEMaxLength createMaxLength() throws SAXException {
    return simpleRestrictionModel.createMaxLength();
  }

  public XsEMaxLength getMaxLength() {
    return simpleRestrictionModel.getMaxLength();
  }

  public XsEWhiteSpace createWhiteSpace() throws SAXException {
    return simpleRestrictionModel.createWhiteSpace();
  }

  public XsEWhiteSpace getWhiteSpace() {
    return simpleRestrictionModel.getWhiteSpace();
  }

  public XsEPattern createPattern() throws SAXException {
    return simpleRestrictionModel.createPattern();
  }

  public XsEPattern[] getPatterns() {
    return simpleRestrictionModel.getPatterns();
  }

  public XsEEnumeration createEnumeration() throws SAXException {
    return simpleRestrictionModel.createEnumeration();
  }

  public XsEEnumeration[] getEnumerations() {
    return simpleRestrictionModel.getEnumerations();
  }

  public boolean hasFacets() {
    return simpleRestrictionModel.hasFacets();
  }

  public XsTFacetBase[] getFacets() {
    return simpleRestrictionModel.getFacets();
  }

  public XsTAttribute createAttribute() {
    return attrDecls.createAttribute();
  }

  public XsTAttribute[] getAttributes() {
    return attrDecls.getAttributes();
  }

  public XsTAttributeGroupRef createAttributeGroup() {
    return attrDecls.createAttributeGroup();
  }

  public XsTAttributeGroupRef[] getAttributeGroups() {
    return attrDecls.getAttributeGroups();
  }

  public XsTWildcard createAnyAttribute() {
    return attrDecls.createAnyAttribute();
  }

  public XsTWildcard getAnyAttribute() {
    return attrDecls.getAnyAttribute();
  }

  public Object[] getAllAttributes() {
    return attrDecls.getAllAttributes();
  }

  public void validate() throws SAXException {
    super.validate();
    if (base == null) {
      throw new LocSAXException("The 'base' attribute must be set.", getLocator());
    }
  }
}
