/*
 * The Apache Software License, Version 1.1
 *
 *
 * Copyright (c) 2003 The Apache Software Foundation.  All rights 
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer. 
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:  
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The name "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written 
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */
package org.apache.ws.jaxme.xs.xml.impl;

import org.apache.ws.jaxme.xs.xml.*;
import org.xml.sax.SAXException;


/** <p>Implementation of <code>xs:simpleRestrictionType</code>,
 * as specified by the following:
 * <pre>
 *  &lt;xs:complexType name="simpleRestrictionType"&gt;
 *    &lt;xs:complexContent&gt;
 *      &lt;xs:restriction base="xs:restrictionType"&gt;
 *        &lt;xs:sequence&gt;
 *          &lt;xs:element ref="xs:annotation" minOccurs="0"/&gt;
 *          &lt;xs:group ref="xs:simpleRestrictionModel" minOccurs="0"/&gt;
 *          &lt;xs:group ref="xs:attrDecls"/&gt;
 *        &lt;/xs:sequence&gt;
 *      &lt;/xs:restriction&gt;
 *    &lt;/xs:complexContent&gt;
 *  &lt;/xs:complexType&gt;
 * </pre></p>
 *
 * @author <a href="mailto:joe@ispsoft.de">Jochen Wiedmann</a>
 */
public class XsTSimpleRestrictionTypeImpl extends XsTRestrictionTypeImpl
    implements XsTSimpleRestrictionType {
  private final XsGSimpleRestrictionModel impl;
  private final XsGAttrDecls decls;

  protected XsTSimpleRestrictionTypeImpl(XsObject pParent) {
    super(pParent);
    impl = getObjectFactory().newXsGSimpleRestrictionModel(this);
    decls = getObjectFactory().newXsGAttrDecls(this);
  }

  public XsTLocalSimpleType createSimpleType() throws SAXException {
    return impl.createSimpleType();
  }

  public XsTLocalSimpleType getSimpleType() {
    return impl.getSimpleType();
  }

  public XsEMaxExclusive getMaxExclusive() {
    return impl.getMaxExclusive();
  }

  public XsEMinExclusive createMinExclusive() throws SAXException {
    return impl.getMinExclusive();
  }

  public XsEMinExclusive getMinExclusive() {
    return impl.getMinExclusive();
  }

  public XsEMaxInclusive createMaxInclusive() throws SAXException {
    return impl.createMaxInclusive();
  }

  public XsEMaxInclusive getMaxInclusive() {
    return impl.getMaxInclusive();
  }

  public XsEMinInclusive createMinInclusive() throws SAXException {
    return impl.createMinInclusive();
  }

  public XsEMinInclusive getMinInclusive() {
    return impl.getMinInclusive();
  }

  public XsETotalDigits createTotalDigits() throws SAXException {
    return impl.createTotalDigits();
  }

  public XsETotalDigits getTotalDigits() {
    return impl.getTotalDigits();
  }

  public XsEFractionDigits createFractionDigits() throws SAXException {
    return impl.createFractionDigits();
  }

  public XsEFractionDigits getFractionDigits() {
    return impl.getFractionDigits();
  }

  public XsELength createLength() throws SAXException {
    return impl.createLength();
  }

  public XsELength getLength() {
    return impl.getLength();
  }

  public XsEMinLength createMinLength() throws SAXException {
    return impl.createMinLength();
  }

  public XsEMinLength getMinLength() {
    return impl.getMinLength();
  }

  public XsEMaxLength createMaxLength() throws SAXException {
    return impl.createMaxLength();
  }

  public XsEMaxLength getMaxLength() {
    return impl.getMaxLength();
  }

  public XsEWhiteSpace createWhiteSpace() throws SAXException {
    return impl.createWhiteSpace();
  }

  public XsEWhiteSpace getWhiteSpace() {
    return impl.getWhiteSpace();
  }

  public XsEPattern createPattern() throws SAXException {
    return impl.createPattern();
  }

  public XsEPattern[] getPatterns() {
    return impl.getPatterns();
  }

  public XsEEnumeration createEnumeration() throws SAXException {
    return impl.createEnumeration();
  }

  public XsEEnumeration[] getEnumerations() {
    return impl.getEnumerations();
  }

  public boolean hasFacets() {
    return impl.hasFacets();
  }

  public XsTFacetBase[] getFacets() {
    return impl.getFacets();
  }

  public XsTAttribute createAttribute() {
    return decls.createAttribute();
  }

  public XsTAttribute[] getAttributes() {
    return decls.getAttributes();
  }

  public XsTAttributeGroupRef createAttributeGroup() {
    return decls.createAttributeGroup();
  }

  public XsTAttributeGroupRef[] getAttributeGroups() {
    return decls.getAttributeGroups();
  }

  public XsTWildcard createAnyAttribute() {
    return decls.createAnyAttribute();
  }

  public XsTWildcard getAnyAttribute() {
    return decls.getAnyAttribute();
  }

  public Object[] getAllAttributes() {
    return decls.getAllAttributes();
  }
}
